@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -25,10 +23,7 @@ It also demonstrates the useful testing technique of testing how the answer
 should change (or not) in response to movements in the underlying data.
 """
 
-from __future__ import absolute_import, division, print_function
-
-import hypothesis.strategies as st
-from hypothesis import given
+from hypothesis import given, strategies as st
 
 
 def binary_search(ls, v):
