@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -21,14 +19,13 @@ Either an explicit settings object can be used or the default object on
 this module can be modified.
 """
 
-from __future__ import absolute_import, division, print_function
-
 import contextlib
 import datetime
 import inspect
-import threading
+import os
 import warnings
 from enum import Enum, IntEnum, unique
+from typing import TYPE_CHECKING, Any, Collection, Dict, List, Optional, Union
 
 import attr
 
@@ -37,25 +34,20 @@ from hypothesis.errors import (
     InvalidArgument,
     InvalidState,
 )
-from hypothesis.internal.compat import integer_types, quiet_raise, string_types
-from hypothesis.internal.reflection import get_pretty_function_description, proxies
+from hypothesis.internal.reflection import get_pretty_function_description
 from hypothesis.internal.validation import check_type, try_convert
-from hypothesis.utils.conventions import UniqueIdentifier, not_set
+from hypothesis.utils.conventions import not_set
 from hypothesis.utils.dynamicvariables import DynamicVariable
 
-if False:
-    from typing import Any, Dict, List  # noqa
+if TYPE_CHECKING:
+    from hypothesis.database import ExampleDatabase
 
 __all__ = ["settings"]
 
-
-unlimited = UniqueIdentifier("unlimited")
-
-
 all_settings = {}  # type: Dict[str, Setting]
 
 
-class settingsProperty(object):
+class settingsProperty:
     def __init__(self, name, show_default):
         self.name = name
         self.show_default = show_default
@@ -75,7 +67,7 @@ class settingsProperty(object):
                     result = ExampleDatabase(not_set)
                 return result
             except KeyError:
-                raise AttributeError(self.name)
+                raise AttributeError(self.name) from None
 
     def __set__(self, obj, value):
         obj.__dict__[self.name] = value
@@ -86,19 +78,12 @@ class settingsProperty(object):
     @property
     def __doc__(self):
         description = all_settings[self.name].description
-        deprecation_message = all_settings[self.name].deprecation_message
         default = (
             repr(getattr(settings.default, self.name))
             if self.show_default
             else "(dynamically calculated)"
         )
-        return "\n\n".join(
-            [
-                description,
-                "default value: ``%s``" % (default,),
-                (deprecation_message or "").strip(),
-            ]
-        ).strip()
+        return "%s\n\ndefault value: ``%s``" % (description, default)
 
 
 default_variable = DynamicVariable(None)
@@ -106,7 +91,7 @@ default_variable = DynamicVariable(None)
 
 class settingsMeta(type):
     def __init__(self, *args, **kwargs):
-        super(settingsMeta, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     @property
     def default(self):
@@ -137,7 +122,7 @@ class settingsMeta(type):
         return type.__setattr__(self, name, value)
 
 
-class settings(settingsMeta("settings", (object,), {})):  # type: ignore
+class settings(metaclass=settingsMeta):
     """A settings object controls a variety of parameters that are used in
     falsification. These may control both the falsification strategy and the
     details of the data that is generated.
@@ -146,7 +131,6 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
     changes made there will be picked up in newly created settings.
     """
 
-    _WHITELISTED_REAL_PROPERTIES = ["_construction_complete", "storage"]
     __definitions_are_locked = False
     _profiles = {}  # type: dict
     __module__ = "hypothesis"
@@ -157,42 +141,45 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
         else:
             raise AttributeError("settings has no attribute %s" % (name,))
 
-    def __init__(self, parent=None, **kwargs):
-        # type: (settings, **Any) -> None
-        if kwargs.get("derandomize"):
-            if kwargs.get("database") is not None:
+    def __init__(
+        self,
+        parent: Optional["settings"] = None,
+        *,
+        # This looks pretty strange, but there's good reason: we want Mypy to detect
+        # bad calls downstream, but not to freak out about the `= not_set` part even
+        # though it's not semantically valid to pass that as an argument value.
+        # The intended use is "like **kwargs, but more tractable for tooling".
+        max_examples: int = not_set,  # type: ignore
+        derandomize: bool = not_set,  # type: ignore
+        database: Union[None, "ExampleDatabase"] = not_set,  # type: ignore
+        verbosity: "Verbosity" = not_set,  # type: ignore
+        phases: Collection["Phase"] = not_set,  # type: ignore
+        stateful_step_count: int = not_set,  # type: ignore
+        report_multiple_bugs: bool = not_set,  # type: ignore
+        suppress_health_check: Collection["HealthCheck"] = not_set,  # type: ignore
+        deadline: Union[None, int, float, datetime.timedelta] = not_set,  # type: ignore
+        print_blob: bool = not_set,  # type: ignore
+    ) -> None:
+        if parent is not None:
+            check_type(settings, parent, "parent")
+        if derandomize not in (not_set, False):
+            if database not in (not_set, None):
                 raise InvalidArgument(
                     "derandomize=True implies database=None, so passing "
-                    "database=%r too is invalid." % (kwargs["database"],)
+                    f"database={database!r} too is invalid."
                 )
-            kwargs["database"] = None
-        self._construction_complete = False
-        deprecations = []
+            database = None
+
         defaults = parent or settings.default
         if defaults is not None:
             for setting in all_settings.values():
-                if kwargs.get(setting.name, not_set) is not_set:
-                    kwargs[setting.name] = getattr(defaults, setting.name)
+                value = locals()[setting.name]
+                if value is not_set:
+                    object.__setattr__(
+                        self, setting.name, getattr(defaults, setting.name)
+                    )
                 else:
-                    if setting.validator:
-                        kwargs[setting.name] = setting.validator(kwargs[setting.name])
-                    if setting.deprecation_message is not None:
-                        deprecations.append(setting)
-        for name, value in kwargs.items():
-            if name not in all_settings:
-                raise InvalidArgument(
-                    "Invalid argument: %r is not a valid setting" % (name,)
-                )
-            setattr(self, name, value)
-        self.storage = threading.local()
-        self._construction_complete = True
-
-        for d in deprecations:
-            note_deprecation(
-                d.deprecation_message,
-                since=d.deprecated_since,
-                verbosity=self.verbosity,
-            )
+                    object.__setattr__(self, setting.name, setting.validator(value))
 
     def __call__(self, test):
         """Make the settings object (self) an attribute of the test.
@@ -205,9 +192,9 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
                 "but decorated test=%r is not callable." % (test,)
             )
         if inspect.isclass(test):
-            from hypothesis.stateful import GenericStateMachine
+            from hypothesis.stateful import RuleBasedStateMachine
 
-            if issubclass(test, GenericStateMachine):
+            if issubclass(test, RuleBasedStateMachine):
                 attr_name = "_hypothesis_internal_settings_applied"
                 if getattr(test, attr_name, False):
                     raise InvalidArgument(
@@ -221,7 +208,7 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
             else:
                 raise InvalidArgument(
                     "@settings(...) can only be used as a decorator on "
-                    "functions, or on subclasses of GenericStateMachine."
+                    "functions, or on subclasses of RuleBasedStateMachine."
                 )
         if hasattr(test, "_hypothesis_internal_settings_applied"):
             # Can't use _hypothesis_internal_use_settings as an indicator that
@@ -238,25 +225,7 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
 
         test._hypothesis_internal_use_settings = self
         test._hypothesis_internal_settings_applied = True
-        if getattr(test, "is_hypothesis_test", False):
-            return test
-
-        @proxies(test)
-        def new_test(*args, **kwargs):
-            """@given has not been applied to `test`, so we replace it with this
-            wrapper so that using *only* @settings is an error.
-
-            We then attach the actual test as an attribute of this function, so
-            that we can unwrap it if @given is applied after the settings decorator.
-            """
-            raise InvalidArgument(
-                "Using `@settings` on a test without `@given` is completely pointless."
-            )
-
-        new_test._hypothesis_internal_test_function_without_warning = test
-        new_test._hypothesis_internal_use_settings = self
-        new_test._hypothesis_internal_settings_applied = True
-        return new_test
+        return test
 
     @classmethod
     def _define_setting(
@@ -267,8 +236,6 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
         options=None,
         validator=None,
         show_default=True,
-        deprecation_message=None,
-        deprecated_since=None,
     ):
         """Add a new setting.
 
@@ -286,6 +253,13 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
         if options is not None:
             options = tuple(options)
             assert default in options
+
+            def validator(value):
+                if value not in options:
+                    msg = f"Invalid {name}, {value!r}. Valid options: {options!r}"
+                    raise InvalidArgument(msg)
+                return value
+
         else:
             assert validator is not None
 
@@ -293,10 +267,7 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
             name=name,
             description=description.strip(),
             default=default,
-            options=options,
             validator=validator,
-            deprecation_message=deprecation_message,
-            deprecated_since=deprecated_since,
         )
         setattr(settings, name, settingsProperty(name, show_default))
 
@@ -305,33 +276,10 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
         settings.__definitions_are_locked = True
 
     def __setattr__(self, name, value):
-        if name in settings._WHITELISTED_REAL_PROPERTIES:
-            return object.__setattr__(self, name, value)
-        elif name in all_settings:
-            if self._construction_complete:
-                raise AttributeError(
-                    "settings objects are immutable and may not be assigned to"
-                    " after construction."
-                )
-            else:
-                setting = all_settings[name]
-                if setting.options is not None and value not in setting.options:
-                    raise InvalidArgument(
-                        "Invalid %s, %r. Valid options: %r"
-                        % (name, value, setting.options)
-                    )
-                return object.__setattr__(self, name, value)
-        else:
-            raise AttributeError("No such setting %s" % (name,))
+        raise AttributeError("settings objects are immutable")
 
     def __repr__(self):
-        bits = []
-        for name, setting in all_settings.items():
-            value = getattr(self, name)
-            # The only settings that are not shown are those that are
-            # deprecated and left at their default values.
-            if value != setting.default or not setting.deprecation_message:
-                bits.append("%s=%r" % (name, value))
+        bits = ("%s=%r" % (name, getattr(self, name)) for name in all_settings)
         return "settings(%s)" % ", ".join(sorted(bits))
 
     def show_changed(self):
@@ -343,8 +291,11 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
         return ", ".join(sorted(bits, key=len))
 
     @staticmethod
-    def register_profile(name, parent=None, **kwargs):
-        # type: (str, settings, **Any) -> None
+    def register_profile(
+        name: str,
+        parent: Optional["settings"] = None,
+        **kwargs: Any,
+    ) -> None:
         """Registers a collection of values to be used as a settings profile.
 
         Settings profiles can be loaded by name - for example, you might
@@ -357,29 +308,27 @@ class settings(settingsMeta("settings", (object,), {})):  # type: ignore
         keyword arguments for each setting that will be set differently to
         parent (or settings.default, if parent is None).
         """
-        check_type(string_types, name, "name")
+        check_type(str, name, "name")
         settings._profiles[name] = settings(parent=parent, **kwargs)
 
     @staticmethod
-    def get_profile(name):
-        # type: (str) -> settings
+    def get_profile(name: str) -> "settings":
         """Return the profile with the given name."""
-        check_type(string_types, name, "name")
+        check_type(str, name, "name")
         try:
             return settings._profiles[name]
         except KeyError:
-            raise InvalidArgument("Profile %r is not registered" % (name,))
+            raise InvalidArgument(f"Profile {name!r} is not registered") from None
 
     @staticmethod
-    def load_profile(name):
-        # type: (str) -> None
+    def load_profile(name: str) -> None:
         """Loads in the settings defined in the profile provided.
 
         If the profile does not exist, InvalidArgument will be raised.
         Any setting not defined in the profile will be the library
         defined default for that setting.
         """
-        check_type(string_types, name, "name")
+        check_type(str, name, "name")
         settings._current_profile = name
         settings._assign_default_internal(settings.get_profile(name))
 
@@ -392,34 +341,19 @@ def local_settings(s):
 
 
 @attr.s()
-class Setting(object):
+class Setting:
     name = attr.ib()
     description = attr.ib()
     default = attr.ib()
-    options = attr.ib()
     validator = attr.ib()
-    deprecation_message = attr.ib()
-    deprecated_since = attr.ib()
-
-
-def _ensure_positive_int(x, name, since, min_value=0):
-    if not isinstance(x, integer_types):
-        note_deprecation(
-            "Passing non-integer %s=%r is deprecated" % (name, x), since=since
-        )
-    x = try_convert(int, x, name)
-    if x < min_value:
-        raise InvalidArgument("%s=%r must be at least %r." % (name, x, min_value))
-    return x
 
 
 def _max_examples_validator(x):
-    x = _ensure_positive_int(x, "max_examples", since="2019-03-06", min_value=0)
-    if x == 0:
-        note_deprecation(
+    check_type(int, x, name="max_examples")
+    if x < 1:
+        raise InvalidArgument(
             "max_examples=%r should be at least one. You can disable example "
-            "generation with the `phases` setting instead." % (x,),
-            since="2019-03-06",
+            "generation with the `phases` setting instead." % (x,)
         )
     return x
 
@@ -440,47 +374,27 @@ If you are writing one-off tests, running tens of thousands of examples is
 quite reasonable as Hypothesis may miss uncommon bugs with default settings.
 For very complex code, we have observed Hypothesis finding novel bugs after
 *several million* examples while testing :pypi:`SymPy`.
+If you are running more than 100k examples for a test, consider using our
+:ref:`integration for coverage-guided fuzzing <fuzz_one_input>` - it really
+shines when given minutes or hours to run.
 """,
 )
 
-settings._define_setting(
-    "buffer_size",
-    default=not_set,
-    validator=lambda x: _ensure_positive_int(x, "buffer_size", since="2019-03-06"),
-    description="The buffer_size setting has been deprecated and no longer does anything.",
-    deprecation_message="The buffer_size setting can safely be removed with no effect.",
-    deprecated_since="2019-07-03",
-)
-
-
-settings._define_setting(
-    "timeout",
-    default=not_set,
-    description="The timeout setting has been deprecated and no longer does anything.",
-    deprecation_message="The timeout setting can safely be removed with no effect.",
-    deprecated_since="2017-11-02",
-    options=(not_set, unlimited),
-)
-
-
-def _derandomize_validator(x):
-    if not isinstance(x, bool):
-        note_deprecation("derandomize=%r should be a bool." % (x,), since="2019-03-06")
-    return bool(x)
-
 
 settings._define_setting(
     "derandomize",
     default=False,
-    validator=_derandomize_validator,
+    options=(True, False),
     description="""
-If this is True then hypothesis will run in deterministic mode
-where each falsification uses a random number generator that is seeded
-based on the hypothesis to falsify, which will be consistent across
-multiple runs. This has the advantage that it will eliminate any
-randomness from your tests, which may be preferable for some situations.
-It does have the disadvantage of making your tests less likely to
-find novel breakages.
+If True, seed Hypothesis' random number generator using a hash of the test
+function, so that every run will test the same set of examples until you
+update Hypothesis, Python, or the test function.
+
+This allows you to `check for regressions and look for bugs
+<https://blog.nelhage.com/post/two-kinds-of-testing/>`__ using
+:ref:`separate settings profiles <settings_profiles>` - for example running
+quick deterministic tests on every commit, and a longer non-deterministic
+nightly testing run.
 """,
 )
 
@@ -503,7 +417,7 @@ settings._define_setting(
     default=not_set,
     show_default=False,
     description="""
-An instance of hypothesis.database.ExampleDatabase that will be
+An instance of :class:`~hypothesis.database.ExampleDatabase` that will be
 used to save examples to and load previous examples from. May be ``None``
 in which case no storage will be used, ``":memory:"`` for an in-memory
 database, or any path for a directory-based example database.
@@ -517,7 +431,8 @@ class Phase(IntEnum):
     explicit = 0
     reuse = 1
     generate = 2
-    shrink = 3
+    target = 3
+    shrink = 4
 
     def __repr__(self):
         return "Phase.%s" % (self.name,)
@@ -534,10 +449,8 @@ class HealthCheck(Enum):
         return "%s.%s" % (self.__class__.__name__, self.name)
 
     @classmethod
-    def all(cls):
-        # type: () -> List[HealthCheck]
-        deprecated = [HealthCheck.hung_test]
-        return [x for x in list(HealthCheck) if x not in deprecated]
+    def all(cls) -> List["HealthCheck"]:
+        return list(HealthCheck)
 
     data_too_large = 1
     """Check for when the typical size of the examples you are generating
@@ -556,11 +469,6 @@ class HealthCheck(Enum):
     """Checks if your tests return a non-None value (which will be ignored and
     is unlikely to do what you want)."""
 
-    hung_test = 6
-    """This health check is deprecated and no longer has any effect.
-    You can use the ``max_examples`` and ``deadline`` settings together to cap
-    the total runtime of your tests, rather than the previous fixed limit."""
-
     large_base_example = 7
     """Checks if the natural example to shrink towards is very large."""
 
@@ -589,9 +497,6 @@ settings._define_setting(
 
 
 def _validate_phases(phases):
-    if phases is None:
-        phases = tuple(Phase)
-        note_deprecation("Use phases=%r, not None." % (phases,), since="2019-08-05")
     phases = tuple(phases)
     for a in phases:
         if not isinstance(a, Phase):
@@ -609,10 +514,18 @@ settings._define_setting(
     validator=_validate_phases,
 )
 
+
+def _validate_stateful_step_count(x):
+    check_type(int, x, name="stateful_step_count")
+    if x < 1:
+        raise InvalidArgument("stateful_step_count=%r must be at least one." % (x,))
+    return x
+
+
 settings._define_setting(
     name="stateful_step_count",
     default=50,
-    validator=lambda x: _ensure_positive_int(x, "stateful_step_count", "2019-03-06"),
+    validator=_validate_stateful_step_count,
     description="""
 Number of steps to run a stateful program for before giving up on it breaking.
 """,
@@ -639,12 +552,6 @@ def validate_health_check_suppressions(suppressions):
                 "Non-HealthCheck value %r of type %s is invalid in suppress_health_check."
                 % (s, type(s).__name__)
             )
-        if s is HealthCheck.hung_test:
-            note_deprecation(
-                "HealthCheck.hung_test is deprecated and has no "
-                "effect, as we no longer run this health check.",
-                since="2019-01-24",
-            )
     return suppressions
 
 
@@ -665,24 +572,23 @@ class duration(datetime.timedelta):
 
 
 def _validate_deadline(x):
-    if isinstance(x, bool):
-        note_deprecation(
-            "The deadline=%r must be a duration in milliseconds, or None to disable."
-            "  Boolean deadlines are treated as ints, and deprecated." % (x,),
-            since="2019-03-06",
-        )
     if x is None:
         return x
-    if isinstance(x, integer_types + (float,)):
+    invalid_deadline_error = InvalidArgument(
+        "deadline=%r (type %s) must be a timedelta object, an integer or float "
+        "number of milliseconds, or None to disable the per-test-case deadline."
+        % (x, type(x).__name__)
+    )
+    if isinstance(x, (int, float)):
+        if isinstance(x, bool):
+            raise invalid_deadline_error
         try:
             x = duration(milliseconds=x)
         except OverflowError:
-            quiet_raise(
-                InvalidArgument(
-                    "deadline=%r is invalid, because it is too large to represent "
-                    "as a timedelta. Use deadline=None to disable deadlines." % (x,)
-                )
-            )
+            raise InvalidArgument(
+                "deadline=%r is invalid, because it is too large to represent "
+                "as a timedelta. Use deadline=None to disable deadlines." % (x,)
+            ) from None
     if isinstance(x, datetime.timedelta):
         if x <= datetime.timedelta(0):
             raise InvalidArgument(
@@ -690,17 +596,14 @@ def _validate_deadline(x):
                 "deadline <= 0. Use deadline=None to disable deadlines." % (x,)
             )
         return duration(seconds=x.total_seconds())
-    raise InvalidArgument(
-        "deadline=%r (type %s) must be a timedelta object, an integer or float number of milliseconds, "
-        "or None to disable the per-test-case deadline." % (x, type(x).__name__)
-    )
+    raise invalid_deadline_error
 
 
 settings._define_setting(
     "deadline",
     default=duration(milliseconds=200),
     validator=_validate_deadline,
-    description=u"""
+    description="""
 If set, a duration (as timedelta, or integer or float number of milliseconds)
 that each individual example (i.e. each time your test
 function is called, not the whole decorated test) within a test is not
@@ -708,72 +611,49 @@ allowed to exceed. Tests which take longer than that may be converted into
 errors (but will not necessarily be if close to the deadline, to allow some
 variability in test run time).
 
-Set this to None to disable this behaviour entirely.
+Set this to ``None`` to disable this behaviour entirely.
 """,
 )
 
 
-class PrintSettings(Enum):
-    """Flags to determine whether or not to print a detailed example blob to
-    use with :func:`~hypothesis.reproduce_failure` for failing test cases."""
-
-    NEVER = 0
-    """Never print a blob."""
-
-    INFER = 1
-    """This option is deprecated and will be treated as equivalent to
-    ALWAYS."""
-
-    ALWAYS = 2
-    """Always print a blob on failure."""
-
-    def __repr__(self):
-        return "PrintSettings.%s" % (self.name,)
-
-
-def _validate_print_blob(value):
-    if isinstance(value, PrintSettings):
-        replacement = value != PrintSettings.NEVER
-
-        note_deprecation(
-            "Setting print_blob=%r is deprecated and will become an error "
-            "in a future version of Hypothesis. Use print_blob=%r instead."
-            % (value, replacement),
-            since="2018-09-30",
-        )
-        return replacement
-
-    check_type(bool, value, "print_blob")
-
-    return value
+def is_in_ci() -> bool:
+    # GitHub Actions, Travis CI and AppVeyor have "CI"
+    # Azure Pipelines has "TF_BUILD"
+    return "CI" in os.environ or "TF_BUILD" in os.environ
 
 
 settings._define_setting(
     "print_blob",
-    default=False,
+    default=is_in_ci(),
+    show_default=False,
+    options=(True, False),
     description="""
-If set to True, Hypothesis will print code for failing examples that can be used with
+If set to ``True``, Hypothesis will print code for failing examples that can be used with
 :func:`@reproduce_failure <hypothesis.reproduce_failure>` to reproduce the failing example.
+The default is ``True`` if the ``CI`` or ``TF_BUILD`` env vars are set, ``False`` otherwise.
 """,
-    validator=_validate_print_blob,
 )
 
 settings.lock_further_definitions()
 
 
-def note_deprecation(message, since, verbosity=None):
-    # type: (str, str, Verbosity) -> None
-    if verbosity is None:
-        verbosity = settings.default.verbosity
-    assert verbosity is not None
+def note_deprecation(message: str, *, since: str) -> None:
     if since != "RELEASEDAY":
         date = datetime.datetime.strptime(since, "%Y-%m-%d").date()
         assert datetime.date(2016, 1, 1) <= date
-    warning = HypothesisDeprecationWarning(message)
-    if verbosity > Verbosity.quiet:
-        warnings.warn(warning, stacklevel=2)
+    warnings.warn(HypothesisDeprecationWarning(message), stacklevel=2)
 
 
 settings.register_profile("default", settings())
 settings.load_profile("default")
 assert settings.default is not None
+
+
+# Check that the kwonly args to settings.__init__ is the same as the set of
+# defined settings - in case we've added or remove something from one but
+# not the other.
+assert set(all_settings) == {
+    p.name
+    for p in inspect.signature(settings.__init__).parameters.values()
+    if p.kind == inspect.Parameter.KEYWORD_ONLY
+}
