@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,33 +13,22 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
+import time
 from collections import defaultdict
 from enum import IntEnum
 
 import attr
 
 from hypothesis.errors import Frozen, InvalidArgument, StopTest
-from hypothesis.internal.compat import (
-    benchmark_time,
-    bit_length,
-    hbytes,
-    hrange,
-    int_from_bytes,
-    int_to_bytes,
-    text_type,
-    unicode_safe_repr,
-)
-from hypothesis.internal.conjecture.junkdrawer import IntList
+from hypothesis.internal.compat import bit_length, int_from_bytes, int_to_bytes
+from hypothesis.internal.conjecture.junkdrawer import IntList, uniform
 from hypothesis.internal.conjecture.utils import calc_label_from_name
-from hypothesis.internal.escalation import mark_for_escalation
 
 TOP_LABEL = calc_label_from_name("top")
 DRAW_BYTES_LABEL = calc_label_from_name("draw_bytes() in ConjectureData")
 
 
-class ExtraInformation(object):
+class ExtraInformation:
     """A class for holding shared state on a ``ConjectureData`` that should
     be added to the final ``ConjectureResult``."""
 
@@ -64,7 +51,22 @@ class Status(IntEnum):
         return "Status.%s" % (self.name,)
 
 
-class Example(object):
+@attr.s(frozen=True, slots=True)
+class StructuralCoverageTag:
+    label = attr.ib()
+
+
+STRUCTURAL_COVERAGE_CACHE = {}
+
+
+def structural_coverage(label):
+    try:
+        return STRUCTURAL_COVERAGE_CACHE[label]
+    except KeyError:
+        return STRUCTURAL_COVERAGE_CACHE.setdefault(label, StructuralCoverageTag(label))
+
+
+class Example:
     """Examples track the hierarchical structure of draws from the byte stream,
     within a single test run.
 
@@ -177,9 +179,9 @@ class Example(object):
         return [self.owner[i] for i in self.owner.children[self.index]]
 
 
-class ExampleProperty(object):
+class ExampleProperty:
     """There are many properties of examples that we calculate by
-    essentially rerunning thet test case multiple times based on the
+    essentially rerunning the test case multiple times based on the
     calls which we record in ExampleRecord.
 
     This class defines a visitor, subclasses of which can be used
@@ -238,7 +240,7 @@ class ExampleProperty(object):
 
     def block(self, i):
         """Called with each ``draw_bits`` call, with ``i`` the index of the
-        corresonding block in ``self.examples.blocks``"""
+        corresponding block in ``self.examples.blocks``"""
 
     def stop_example(self, i, discarded):
         """Called at the end of each example, with ``i`` the
@@ -278,7 +280,7 @@ STOP_EXAMPLE_NO_DISCARD_RECORD = 2
 START_EXAMPLE_RECORD = 3
 
 
-class ExampleRecord(object):
+class ExampleRecord:
     """Records the series of ``start_example``, ``stop_example``, and
     ``draw_bits`` calls so that these may be stored in ``Examples`` and
     replayed when we need to know about the structure of individual
@@ -315,7 +317,7 @@ class ExampleRecord(object):
         self.trail.append(DRAW_BITS_RECORD)
 
 
-class Examples(object):
+class Examples:
     """A lazy collection of ``Example`` objects, derived from
     the record of recorded behaviour in ``ExampleRecord``.
 
@@ -413,10 +415,24 @@ class Examples(object):
         def start_example(self, i, label_index):
             self.result[i] = label_index
 
+    @calculated_example_property
+    class mutator_groups(ExampleProperty):
+        def begin(self):
+            self.groups = defaultdict(list)
+
+        def start_example(self, i, label_index):
+            depth = len(self.example_stack)
+            self.groups[label_index, depth].append(i)
+
+        def finish(self):
+            # Discard groups with only one example, since the mutator can't
+            # do anything useful with them.
+            return [g for g in self.groups.values() if len(g) >= 2]
+
     @property
     def children(self):
         if self.__children is None:
-            self.__children = [IntList() for _ in hrange(len(self))]
+            self.__children = [IntList() for _ in range(len(self))]
             for i, p in enumerate(self.parentage):
                 if i > 0:
                     self.__children[p].append(i)
@@ -441,7 +457,7 @@ class Examples(object):
 
 
 @attr.s(slots=True, frozen=True)
-class Block(object):
+class Block:
     """Blocks track the flat list of lowest-level draws from the byte stream,
     within a single test run.
 
@@ -478,7 +494,7 @@ class Block(object):
         return self.forced or self.all_zero
 
 
-class Blocks(object):
+class Blocks:
     """A lazily calculated list of blocks for a particular ``ConjectureResult``
     or ``ConjectureData`` object.
 
@@ -634,12 +650,12 @@ class Blocks(object):
             self.owner = None
 
     def __iter__(self):
-        for i in hrange(len(self)):
+        for i in range(len(self)):
             yield self[i]
 
     def __repr__(self):
         parts = []
-        for i in hrange(len(self)):
+        for i in range(len(self)):
             b = self.__known_block(i)
             if b is None:
                 parts.append("...")
@@ -648,12 +664,15 @@ class Blocks(object):
         return "Block([%s])" % (", ".join(parts),)
 
 
-class _Overrun(object):
+class _Overrun:
     status = Status.OVERRUN
 
     def __repr__(self):
         return "Overrun"
 
+    def as_result(self):
+        return self
+
 
 Overrun = _Overrun()
 
@@ -663,7 +682,7 @@ global_test_counter = 0
 MAX_DEPTH = 100
 
 
-class DataObserver(object):
+class DataObserver:
     """Observer class for recording the behaviour of a
     ConjectureData object, primarily used for tracking
     the behaviour in the tree cache."""
@@ -684,9 +703,12 @@ class DataObserver(object):
         * ``value`` is the result that ``draw_bits`` returned.
         """
 
+    def kill_branch(self):
+        """Mark this part of the tree as not worth re-exploring."""
+
 
 @attr.s(slots=True)
-class ConjectureResult(object):
+class ConjectureResult:
     """Result class storing the parts of ConjectureData that we
     will care about after the original ConjectureData has outlived its
     usefulness."""
@@ -698,6 +720,8 @@ class ConjectureResult(object):
     output = attr.ib()
     extra_information = attr.ib()
     has_discards = attr.ib()
+    target_observations = attr.ib()
+    tags = attr.ib()
     forced_indices = attr.ib(repr=False)
     examples = attr.ib(repr=False)
 
@@ -707,55 +731,67 @@ class ConjectureResult(object):
         self.index = len(self.buffer)
         self.forced_indices = frozenset(self.forced_indices)
 
+    def as_result(self):
+        return self
+
 
 # Masks for masking off the first byte of an n-bit buffer.
 # The appropriate mask is stored at position n % 8.
-BYTE_MASKS = [(1 << n) - 1 for n in hrange(8)]
+BYTE_MASKS = [(1 << n) - 1 for n in range(8)]
 BYTE_MASKS[0] = 255
 
 
-class ConjectureData(object):
+class ConjectureData:
     @classmethod
     def for_buffer(self, buffer, observer=None):
-        buffer = hbytes(buffer)
         return ConjectureData(
-            max_length=len(buffer),
-            draw_bytes=lambda data, n: hbytes(buffer[data.index : data.index + n]),
-            observer=observer,
+            prefix=buffer, max_length=len(buffer), random=None, observer=observer
         )
 
-    def __init__(self, max_length, draw_bytes, observer=None):
+    def __init__(self, max_length, prefix, random, observer=None):
         if observer is None:
             observer = DataObserver()
         assert isinstance(observer, DataObserver)
+        self.__bytes_drawn = 0
         self.observer = observer
         self.max_length = max_length
         self.is_find = False
-        self._draw_bytes = draw_bytes
         self.overdraw = 0
         self.__block_starts = defaultdict(list)
         self.__block_starts_calculated_to = 0
+        self.__prefix = prefix
+        self.__random = random
+
+        assert random is not None or max_length <= len(prefix)
 
         self.blocks = Blocks(self)
         self.buffer = bytearray()
         self.index = 0
-        self.output = u""
+        self.output = ""
         self.status = Status.VALID
         self.frozen = False
         global global_test_counter
         self.testcounter = global_test_counter
         global_test_counter += 1
-        self.start_time = benchmark_time()
+        self.start_time = time.perf_counter()
         self.events = set()
         self.forced_indices = set()
         self.interesting_origin = None
         self.draw_times = []
         self.max_depth = 0
         self.has_discards = False
-        self.consecutive_discard_counts = []
 
         self.__result = None
 
+        # Observations used for targeted search.  They'll be aggregated in
+        # ConjectureRunner.generate_new_examples and fed to TargetSelector.
+        self.target_observations = {}
+
+        # Tags which indicate something about which part of the search space
+        # this example is in. These are used to guide generation.
+        self.tags = set()
+        self.labels_for_structure_stack = []
+
         # Normally unpopulated but we need this in the niche case
         # that self.as_result() is Overrun but we still want the
         # examples for reporting purposes.
@@ -796,6 +832,8 @@ class ConjectureData(object):
                 if self.extra_information.has_information()
                 else None,
                 has_discards=self.has_discards,
+                target_observations=self.target_observations,
+                tags=frozenset(self.tags),
                 forced_indices=self.forced_indices,
             )
             self.blocks.transfer_ownership(self.__result)
@@ -807,8 +845,8 @@ class ConjectureData(object):
 
     def note(self, value):
         self.__assert_not_frozen("note")
-        if not isinstance(value, text_type):
-            value = unicode_safe_repr(value)
+        if not isinstance(value, str):
+            value = repr(value)
         self.output += value
 
     def draw(self, strategy, label=None):
@@ -821,16 +859,22 @@ class ConjectureData(object):
                 % (strategy,)
             )
 
+        at_top_level = self.depth == 0
+        if at_top_level:
+            # We start this timer early, because accessing attributes on a LazyStrategy
+            # can be almost arbitrarily slow.  In cases like characters() and text()
+            # where we cache something expensive, this led to Flaky deadline errors!
+            # See https://github.com/HypothesisWorks/hypothesis/issues/2108
+            start_time = time.perf_counter()
+
+        strategy.validate()
+
         if strategy.is_empty:
             self.mark_invalid()
 
         if self.depth >= MAX_DEPTH:
             self.mark_invalid()
 
-        return self.__draw(strategy, label=label)
-
-    def __draw(self, strategy, label):
-        at_top_level = self.depth == 0
         if label is None:
             label = strategy.label
         self.start_example(label=label)
@@ -838,16 +882,11 @@ class ConjectureData(object):
             if not at_top_level:
                 return strategy.do_draw(self)
             else:
+                strategy.validate()
                 try:
-                    strategy.validate()
-                    start_time = benchmark_time()
-                    try:
-                        return strategy.do_draw(self)
-                    finally:
-                        self.draw_times.append(benchmark_time() - start_time)
-                except BaseException as e:
-                    mark_for_escalation(e)
-                    raise
+                    return strategy.do_draw(self)
+                finally:
+                    self.draw_times.append(time.perf_counter() - start_time)
         finally:
             self.stop_example()
 
@@ -863,34 +902,51 @@ class ConjectureData(object):
         if self.depth > self.max_depth:
             self.max_depth = self.depth
         self.__example_record.start_example(label)
-        self.consecutive_discard_counts.append(0)
+        self.labels_for_structure_stack.append({label})
 
     def stop_example(self, discard=False):
         if self.frozen:
             return
-        self.consecutive_discard_counts.pop()
         if discard:
             self.has_discards = True
         self.depth -= 1
         assert self.depth >= -1
         self.__example_record.stop_example(discard)
-        if self.consecutive_discard_counts:
-            # We block long sequences of discards. This helps us avoid performance
-            # problems where there is rejection sampling. In particular tests which
-            # have a very small actual state space but use rejection sampling will
-            # play badly with generate_novel_prefix() in DataTree, and will end up
-            # generating very long tests with long runs of the rejection sample.
-            if discard:
-                self.consecutive_discard_counts[-1] += 1
-                # 20 is a fairly arbitrary limit chosen mostly so that all of the
-                # existing tests passed under it. Essentially no reasonable
-                # generation should hit this limit when running in purely random
-                # mode, but unreasonable generation is fairly widespread, and our
-                # manipulation of the bitstream can make it more likely.
-                if self.consecutive_discard_counts[-1] > 20:
-                    self.mark_invalid()
+
+        labels_for_structure = self.labels_for_structure_stack.pop()
+
+        if not discard:
+            if self.labels_for_structure_stack:
+                self.labels_for_structure_stack[-1].update(labels_for_structure)
             else:
-                self.consecutive_discard_counts[-1] = 0
+                self.tags.update([structural_coverage(l) for l in labels_for_structure])
+
+        if discard:
+            # Once we've discarded an example, every test case starting with
+            # this prefix contains discards. We prune the tree at that point so
+            # as to avoid future test cases bothering with this region, on the
+            # assumption that some example that you could have used instead
+            # there would *not* trigger the discard. This greatly speeds up
+            # test case generation in some cases, because it allows us to
+            # ignore large swathes of the search space that are effectively
+            # redundant.
+            #
+            # A scenario that can cause us problems but which we deliberately
+            # have decided not to support is that if there are side effects
+            # during data generation then you may end up with a scenario where
+            # every good test case generates a discard because the discarded
+            # section sets up important things for later. This is not terribly
+            # likely and all that you see in this case is some degradation in
+            # quality of testing, so we don't worry about it.
+            #
+            # Note that killing the branch does *not* mean we will never
+            # explore below this point, and in particular we may do so during
+            # shrinking. Any explicit request for a data object that starts
+            # with the branch here will work just fine, but novel prefix
+            # generation will avoid it, and we can use it to detect when we
+            # have explored the entire tree (up to redundancy).
+
+            self.observer.kill_branch()
 
     def note_event(self, event):
         self.events.add(event)
@@ -904,9 +960,9 @@ class ConjectureData(object):
 
     def freeze(self):
         if self.frozen:
-            assert isinstance(self.buffer, hbytes)
+            assert isinstance(self.buffer, bytes)
             return
-        self.finish_time = benchmark_time()
+        self.finish_time = time.perf_counter()
         assert len(self.buffer) == self.index
 
         # Always finish by closing all remaining examples so that we have a
@@ -918,12 +974,11 @@ class ConjectureData(object):
 
         self.frozen = True
 
-        self.buffer = hbytes(self.buffer)
+        self.buffer = bytes(self.buffer)
         self.events = frozenset(self.events)
-        del self._draw_bytes
         self.observer.conclude_test(self.status, self.interesting_origin)
 
-    def draw_bits(self, n, forced=None):
+    def draw_bits(self, n, *, forced=None):
         """Return an ``n``-bit integer from the underlying source of
         bytes. If ``forced`` is set to an integer will instead
         ignore the underlying source and simulate a draw as if it had
@@ -936,15 +991,23 @@ class ConjectureData(object):
         self.__check_capacity(n_bytes)
 
         if forced is not None:
-            buf = bytearray(int_to_bytes(forced, n_bytes))
+            buf = int_to_bytes(forced, n_bytes)
+        elif self.__bytes_drawn < len(self.__prefix):
+            index = self.__bytes_drawn
+            buf = self.__prefix[index : index + n_bytes]
+            if len(buf) < n_bytes:
+                buf += uniform(self.__random, n_bytes - len(buf))
         else:
-            buf = bytearray(self._draw_bytes(self, n_bytes))
+            buf = uniform(self.__random, n_bytes)
+        buf = bytearray(buf)
+        self.__bytes_drawn += n_bytes
+
         assert len(buf) == n_bytes
 
         # If we have a number of bits that is not a multiple of 8
         # we have to mask off the high bits.
         buf[0] &= BYTE_MASKS[n % 8]
-        buf = hbytes(buf)
+        buf = bytes(buf)
         result = int_from_bytes(buf)
 
         self.observer.draw_bits(n, forced is not None, result)
@@ -956,22 +1019,13 @@ class ConjectureData(object):
         self.index = len(self.buffer)
 
         if forced is not None:
-            self.forced_indices.update(hrange(initial, self.index))
+            self.forced_indices.update(range(initial, self.index))
 
         self.blocks.add_endpoint(self.index)
 
         assert bit_length(result) <= n
         return result
 
-    @property
-    def block_starts(self):
-        while self.__block_starts_calculated_to < len(self.blocks):
-            i = self.__block_starts_calculated_to
-            self.__block_starts_calculated_to += 1
-            u, v = self.blocks.bounds(i)
-            self.__block_starts[v - u].append(u)
-        return self.__block_starts
-
     def draw_bytes(self, n):
         """Draw n bytes from the underlying source."""
         return int_to_bytes(self.draw_bits(8 * n), n)
@@ -979,7 +1033,7 @@ class ConjectureData(object):
     def write(self, string):
         """Write ``string`` to the output buffer."""
         self.__assert_not_frozen("write")
-        string = hbytes(string)
+        string = bytes(string)
         if not string:
             return
         self.draw_bits(len(string) * 8, forced=int_from_bytes(string))
