@@ -1336,7 +1336,7 @@ class Shrinker:
 
 def shrink_pass_family(f):
     def accept(*args):
-        name = "%s(%s)" % (f.__name__, ", ".join(map(repr, args)),)
+        name = "%s(%s)" % (f.__name__, ", ".join(map(repr, args)))
         if name not in SHRINK_PASS_DEFINITIONS:
 
             def run(self, chooser):
