@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -18,33 +16,29 @@
 """This file can approximately be considered the collection of hypothesis going
 to really unreasonable lengths to produce pretty output."""
 
-
-from __future__ import absolute_import, division, print_function
-
 import ast
 import hashlib
 import inspect
+import os
 import re
-import tokenize
 import types
-import uuid
 from functools import wraps
+from tokenize import detect_encoding
 from types import ModuleType
+from typing import Any, Callable, TypeVar
 
-from hypothesis.configuration import storage_directory
 from hypothesis.internal.compat import (
-    ARG_NAME_ATTRIBUTE,
-    getfullargspec,
-    hrange,
-    isidentifier,
+    is_typed_named_tuple,
     qualname,
     str_to_bytes,
-    to_str,
     to_unicode,
     update_code_location,
 )
 from hypothesis.vendor.pretty import pretty
 
+C = TypeVar("C", bound=Callable)
+READTHEDOCS = os.environ.get("READTHEDOCS", None) == "True"
+
 
 def fully_qualified_name(f):
     """Returns a unique identifier for f pointing to the module it was defined
@@ -56,17 +50,15 @@ def fully_qualified_name(f):
 
 
 def is_mock(obj):
-    """Determine if the given argument is a mock type.
+    """Determine if the given argument is a mock type."""
 
-    We want to be able to detect these when dealing with various test
-    args. As they are sneaky and can look like almost anything else,
-    we'll check this by looking for random attributes.  This is more
-    robust than looking for types.
-    """
-    for _ in range(10):
-        if not hasattr(obj, str(uuid.uuid4())):
-            return False
-    return True
+    # We want to be able to detect these when dealing with various test
+    # args. As they are sneaky and can look like almost anything else,
+    # we'll check this by looking for an attribute with a name that it's really
+    # unlikely to implement accidentally, and that anyone who implements it
+    # deliberately should know what they're doing. This is more robust than
+    # looking for types.
+    return hasattr(obj, "hypothesis_internal_is_this_a_mock_check")
 
 
 def function_digest(function):
@@ -76,11 +68,10 @@ def function_digest(function):
 
     No guarantee of uniqueness though it usually will be.
     """
-    hasher = hashlib.md5()
+    hasher = hashlib.sha384()
     try:
         hasher.update(to_unicode(inspect.getsource(function)).encode("utf-8"))
-    # Different errors on different versions of python. What fun.
-    except (OSError, IOError, TypeError):
+    except (OSError, TypeError):
         pass
     try:
         hasher.update(str_to_bytes(function.__name__))
@@ -91,7 +82,7 @@ def function_digest(function):
     except AttributeError:
         pass
     try:
-        hasher.update(str_to_bytes(repr(getfullargspec(function))))
+        hasher.update(str_to_bytes(repr(inspect.getfullargspec(function))))
     except TypeError:
         pass
     try:
@@ -101,21 +92,6 @@ def function_digest(function):
     return hasher.digest()
 
 
-def is_typed_named_tuple(cls):
-    """Return True if cls is probably a subtype of `typing.NamedTuple`.
-
-    Unfortunately types created with `class T(NamedTuple):` actually
-    subclass `tuple` directly rather than NamedTuple.  This is annoying,
-    and means we just have to hope that nobody defines a different tuple
-    subclass with similar attributes.
-    """
-    return (
-        issubclass(cls, tuple)
-        and hasattr(cls, "_fields")
-        and hasattr(cls, "_field_types")
-    )
-
-
 def required_args(target, args=(), kwargs=()):
     """Return a set of names of required args to target that were not supplied
     in args or kwargs.
@@ -129,10 +105,15 @@ def required_args(target, args=(), kwargs=()):
     if inspect.isclass(target) and is_typed_named_tuple(target):
         provided = set(kwargs) | set(target._fields[: len(args)])
         return set(target._fields) - provided
-    # Then we try to do the right thing with getfullargspec
+    # Then we try to do the right thing with inspect.getfullargspec
+    # Note that for classes we inspect the __init__ method, *unless* the class
+    # has an explicit __signature__ attribute.  This allows us to support
+    # runtime-generated constraints on **kwargs, as for e.g. Pydantic models.
     try:
-        spec = getfullargspec(
-            getattr(target, "__init__", target) if inspect.isclass(target) else target
+        spec = inspect.getfullargspec(
+            getattr(target, "__init__", target)
+            if inspect.isclass(target) and not hasattr(target, "__signature__")
+            else target
         )
     except TypeError:  # pragma: no cover
         return None
@@ -152,11 +133,10 @@ def required_args(target, args=(), kwargs=()):
 
 def convert_keyword_arguments(function, args, kwargs):
     """Returns a pair of a tuple and a dictionary which would be equivalent
-    passed as positional and keyword args to the function. Unless function has.
-
-    **kwargs the dictionary will always be empty.
+    passed as positional and keyword args to the function. Unless function has
+    kwonlyargs or **kwargs the dictionary will always be empty.
     """
-    argspec = getfullargspec(function)
+    argspec = inspect.getfullargspec(function)
     new_args = []
     kwargs = dict(kwargs)
 
@@ -170,7 +150,7 @@ def convert_keyword_arguments(function, args, kwargs):
 
     n = max(len(args), len(argspec.args))
 
-    for i in hrange(n):
+    for i in range(n):
         if i < len(args):
             new_args.append(args[i])
         else:
@@ -203,7 +183,7 @@ def convert_positional_arguments(function, args, kwargs):
 
     new_args will only be non-empty if function has a variadic argument.
     """
-    argspec = getfullargspec(function)
+    argspec = inspect.getfullargspec(function)
     new_kwargs = dict(argspec.kwonlydefaults or {})
     new_kwargs.update(kwargs)
     if not argspec.varkw:
@@ -214,7 +194,7 @@ def convert_positional_arguments(function, args, kwargs):
                     % (function.__name__, k)
                 )
     if len(args) < len(argspec.args):
-        for i in hrange(len(args), len(argspec.args) - len(argspec.defaults or ())):
+        for i in range(len(args), len(argspec.args) - len(argspec.defaults or ())):
             if argspec.args[i] not in kwargs:
                 raise TypeError(
                     "No value provided for argument %s" % (argspec.args[i],)
@@ -237,7 +217,12 @@ def convert_positional_arguments(function, args, kwargs):
             )
         else:
             new_kwargs[name] = arg
-    return (tuple(args[len(argspec.args) :]), new_kwargs)
+
+    deprecated_posargs = getattr(function, "__deprecated_posargs", ())
+    for param, val in zip(deprecated_posargs, args[len(argspec.args) :]):
+        new_kwargs[param.name] = val
+
+    return (tuple(args[len(argspec.args) + len(deprecated_posargs) :]), new_kwargs)
 
 
 def extract_all_lambdas(tree):
@@ -253,7 +238,7 @@ def extract_all_lambdas(tree):
 
 
 def args_for_lambda_ast(l):
-    return [getattr(n, ARG_NAME_ATTRIBUTE) for n in l.args.args]
+    return [n.arg for n in l.args.args]
 
 
 LINE_CONTINUATION = re.compile(r"\\\n")
@@ -270,19 +255,11 @@ def extract_lambda_source(f):
     This is not a good function and I am sorry for it. Forgive me my
     sins, oh lord
     """
-    argspec = getfullargspec(f)
+    argspec = inspect.getfullargspec(f)
     arg_strings = []
-    # In Python 2 you can have destructuring arguments to functions. This
-    # results in an argspec with non-string values. I'm not very interested in
-    # handling these properly, but it's important to not crash on them.
-    bad_lambda = False
     for a in argspec.args:
-        if isinstance(a, (tuple, list)):  # pragma: no cover
-            arg_strings.append("(%s)" % (", ".join(a),))
-            bad_lambda = True
-        else:
-            assert isinstance(a, str)
-            arg_strings.append(a)
+        assert isinstance(a, str)
+        arg_strings.append(a)
     if argspec.varargs:
         arg_strings.append("*" + argspec.varargs)
     elif argspec.kwonlyargs:
@@ -290,7 +267,7 @@ def extract_lambda_source(f):
     for a in argspec.kwonlyargs or []:
         default = (argspec.kwonlydefaults or {}).get(a)
         if default:
-            arg_strings.append("{}={}".format(a, default))
+            arg_strings.append(f"{a}={default}")
         else:
             arg_strings.append(a)
 
@@ -298,11 +275,9 @@ def extract_lambda_source(f):
         if_confused = "lambda %s: <unknown>" % (", ".join(arg_strings),)
     else:
         if_confused = "lambda: <unknown>"
-    if bad_lambda:  # pragma: no cover
-        return if_confused
     try:
         source = inspect.getsource(f)
-    except IOError:
+    except OSError:
         return if_confused
 
     source = LINE_CONTINUATION.sub(" ", source)
@@ -315,7 +290,7 @@ def extract_lambda_source(f):
     try:
         tree = ast.parse(source)
     except SyntaxError:
-        for i in hrange(len(source) - 1, len("lambda"), -1):
+        for i in range(len(source) - 1, len("lambda"), -1):
             prefix = source[:i]
             if "lambda" not in prefix:
                 break
@@ -325,22 +300,22 @@ def extract_lambda_source(f):
                 break
             except SyntaxError:
                 continue
-    if tree is None:
-        if source.startswith("@"):
-            # This will always eventually find a valid expression because
-            # the decorator must be a valid Python function call, so will
-            # eventually be syntactically valid and break out of the loop. Thus
-            # this loop can never terminate normally, so a no branch pragma is
-            # appropriate.
-            for i in hrange(len(source) + 1):  # pragma: no branch
-                p = source[1:i]
-                if "lambda" in p:
-                    try:
-                        tree = ast.parse(p)
-                        source = p
-                        break
-                    except SyntaxError:
-                        pass
+    if tree is None and source.startswith("@"):
+        # This will always eventually find a valid expression because
+        # the decorator must be a valid Python function call, so will
+        # eventually be syntactically valid and break out of the loop.
+        # Thus, this loop can never terminate normally.
+        for i in range(len(source) + 1):
+            p = source[1:i]
+            if "lambda" in p:
+                try:
+                    tree = ast.parse(p)
+                    source = p
+                    break
+                except SyntaxError:
+                    pass
+        else:
+            raise NotImplementedError("expected to be unreachable")
 
     if tree is None:
         return if_confused
@@ -369,21 +344,14 @@ def extract_lambda_source(f):
     # an OSError.  Or if `f` is a built-in function, in which case we get a
     # TypeError.  In both cases, fall back to splitting the Unicode string.
     # It's not perfect, but it's the best we can do.
-    #
-    # Note 2: You can only detect the encoding with `tokenize.detect_encoding`
-    # in Python 3.2 or later.  But that's okay, because the only version that
-    # affects for us is Python 2.7, and 2.7 doesn't support non-ASCII identifiers:
-    # https://www.python.org/dev/peps/pep-3131/. In this case we'll get an
-    # AttributeError.
-    #
     try:
         with open(inspect.getsourcefile(f), "rb") as src_f:
-            encoding, _ = tokenize.detect_encoding(src_f.readline)
+            encoding, _ = detect_encoding(src_f.readline)
 
         source_bytes = source.encode(encoding)
         source_bytes = source_bytes[lambda_ast.col_offset :].strip()
         source = source_bytes.decode(encoding)
-    except (AttributeError, OSError, TypeError):
+    except (OSError, TypeError):
         source = source[lambda_ast.col_offset :].strip()
 
     # This ValueError can be thrown in Python 3 if:
@@ -401,7 +369,7 @@ def extract_lambda_source(f):
     except ValueError:
         return if_confused
 
-    for i in hrange(len(source), len("lambda"), -1):  # pragma: no branch
+    for i in range(len(source), len("lambda"), -1):  # pragma: no branch
         try:
             parsed = ast.parse(source[:i])
             assert len(parsed.body) == 1
@@ -428,9 +396,11 @@ def get_pretty_function_description(f):
     name = f.__name__
     if name == "<lambda>":
         return extract_lambda_source(f)
-    elif isinstance(f, types.MethodType):
+    elif isinstance(f, (types.MethodType, types.BuiltinMethodType)):
         self = f.__self__
-        if not (self is None or inspect.isclass(self)):
+        # Some objects, like `builtins.abs` are of BuiltinMethodType but have
+        # their module as __self__.  This might include c-extensions generally?
+        if not (self is None or inspect.isclass(self) or inspect.ismodule(self)):
             return "%r.%s" % (self, name)
     return name
 
@@ -441,14 +411,14 @@ def nicerepr(v):
     elif isinstance(v, type):
         return v.__name__
     else:
-        return to_str(pretty(v))
+        return pretty(v)
 
 
 def arg_string(f, args, kwargs, reorder=True):
     if reorder:
         args, kwargs = convert_positional_arguments(f, args, kwargs)
 
-    argspec = getfullargspec(f)
+    argspec = inspect.getfullargspec(f)
 
     bits = []
 
@@ -469,14 +439,10 @@ def unbind_method(f):
 
 
 def check_valid_identifier(identifier):
-    if not isidentifier(identifier):
+    if not identifier.isidentifier():
         raise ValueError("%r is not a valid python identifier" % (identifier,))
 
 
-def eval_directory():
-    return storage_directory("eval_source")
-
-
 eval_cache = {}  # type: dict
 
 
@@ -488,7 +454,7 @@ def source_exec_as_module(source):
 
     result = ModuleType(
         "hypothesis_temporary_module_%s"
-        % (hashlib.sha1(str_to_bytes(source)).hexdigest(),)
+        % (hashlib.sha384(str_to_bytes(source)).hexdigest(),)
     )
     assert isinstance(source, str)
     exec(source, result.__dict__)
@@ -532,7 +498,7 @@ def define_function_signature(name, docstring, argspec):
         check_valid_identifier(a)
 
     def accept(f):
-        fargspec = getfullargspec(f)
+        fargspec = inspect.getfullargspec(f)
         must_pass_as_kwargs = []
         invocation_parts = []
         for a in argspec.args:
@@ -560,9 +526,7 @@ def define_function_signature(name, docstring, argspec):
             parts.append("**" + argspec.varkw)
             invocation_parts.append("**" + argspec.varkw)
 
-        candidate_names = ["f"] + [
-            "f_%d" % (i,) for i in hrange(1, len(used_names) + 2)
-        ]
+        candidate_names = ["f"] + ["f_%d" % (i,) for i in range(1, len(used_names) + 2)]
 
         for funcname in candidate_names:  # pragma: no branch
             if funcname not in used_names:
@@ -618,9 +582,78 @@ def proxies(target):
                 define_function_signature(
                     target.__name__.replace("<lambda>", "_lambda_"),
                     target.__doc__,
-                    getfullargspec(target),
+                    inspect.getfullargspec(target),
                 )(proxy)
             )
         )
 
     return accept
+
+
+def deprecated_posargs(func: C) -> C:
+    """Insert a `*__deprecated_posargs,` shim in place of the `*,` for kwonly args.
+
+    This turns out to be fairly tricky to get right with our preferred style of
+    error handling (exhaustive) and various function-rewriting wrappers.
+    """
+    if READTHEDOCS:  # pragma: no cover
+        # Documentation should show the new signatures without deprecation helpers.
+        return func
+
+    signature = inspect.signature(func)
+    parameters = list(signature.parameters.values())
+    vararg = inspect.Parameter(
+        name="__deprecated_posargs",
+        kind=inspect.Parameter.VAR_POSITIONAL,
+        annotation=Any,
+    )
+
+    # If we're passed any VAR_POSITIONAL args, we'll use this sequence of
+    # params to match them up with the correct KEYWORD_ONLY argument after
+    # checking that it has its default value - if you're passing by name,
+    # can't have also been passing positionally before we deprecated that.
+    deprecated = []
+    for i, arg in enumerate(tuple(parameters)):
+        if arg.kind == inspect.Parameter.KEYWORD_ONLY:
+            if not deprecated:
+                parameters.insert(i, vararg)
+            deprecated.append(arg)
+
+    func.__signature__ = signature.replace(parameters=parameters)
+
+    @proxies(func)
+    def accept(*args, **kwargs):
+        bound = func.__signature__.bind_partial(*args, **kwargs)
+        bad_posargs = bound.arguments.pop("__deprecated_posargs", None) or ()
+        if len(bad_posargs) > len(deprecated):
+            # We have more positional arguments than the wrapped func has parameters,
+            # so there's no way this ever worked.  We know that this bind will fail
+            # but attempting it will raise a nice descriptive TypeError.
+            signature.bind_partial(*args, **kwargs)
+        for param, pos in zip(deprecated, bad_posargs):
+            # Unfortunately, another layer of our function-wrapping logic passes in
+            # all the default arguments as explicit arguments.  This means that if
+            # someone explicitly passes some value for a parameter as a positional
+            # argument and *the default value* as a keyword argument, we'll emit a
+            # deprecation warning but not an immediate error.  Ah well...
+            if bound.arguments.get(param.name, param.default) != param.default:
+                raise TypeError(
+                    "Cannot pass {name}={p} positionally and {name}={n} by name!".format(
+                        name=param.name, p=pos, n=bound.arguments[param.name]
+                    )
+                )
+            from hypothesis._settings import note_deprecation
+
+            note_deprecation(
+                "%s was passed %s=%r as a positional argument, which will be a "
+                "keyword-only argument in a future version."
+                % (qualname(func), param.name, pos),
+                since="2020-02-07",
+            )
+            bound.arguments[param.name] = pos
+        return func(*bound.args, **bound.kwargs)
+
+    # We use these in convert_positional_arguments, to ensure that the LazyStrategy
+    # repr of strategy objects look sensible (and will work without this shim).
+    accept.__deprecated_posargs = tuple(deprecated)
+    return accept
