@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -23,58 +21,63 @@ Notably, the set of steps available at any point may depend on the
 execution to date.
 """
 
-
-from __future__ import absolute_import, division, print_function
-
 import inspect
+from collections.abc import Iterable
 from copy import copy
+from functools import lru_cache
+from io import StringIO
+from typing import Any, Dict, List
 from unittest import TestCase
 
 import attr
 
-import hypothesis.internal.conjecture.utils as cu
-import hypothesis.strategies as st
-from hypothesis._settings import (
-    HealthCheck,
-    Verbosity,
-    note_deprecation,
-    settings as Settings,
-)
+from hypothesis import strategies as st
+from hypothesis._settings import HealthCheck, Verbosity, settings as Settings
 from hypothesis.control import current_build_context
 from hypothesis.core import given
-from hypothesis.errors import HypothesisException, InvalidArgument, InvalidDefinition
-from hypothesis.internal.compat import quiet_raise, string_types
-from hypothesis.internal.reflection import function_digest, nicerepr, proxies
+from hypothesis.errors import InvalidArgument, InvalidDefinition
+from hypothesis.internal.conjecture import utils as cu
+from hypothesis.internal.reflection import (
+    deprecated_posargs,
+    function_digest,
+    nicerepr,
+    proxies,
+    qualname,
+)
 from hypothesis.internal.validation import check_type
 from hypothesis.reporting import current_verbosity, report
-from hypothesis.searchstrategy.strategies import OneOfStrategy, SearchStrategy
-from hypothesis.vendor.pretty import CUnicodeIO, RepresentationPrinter
+from hypothesis.strategies._internal.featureflags import FeatureStrategy
+from hypothesis.strategies._internal.strategies import (
+    OneOfStrategy,
+    SearchStrategy,
+    check_strategy,
+)
+from hypothesis.vendor.pretty import RepresentationPrinter
 
 STATE_MACHINE_RUN_LABEL = cu.calc_label_from_name("another state machine step")
-
-if False:
-    from typing import Any, Dict, List, Text  # noqa
+SHOULD_CONTINUE_LABEL = cu.calc_label_from_name("should we continue drawing")
 
 
-class TestCaseProperty(object):  # pragma: no cover
+class TestCaseProperty:  # pragma: no cover
     def __get__(self, obj, typ=None):
         if obj is not None:
             typ = type(obj)
         return typ._to_test_case()
 
     def __set__(self, obj, value):
-        raise AttributeError(u"Cannot set TestCase")
+        raise AttributeError("Cannot set TestCase")
 
     def __delete__(self, obj):
-        raise AttributeError(u"Cannot delete TestCase")
+        raise AttributeError("Cannot delete TestCase")
 
 
-def run_state_machine_as_test(state_machine_factory, settings=None):
+@deprecated_posargs
+def run_state_machine_as_test(state_machine_factory, *, settings=None):
     """Run a state machine definition as a test, either silently doing nothing
     or printing a minimal breaking program and raising an exception.
 
     state_machine_factory is anything which returns an instance of
-    GenericStateMachine when called with no arguments - it can be a class or a
+    RuleBasedStateMachine when called with no arguments - it can be a class or a
     function. settings will be used to control the execution of the test.
     """
     if settings is None:
@@ -88,47 +91,102 @@ def run_state_machine_as_test(state_machine_factory, settings=None):
     @settings
     @given(st.data())
     def run_state_machine(factory, data):
+        cd = data.conjecture_data
         machine = factory()
-        if isinstance(machine, GenericStateMachine) and not isinstance(
-            machine, RuleBasedStateMachine
-        ):
-            note_deprecation(
-                "%s inherits from GenericStateMachine, which is deprecated.  Use a "
-                "RuleBasedStateMachine, or a test function with st.data(), instead."
-                % (type(machine).__name__,),
-                since="2019-05-29",
-            )
-        else:
-            check_type(RuleBasedStateMachine, machine, "state_machine_factory()")
-        data.conjecture_data.hypothesis_runner = machine
-
-        n_steps = settings.stateful_step_count
-        should_continue = cu.many(
-            data.conjecture_data, min_size=1, max_size=n_steps, average_size=n_steps
-        )
+        check_type(RuleBasedStateMachine, machine, "state_machine_factory()")
+        cd.hypothesis_runner = machine
 
         print_steps = (
             current_build_context().is_final or current_verbosity() >= Verbosity.debug
         )
         try:
             if print_steps:
-                machine.print_start()
+                report("state = %s()" % (machine.__class__.__name__,))
             machine.check_invariants()
+            max_steps = settings.stateful_step_count
+            steps_run = 0
 
-            while should_continue.more():
-                value = data.conjecture_data.draw(machine.steps())
+            while True:
+                # We basically always want to run the maximum number of steps,
+                # but need to leave a small probability of terminating early
+                # in order to allow for reducing the number of steps once we
+                # find a failing test case, so we stop with probability of
+                # 2 ** -16 during normal operation but force a stop when we've
+                # generated enough steps.
+                cd.start_example(STATE_MACHINE_RUN_LABEL)
+                if steps_run == 0:
+                    cd.draw_bits(16, forced=1)
+                elif steps_run >= max_steps:
+                    cd.draw_bits(16, forced=0)
+                    break
+                else:
+                    # All we really care about is whether this value is zero
+                    # or non-zero, so if it's > 1 we discard it and insert a
+                    # replacement value after
+                    cd.start_example(SHOULD_CONTINUE_LABEL)
+                    should_continue_value = cd.draw_bits(16)
+                    if should_continue_value > 1:
+                        cd.stop_example(discard=True)
+                        cd.draw_bits(16, forced=int(bool(should_continue_value)))
+                    else:
+                        cd.stop_example()
+                        if should_continue_value == 0:
+                            break
+                steps_run += 1
+
+                # Choose a rule to run, preferring an initialize rule if there are
+                # any which have not been run yet.
+                if machine._initialize_rules_to_run:
+                    init_rules = [
+                        st.tuples(st.just(rule), st.fixed_dictionaries(rule.arguments))
+                        for rule in machine._initialize_rules_to_run
+                    ]
+                    rule, data = cd.draw(st.one_of(init_rules))
+                    machine._initialize_rules_to_run.remove(rule)
+                else:
+                    rule, data = cd.draw(machine._rules_strategy)
+
+                # Pretty-print the values this rule was called with *before* calling
+                # _add_result_to_targets, to avoid printing arguments which are also
+                # a return value using the variable name they are assigned to.
+                # See https://github.com/HypothesisWorks/hypothesis/issues/2341
                 if print_steps:
-                    machine.print_step(value)
-                machine.execute_step(value)
+                    data_to_print = {
+                        k: machine._pretty_print(v) for k, v in data.items()
+                    }
+
+                # Assign 'result' here in case executing the rule fails below
+                result = multiple()
+                try:
+                    data = dict(data)
+                    for k, v in list(data.items()):
+                        if isinstance(v, VarReference):
+                            data[k] = machine.names_to_values[v.name]
+                    result = rule.function(machine, **data)
+                    if rule.targets:
+                        if isinstance(result, MultipleResults):
+                            for single_result in result.values:
+                                machine._add_result_to_targets(
+                                    rule.targets, single_result
+                                )
+                        else:
+                            machine._add_result_to_targets(rule.targets, result)
+                finally:
+                    if print_steps:
+                        # 'result' is only used if the step has target bundles.
+                        # If it does, and the result is a 'MultipleResult',
+                        # then 'print_step' prints a multi-variable assignment.
+                        machine._print_step(rule, data_to_print, result)
                 machine.check_invariants()
+                cd.stop_example()
         finally:
             if print_steps:
-                machine.print_end()
+                report("state.teardown()")
             machine.teardown()
 
     # Use a machine digest to identify stateful tests in the example database
-    run_state_machine.hypothesis.inner_test._hypothesis_internal_add_digest = function_digest(
-        state_machine_factory
+    run_state_machine.hypothesis.inner_test._hypothesis_internal_add_digest = (
+        function_digest(state_machine_factory)
     )
     # Copy some attributes so @seed and @reproduce_failure "just work"
     run_state_machine._hypothesis_internal_use_seed = getattr(
@@ -137,14 +195,12 @@ def run_state_machine_as_test(state_machine_factory, settings=None):
     run_state_machine._hypothesis_internal_use_reproduce_failure = getattr(
         state_machine_factory, "_hypothesis_internal_use_reproduce_failure", None
     )
+    run_state_machine._hypothesis_internal_print_given_args = False
 
     run_state_machine(state_machine_factory)
 
 
-class GenericStateMachineMeta(type):
-    def __init__(self, *args, **kwargs):
-        super(GenericStateMachineMeta, self).__init__(*args, **kwargs)
-
+class StateMachineMeta(type):
     def __setattr__(self, name, value):
         if name == "settings" and isinstance(value, Settings):
             raise AttributeError(
@@ -157,61 +213,166 @@ class GenericStateMachineMeta(type):
         return type.__setattr__(self, name, value)
 
 
-class GenericStateMachine(
-    GenericStateMachineMeta("GenericStateMachine", (object,), {})  # type: ignore
-):
-    """A GenericStateMachine is a deprecated approach to stateful testing.
+class RuleBasedStateMachine(metaclass=StateMachineMeta):
+    """A RuleBasedStateMachine gives you a structured way to define state machines.
 
-    In earlier versions of Hypothesis, you would define ``steps``,
-    ``execute_step``, ``teardown``, and ``check_invariants`` methods;
-    and the engine would then run something like the following::
-
-        @given(st.data())
-        def test_the_stateful_thing(data):
-            x = MyStatemachineSubclass()
-            x.check_invariants()
-            try:
-                for _ in range(50):
-                    step = data.draw(x.steps())
-                    x.execute_step(step)
-                    x.check_invariants()
-            finally:
-                x.teardown()
-
-    We now recommend using rule-based stateful testing instead wherever
-    possible.  If your test is better expressed in the above format than
-    as a rule-based state machine, we suggest "unrolling" your method
-    definitions into a simple test function with the above control flow.
+    The idea is that a state machine carries a bunch of types of data
+    divided into Bundles, and has a set of rules which may read data
+    from bundles (or just from normal strategies) and push data onto
+    bundles. At any given point a random applicable rule will be
+    executed.
     """
 
-    def steps(self):
-        """Return a SearchStrategy instance the defines the available next
-        steps."""
-        raise NotImplementedError(u"%r.steps()" % (self,))
+    _rules_per_class = {}  # type: Dict[type, List[classmethod]]
+    _invariants_per_class = {}  # type: Dict[type, List[classmethod]]
+    _base_rules_per_class = {}  # type: Dict[type, List[classmethod]]
+    _initializers_per_class = {}  # type: Dict[type, List[classmethod]]
+    _base_initializers_per_class = {}  # type: Dict[type, List[classmethod]]
 
-    def execute_step(self, step):
-        """Execute a step that has been previously drawn from self.steps()"""
-        raise NotImplementedError(u"%r.execute_step()" % (self,))
+    def __init__(self):
+        if not self.rules():
+            raise InvalidDefinition("Type %s defines no rules" % (type(self).__name__,))
+        self.bundles = {}  # type: Dict[str, list]
+        self.name_counter = 1
+        self.names_to_values = {}  # type: Dict[str, Any]
+        self.__stream = StringIO()
+        self.__printer = RepresentationPrinter(self.__stream)
+        self._initialize_rules_to_run = copy(self.initialize_rules())
+        self._rules_strategy = RuleStrategy(self)
 
-    def print_start(self):
-        """Called right at the start of printing.
+    def _pretty_print(self, value):
+        if isinstance(value, VarReference):
+            return value.name
+        self.__stream.seek(0)
+        self.__stream.truncate(0)
+        self.__printer.output_width = 0
+        self.__printer.buffer_width = 0
+        self.__printer.buffer.clear()
+        self.__printer.pretty(value)
+        self.__printer.flush()
+        return self.__stream.getvalue()
 
-        By default does nothing.
-        """
+    def __repr__(self):
+        return "%s(%s)" % (type(self).__name__, nicerepr(self.bundles))
 
-    def print_end(self):
-        """Called right at the end of printing.
+    def _new_name(self):
+        result = "v%d" % (self.name_counter,)
+        self.name_counter += 1
+        return result
 
-        By default does nothing.
-        """
+    def _last_names(self, n):
+        assert self.name_counter > n
+        count = self.name_counter
+        return ["v%d" % (i,) for i in range(count - n, count)]
 
-    def print_step(self, step):
-        """Print a step to the current reporter.
+    def bundle(self, name):
+        return self.bundles.setdefault(name, [])
 
-        This is called right before a step is executed.
-        """
-        self.step_count = getattr(self, u"step_count", 0) + 1
-        report(u"Step #%d: %s" % (self.step_count, nicerepr(step)))
+    @classmethod
+    def initialize_rules(cls):
+        try:
+            return cls._initializers_per_class[cls]
+        except KeyError:
+            pass
+
+        for _, v in inspect.getmembers(cls):
+            r = getattr(v, INITIALIZE_RULE_MARKER, None)
+            if r is not None:
+                cls.define_initialize_rule(
+                    r.targets, r.function, r.arguments, r.precondition
+                )
+        cls._initializers_per_class[cls] = cls._base_initializers_per_class.pop(cls, [])
+        return cls._initializers_per_class[cls]
+
+    @classmethod
+    def rules(cls):
+        try:
+            return cls._rules_per_class[cls]
+        except KeyError:
+            pass
+
+        for _, v in inspect.getmembers(cls):
+            r = getattr(v, RULE_MARKER, None)
+            if r is not None:
+                cls.define_rule(r.targets, r.function, r.arguments, r.precondition)
+        cls._rules_per_class[cls] = cls._base_rules_per_class.pop(cls, [])
+        return cls._rules_per_class[cls]
+
+    @classmethod
+    def invariants(cls):
+        try:
+            return cls._invariants_per_class[cls]
+        except KeyError:
+            pass
+
+        target = []
+        for _, v in inspect.getmembers(cls):
+            i = getattr(v, INVARIANT_MARKER, None)
+            if i is not None:
+                target.append(i)
+        cls._invariants_per_class[cls] = target
+        return cls._invariants_per_class[cls]
+
+    @classmethod
+    def define_initialize_rule(cls, targets, function, arguments, precondition=None):
+        converted_arguments = {}
+        for k, v in arguments.items():
+            converted_arguments[k] = v
+        if cls in cls._initializers_per_class:
+            target = cls._initializers_per_class[cls]
+        else:
+            target = cls._base_initializers_per_class.setdefault(cls, [])
+
+        return target.append(Rule(targets, function, converted_arguments, precondition))
+
+    @classmethod
+    def define_rule(cls, targets, function, arguments, precondition=None):
+        converted_arguments = {}
+        for k, v in arguments.items():
+            converted_arguments[k] = v
+        if cls in cls._rules_per_class:
+            target = cls._rules_per_class[cls]
+        else:
+            target = cls._base_rules_per_class.setdefault(cls, [])
+
+        return target.append(Rule(targets, function, converted_arguments, precondition))
+
+    def _print_step(self, rule, data, result):
+        self.step_count = getattr(self, "step_count", 0) + 1
+        # If the step has target bundles, and the result is a MultipleResults
+        # then we want to assign to multiple variables.
+        if isinstance(result, MultipleResults):
+            n_output_vars = len(result.values)
+        else:
+            n_output_vars = 1
+        output_assignment = (
+            "%s = " % (", ".join(self._last_names(n_output_vars)),)
+            if rule.targets and n_output_vars >= 1
+            else ""
+        )
+        report(
+            "%sstate.%s(%s)"
+            % (
+                output_assignment,
+                rule.function.__name__,
+                ", ".join("%s=%s" % kv for kv in data.items()),
+            )
+        )
+
+    def _add_result_to_targets(self, targets, result):
+        name = self._new_name()
+        self.__printer.singleton_pprinters.setdefault(
+            id(result), lambda obj, p, cycle: p.text(name)
+        )
+        self.names_to_values[name] = result
+        for target in targets:
+            self.bundles.setdefault(target, []).append(VarReference(name))
+
+    def check_invariants(self):
+        for invar in self.invariants():
+            if invar.precondition and not invar.precondition(self):
+                continue
+            invar.function(self)
 
     def teardown(self):
         """Called after a run has finished executing to clean up any necessary
@@ -220,43 +381,28 @@ class GenericStateMachine(
         Does nothing by default.
         """
 
-    def check_invariants(self):
-        """Called after initializing and after executing each step."""
-
-    _test_case_cache = {}  # type: dict
-
     TestCase = TestCaseProperty()
 
     @classmethod
+    @lru_cache()
     def _to_test_case(state_machine_class):
-        try:
-            return state_machine_class._test_case_cache[state_machine_class]
-        except KeyError:
-            pass
-
         class StateMachineTestCase(TestCase):
             settings = Settings(deadline=None, suppress_health_check=HealthCheck.all())
 
-        # We define this outside of the class and assign it because you can't
-        # assign attributes to instance method values in Python 2
-        def runTest(self):
-            run_state_machine_as_test(state_machine_class)
+            def runTest(self):
+                run_state_machine_as_test(state_machine_class)
 
-        runTest.is_hypothesis_test = True
-        StateMachineTestCase.runTest = runTest
-        base_name = state_machine_class.__name__
-        StateMachineTestCase.__name__ = str(base_name + u".TestCase")
-        StateMachineTestCase.__qualname__ = str(
-            getattr(state_machine_class, u"__qualname__", base_name) + u".TestCase"
-        )
-        state_machine_class._test_case_cache[state_machine_class] = StateMachineTestCase
+            runTest.is_hypothesis_test = True
+
+        StateMachineTestCase.__name__ = state_machine_class.__name__ + ".TestCase"
+        StateMachineTestCase.__qualname__ = qualname(state_machine_class) + ".TestCase"
         return StateMachineTestCase
 
 
 @attr.s()
-class Rule(object):
+class Rule:
     targets = attr.ib()
-    function = attr.ib()
+    function = attr.ib(repr=qualname)
     arguments = attr.ib()
     precondition = attr.ib()
     bundles = attr.ib(init=False)
@@ -309,10 +455,27 @@ class Bundle(SearchStrategy):
         reference = data.draw(self.__reference_strategy)
         return machine.names_to_values[reference.name]
 
+    def __repr__(self):
+        consume = self.__reference_strategy.consume
+        if consume is False:
+            return "Bundle(name=%r)" % (self.name,)
+        return "Bundle(name=%r, consume=%r)" % (self.name, consume)
+
+    def calc_is_empty(self, recur):
+        # We assume that a bundle will grow over time
+        return False
+
+    def available(self, data):
+        # ``self_strategy`` is an instance of the ``st.runner()`` strategy.
+        # Hence drawing from it only returns the current state machine without
+        # modifying the underlying buffer.
+        machine = data.draw(self_strategy)
+        return bool(machine.bundle(self.name))
+
 
 class BundleConsumer(Bundle):
     def __init__(self, bundle):
-        super(BundleConsumer, self).__init__(bundle.name, consume=True)
+        super().__init__(bundle.name, consume=True)
 
 
 def consumes(bundle):
@@ -334,9 +497,12 @@ def consumes(bundle):
 
 
 @attr.s()
-class MultipleResults(object):
+class MultipleResults(Iterable):
     values = attr.ib()
 
+    def __iter__(self):
+        return iter(self.values)
+
 
 def multiple(*args):
     """This function can be used to pass multiple results to the target(s) of
@@ -352,28 +518,16 @@ def _convert_targets(targets, target):
     """Single validator and convertor for target arguments."""
     if target is not None:
         if targets:
-            note_deprecation(
-                "Passing both targets=%r and target=%r is redundant, and "
-                "will become an error in a future version of Hypothesis.  "
-                "Pass targets=%r instead."
-                % (targets, target, tuple(targets) + (target,)),
-                since="2018-08-18",
+            raise InvalidArgument(
+                "Passing both targets=%r and target=%r is redundant - pass "
+                "targets=%r instead." % (targets, target, tuple(targets) + (target,))
             )
-        targets = tuple(targets) + (target,)
+        targets = (target,)
 
     converted_targets = []
     for t in targets:
-        if isinstance(t, string_types):
-            note_deprecation(
-                "Got %r as a target, but passing the name of a Bundle is "
-                "deprecated - please pass the Bundle directly." % (t,),
-                since="2018-08-18",
-            )
-        elif not isinstance(t, Bundle):
-            msg = (
-                "Got invalid target %r of type %r, but all targets must "
-                "be either a Bundle or the name of a Bundle."
-            )
+        if not isinstance(t, Bundle):
+            msg = "Got invalid target %r of type %r, but all targets must be Bundles."
             if isinstance(t, OneOfStrategy):
                 msg += (
                     "\nIt looks like you passed `one_of(a, b)` or `a | b` as "
@@ -389,13 +543,14 @@ def _convert_targets(targets, target):
     return tuple(converted_targets)
 
 
-RULE_MARKER = u"hypothesis_stateful_rule"
-INITIALIZE_RULE_MARKER = u"hypothesis_stateful_initialize_rule"
-PRECONDITION_MARKER = u"hypothesis_stateful_precondition"
-INVARIANT_MARKER = u"hypothesis_stateful_invariant"
+RULE_MARKER = "hypothesis_stateful_rule"
+INITIALIZE_RULE_MARKER = "hypothesis_stateful_initialize_rule"
+PRECONDITION_MARKER = "hypothesis_stateful_precondition"
+INVARIANT_MARKER = "hypothesis_stateful_invariant"
 
 
-def rule(targets=(), target=None, **kwargs):
+@deprecated_posargs
+def rule(*, targets=(), target=None, **kwargs):
     """Decorator for RuleBasedStateMachine. Any name present in target or
     targets will define where the end result of this function should go. If
     both are empty then the end result will be discarded.
@@ -416,6 +571,8 @@ def rule(targets=(), target=None, **kwargs):
     provided.
     """
     converted_targets = _convert_targets(targets, target)
+    for k, v in kwargs.items():
+        check_strategy(v, name=k)
 
     def accept(f):
         existing_rule = getattr(f, RULE_MARKER, None)
@@ -442,7 +599,8 @@ def rule(targets=(), target=None, **kwargs):
     return accept
 
 
-def initialize(targets=(), target=None, **kwargs):
+@deprecated_posargs
+def initialize(*, targets=(), target=None, **kwargs):
     """Decorator for RuleBasedStateMachine.
 
     An initialize decorator behaves like a rule, but the decorated
@@ -451,6 +609,8 @@ def initialize(targets=(), target=None, **kwargs):
     arbitrary order.
     """
     converted_targets = _convert_targets(targets, target)
+    for k, v in kwargs.items():
+        check_strategy(v, name=k)
 
     def accept(f):
         existing_rule = getattr(f, RULE_MARKER, None)
@@ -482,7 +642,7 @@ def initialize(targets=(), target=None, **kwargs):
 
 
 @attr.s()
-class VarReference(object):
+class VarReference:
     name = attr.ib()
 
 
@@ -541,7 +701,7 @@ def precondition(precond):
 
 
 @attr.s()
-class Invariant(object):
+class Invariant:
     function = attr.ib()
     precondition = attr.ib()
 
@@ -590,6 +750,10 @@ class RuleStrategy(SearchStrategy):
         self.machine = machine
         self.rules = list(machine.rules())
 
+        self.enabled_rules_strategy = st.shared(
+            FeatureStrategy(), key=("enabled rules", machine)
+        )
+
         # The order is a bit arbitrary. Primarily we're trying to group rules
         # that write to the same location together, and to put rules with no
         # target first as they have less effect on the structure. We order from
@@ -605,210 +769,39 @@ class RuleStrategy(SearchStrategy):
             )
         )
 
+    def __repr__(self):
+        return "%s(machine=%s({...}))" % (
+            self.__class__.__name__,
+            self.machine.__class__.__name__,
+        )
+
     def do_draw(self, data):
-        try:
-            rule = data.draw(st.sampled_from(self.rules).filter(self.is_valid))
-        except HypothesisException:
-            # FailedHealthCheck or UnsatisfiedAssumption depending on user settings.
-            msg = u"No progress can be made from state %r" % (self.machine,)
-            quiet_raise(InvalidDefinition(msg))
+        if not any(self.is_valid(rule) for rule in self.rules):
+            msg = "No progress can be made from state %r" % (self.machine,)
+            raise InvalidDefinition(msg) from None
+
+        feature_flags = data.draw(self.enabled_rules_strategy)
+
+        # Note: The order of the filters here is actually quite important,
+        # because checking is_enabled makes choices, so increases the size of
+        # the choice sequence. This means that if we are in a case where many
+        # rules are invalid we will make a lot more choices if we ask if they
+        # are enabled before we ask if they are valid, so our test cases will
+        # be artificially large.
+        rule = data.draw(
+            st.sampled_from(self.rules)
+            .filter(self.is_valid)
+            .filter(lambda r: feature_flags.is_enabled(r.function.__name__))
+        )
+
         return (rule, data.draw(rule.arguments_strategy))
 
     def is_valid(self, rule):
         if rule.precondition and not rule.precondition(self.machine):
             return False
+
         for b in rule.bundles:
             bundle = self.machine.bundle(b.name)
             if not bundle:
                 return False
         return True
-
-
-class RuleBasedStateMachine(GenericStateMachine):
-    """A RuleBasedStateMachine gives you a more structured way to define state
-    machines.
-
-    The idea is that a state machine carries a bunch of types of data
-    divided into Bundles, and has a set of rules which may read data
-    from bundles (or just from normal strategies) and push data onto
-    bundles. At any given point a random applicable rule will be
-    executed.
-    """
-
-    _rules_per_class = {}  # type: Dict[type, List[classmethod]]
-    _invariants_per_class = {}  # type: Dict[type, List[classmethod]]
-    _base_rules_per_class = {}  # type: Dict[type, List[classmethod]]
-    _initializers_per_class = {}  # type: Dict[type, List[classmethod]]
-    _base_initializers_per_class = {}  # type: Dict[type, List[classmethod]]
-
-    def __init__(self):
-        if not self.rules():
-            raise InvalidDefinition(
-                u"Type %s defines no rules" % (type(self).__name__,)
-            )
-        self.bundles = {}  # type: Dict[Text, list]
-        self.name_counter = 1
-        self.names_to_values = {}  # type: Dict[Text, Any]
-        self.__stream = CUnicodeIO()
-        self.__printer = RepresentationPrinter(self.__stream)
-        self._initialize_rules_to_run = copy(self.initialize_rules())
-        self.__rules_strategy = RuleStrategy(self)
-
-    def __pretty(self, value):
-        if isinstance(value, VarReference):
-            return value.name
-        self.__stream.seek(0)
-        self.__stream.truncate(0)
-        self.__printer.output_width = 0
-        self.__printer.buffer_width = 0
-        self.__printer.buffer.clear()
-        self.__printer.pretty(value)
-        self.__printer.flush()
-        return self.__stream.getvalue()
-
-    def __repr__(self):
-        return u"%s(%s)" % (type(self).__name__, nicerepr(self.bundles))
-
-    def upcoming_name(self):
-        return u"v%d" % (self.name_counter,)
-
-    def new_name(self):
-        result = self.upcoming_name()
-        self.name_counter += 1
-        return result
-
-    def bundle(self, name):
-        return self.bundles.setdefault(name, [])
-
-    @classmethod
-    def initialize_rules(cls):
-        try:
-            return cls._initializers_per_class[cls]
-        except KeyError:
-            pass
-
-        for k, v in inspect.getmembers(cls):
-            r = getattr(v, INITIALIZE_RULE_MARKER, None)
-            if r is not None:
-                cls.define_initialize_rule(
-                    r.targets, r.function, r.arguments, r.precondition
-                )
-        cls._initializers_per_class[cls] = cls._base_initializers_per_class.pop(cls, [])
-        return cls._initializers_per_class[cls]
-
-    @classmethod
-    def rules(cls):
-        try:
-            return cls._rules_per_class[cls]
-        except KeyError:
-            pass
-
-        for k, v in inspect.getmembers(cls):
-            r = getattr(v, RULE_MARKER, None)
-            if r is not None:
-                cls.define_rule(r.targets, r.function, r.arguments, r.precondition)
-        cls._rules_per_class[cls] = cls._base_rules_per_class.pop(cls, [])
-        return cls._rules_per_class[cls]
-
-    @classmethod
-    def invariants(cls):
-        try:
-            return cls._invariants_per_class[cls]
-        except KeyError:
-            pass
-
-        target = []
-        for k, v in inspect.getmembers(cls):
-            i = getattr(v, INVARIANT_MARKER, None)
-            if i is not None:
-                target.append(i)
-        cls._invariants_per_class[cls] = target
-        return cls._invariants_per_class[cls]
-
-    @classmethod
-    def define_initialize_rule(cls, targets, function, arguments, precondition=None):
-        converted_arguments = {}
-        for k, v in arguments.items():
-            converted_arguments[k] = v
-        if cls in cls._initializers_per_class:
-            target = cls._initializers_per_class[cls]
-        else:
-            target = cls._base_initializers_per_class.setdefault(cls, [])
-
-        return target.append(Rule(targets, function, converted_arguments, precondition))
-
-    @classmethod
-    def define_rule(cls, targets, function, arguments, precondition=None):
-        converted_arguments = {}
-        for k, v in arguments.items():
-            converted_arguments[k] = v
-        if cls in cls._rules_per_class:
-            target = cls._rules_per_class[cls]
-        else:
-            target = cls._base_rules_per_class.setdefault(cls, [])
-
-        return target.append(Rule(targets, function, converted_arguments, precondition))
-
-    def steps(self):
-        # Pick initialize rules first
-        if self._initialize_rules_to_run:
-            return st.one_of(
-                [
-                    st.tuples(st.just(rule), st.fixed_dictionaries(rule.arguments))
-                    for rule in self._initialize_rules_to_run
-                ]
-            )
-
-        return self.__rules_strategy
-
-    def print_start(self):
-        report(u"state = %s()" % (self.__class__.__name__,))
-
-    def print_end(self):
-        report(u"state.teardown()")
-
-    def print_step(self, step):
-        rule, data = step
-        data_repr = {}
-        for k, v in data.items():
-            data_repr[k] = self.__pretty(v)
-        self.step_count = getattr(self, u"step_count", 0) + 1
-        report(
-            u"%sstate.%s(%s)"
-            % (
-                u"%s = " % (self.upcoming_name(),) if rule.targets else u"",
-                rule.function.__name__,
-                u", ".join(u"%s=%s" % kv for kv in data_repr.items()),
-            )
-        )
-
-    def _add_result_to_targets(self, targets, result):
-        name = self.new_name()
-        self.__printer.singleton_pprinters.setdefault(
-            id(result), lambda obj, p, cycle: p.text(name)
-        )
-        self.names_to_values[name] = result
-        for target in targets:
-            self.bundle(target).append(VarReference(name))
-
-    def execute_step(self, step):
-        rule, data = step
-        data = dict(data)
-        for k, v in list(data.items()):
-            if isinstance(v, VarReference):
-                data[k] = self.names_to_values[v.name]
-        result = rule.function(self, **data)
-        if rule.targets:
-            if isinstance(result, MultipleResults):
-                for single_result in result.values:
-                    self._add_result_to_targets(rule.targets, single_result)
-            else:
-                self._add_result_to_targets(rule.targets, result)
-        if self._initialize_rules_to_run:
-            self._initialize_rules_to_run.remove(rule)
-
-    def check_invariants(self):
-        for invar in self.invariants():
-            if invar.precondition and not invar.precondition(self):
-                continue
-            invar.function(self)
