@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import sys
 from collections import namedtuple
 
@@ -45,17 +41,10 @@ from hypothesis.strategies import (
 )
 from tests.common.debug import TIME_INCREMENT
 
-try:
-    import pytest
-except ImportError:
-    pytest = None
-
-
 __all__ = ["standard_types", "OrderedPair", "TIME_INCREMENT"]
 
 OrderedPair = namedtuple("OrderedPair", ("left", "right"))
 
-
 ordered_pair = integers().flatmap(
     lambda right: integers(min_value=0).map(
         lambda length: OrderedPair(right - length, right)
@@ -91,7 +80,7 @@ standard_types = [
     sampled_from(("a", "b", "c")),
     integers(),
     integers(min_value=3),
-    integers(min_value=(-2 ** 32), max_value=(2 ** 64)),
+    integers(min_value=(-(2 ** 32)), max_value=(2 ** 64)),
     floats(),
     floats(min_value=-2.0, max_value=3.0),
     floats(),
@@ -117,7 +106,7 @@ standard_types = [
     integers().filter(lambda x: abs(x) > 100),
     floats(min_value=-sys.float_info.max, max_value=sys.float_info.max),
     none(),
-    randoms(),
+    randoms(use_true_random=True),
     booleans().flatmap(lambda x: booleans() if x else complex_numbers()),
     recursive(base=booleans(), extend=lambda x: lists(x, max_size=3), max_leaves=10),
 ]
