@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,11 +13,14 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
-import hypothesis.strategies as st
-from hypothesis import HealthCheck, Verbosity, given, settings as Settings
-from hypothesis.errors import NoSuchExample, Unsatisfiable
+from hypothesis import (
+    HealthCheck,
+    Verbosity,
+    given,
+    settings as Settings,
+    strategies as st,
+)
+from hypothesis.errors import Found, NoSuchExample, Unsatisfiable
 from hypothesis.internal.conjecture.data import ConjectureData, StopTest
 from hypothesis.internal.reflection import get_pretty_function_description
 from tests.common.utils import no_shrink
@@ -32,9 +33,6 @@ class Timeout(BaseException):
 
 
 def minimal(definition, condition=lambda x: True, settings=None, timeout_after=10):
-    class Found(Exception):
-        """Signal that the example matches condition."""
-
     def wrapped_condition(x):
         if timeout_after is not None:
             if runtime:
@@ -46,13 +44,21 @@ def minimal(definition, condition=lambda x: True, settings=None, timeout_after=1
             runtime.append(0.0)
         return result
 
+    if settings is None:
+        settings = Settings(max_examples=50000)
+
+    verbosity = settings.verbosity
+    if verbosity == Verbosity.normal:
+        verbosity = Verbosity.quiet
+
     @given(definition)
     @Settings(
-        parent=settings or Settings(max_examples=50000, verbosity=Verbosity.quiet),
+        parent=settings,
         suppress_health_check=HealthCheck.all(),
         report_multiple_bugs=False,
         derandomize=True,
         database=None,
+        verbosity=verbosity,
     )
     def inner(x):
         if wrapped_condition(x):
@@ -73,7 +79,14 @@ def minimal(definition, condition=lambda x: True, settings=None, timeout_after=1
 
 
 def find_any(definition, condition=lambda _: True, settings=None):
-    return minimal(definition, condition, settings=Settings(settings, phases=no_shrink))
+    settings = settings or Settings.default
+    return minimal(
+        definition,
+        condition,
+        settings=Settings(
+            settings, phases=no_shrink, max_examples=max(1000, settings.max_examples)
+        ),
+    )
 
 
 def assert_no_examples(strategy, condition=lambda _: True):
