@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import os
 from tempfile import mkdtemp
 from warnings import filterwarnings
@@ -24,6 +20,7 @@ from warnings import filterwarnings
 from hypothesis import Verbosity, settings
 from hypothesis._settings import not_set
 from hypothesis.configuration import set_hypothesis_home_dir
+from hypothesis.errors import NonInteractiveExampleWarning
 from hypothesis.internal.charmap import charmap, charmap_file
 from hypothesis.internal.coverage import IN_COVERAGE_TESTS
 
@@ -58,6 +55,9 @@ def run():
         "ignore", message="Importing from numpy.testing.nosetester is deprecated"
     )
 
+    # User-facing warning which does not apply to our own tests
+    filterwarnings("ignore", category=NonInteractiveExampleWarning)
+
     new_home = mkdtemp()
     set_hypothesis_home_dir(new_home)
     assert settings.default.database.path.startswith(new_home)
@@ -69,7 +69,7 @@ def run():
     # We do a smoke test here before we mess around with settings.
     x = settings()
 
-    import hypothesis._settings as settings_module
+    from hypothesis import _settings as settings_module
 
     for s in settings_module.all_settings.values():
         v = getattr(x, s.name)
@@ -84,7 +84,7 @@ def run():
             )
 
     settings.register_profile(
-        "default", settings(max_examples=10 if IN_COVERAGE_TESTS else not_set)
+        "default", settings(max_examples=20 if IN_COVERAGE_TESTS else not_set)
     )
 
     settings.register_profile("speedy", settings(max_examples=5))
