@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,12 +13,9 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import time
 
-from hypothesis.internal.compat import hbytes, hrange
-from hypothesis.searchstrategy import SearchStrategy
+from hypothesis.strategies._internal import SearchStrategy
 
 
 class _Slow(SearchStrategy):
@@ -39,7 +34,7 @@ class HardToShrink(SearchStrategy):
         self.accepted = set()
 
     def do_draw(self, data):
-        x = hbytes([data.draw_bits(8) for _ in range(100)])
+        x = bytes([data.draw_bits(8) for _ in range(100)])
         if x in self.accepted:
             return True
         ls = self.__last
@@ -50,7 +45,7 @@ class HardToShrink(SearchStrategy):
                 return True
             else:
                 return False
-        diffs = [i for i in hrange(len(x)) if x[i] != ls[i]]
+        diffs = [i for i in range(len(x)) if x[i] != ls[i]]
         if len(diffs) == 1:
             i = diffs[0]
             if x[i] + 1 == ls[i]:
