@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,18 +13,17 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import contextlib
 import sys
 import traceback
-from io import BytesIO, StringIO
+from io import StringIO
 
 from hypothesis._settings import Phase
 from hypothesis.errors import HypothesisDeprecationWarning
-from hypothesis.internal.compat import PY2
 from hypothesis.internal.reflection import proxies
 from hypothesis.reporting import default, with_reporter
+from hypothesis.strategies._internal.core import from_type, register_type_strategy
+from hypothesis.strategies._internal.types import _global_type_lookup
 
 no_shrink = tuple(set(Phase) - {Phase.shrink})
 
@@ -58,7 +55,7 @@ def flaky(max_runs, min_passes):
 def capture_out():
     old_out = sys.stdout
     try:
-        new_out = BytesIO() if PY2 else StringIO()
+        new_out = StringIO()
         sys.stdout = new_out
         with with_reporter(default):
             yield new_out
@@ -66,7 +63,7 @@ def capture_out():
         sys.stdout = old_out
 
 
-class ExcInfo(object):
+class ExcInfo:
     pass
 
 
@@ -135,7 +132,7 @@ def all_values(db):
 
 def non_covering_examples(database):
     return {
-        v for k, vs in database.data.items() if not k.endswith(b".coverage") for v in vs
+        v for k, vs in database.data.items() if not k.endswith(b".pareto") for v in vs
     }
 
 
@@ -152,3 +149,38 @@ def counts_calls(func):
 
     _inner.calls = 0
     return _inner
+
+
+def assert_output_contains_failure(output, test, **kwargs):
+    assert test.__name__ + "(" in output
+    for k, v in kwargs.items():
+        assert ("%s=%r" % (k, v)) in output
+
+
+def assert_falsifying_output(
+    test, example_type="Falsifying", expected_exception=AssertionError, **kwargs
+):
+    with capture_out() as out:
+        with raises(expected_exception):
+            test()
+
+    assert "%s example:" % (example_type,)
+    assert_output_contains_failure(out.getvalue(), test, **kwargs)
+
+
+@contextlib.contextmanager
+def temp_registered(type_, strat_or_factory):
+    """Register and un-register a type for st.from_type().
+
+    This not too hard, but there's a subtlety in restoring the
+    previously-registered strategy which we got wrong in a few places.
+    """
+    prev = _global_type_lookup.get(type_)
+    try:
+        register_type_strategy(type_, strat_or_factory)
+        yield
+    finally:
+        del _global_type_lookup[type_]
+        from_type.__clear_cache()
+        if prev is not None:
+            register_type_strategy(type_, prev)
