@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,13 +13,11 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
 from hypothesis import find, given, reporting, strategies as st
 from hypothesis.errors import InvalidArgument
-from tests.common.utils import capture_out, checks_deprecated_behaviour, raises
+from tests.common.utils import capture_out, raises
 
 
 @given(st.integers(), st.data())
@@ -82,7 +78,6 @@ def test_given_twice_is_same():
     assert "Draw 2: 0" in result
 
 
-@checks_deprecated_behaviour
 def test_errors_when_used_in_find():
     with raises(InvalidArgument):
         find(st.data(), lambda x: x.draw(st.booleans()))
