@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,23 +13,17 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
+import typing
 
 import attr
 import pytest
 
-import hypothesis.strategies as st
-from hypothesis import given, infer
+from hypothesis import given, infer, strategies as st
 from hypothesis.errors import ResolutionFailed
 
-try:
-    import typing
-except ImportError:
-    typing = None
-
 
 @attr.s
-class Inferrables(object):
+class Inferrables:
     type_ = attr.ib(type=int)
     type_converter = attr.ib(converter=bool)
     validator_type = attr.ib(validator=attr.validators.instance_of(str))
@@ -60,27 +52,26 @@ class Inferrables(object):
         validator=[attr.validators.in_("abcd"), attr.validators.in_(["ab", "cd"])]
     )
 
-    if typing is not None:
-        typing_list = attr.ib(type=typing.List[int])
-        typing_list_of_list = attr.ib(type=typing.List[typing.List[int]])
-        typing_dict = attr.ib(type=typing.Dict[str, int])
-        typing_union = attr.ib(type=typing.Optional[bool])
-        typing_union = attr.ib(type=typing.Union[str, int])
+    typing_list = attr.ib(type=typing.List[int])
+    typing_list_of_list = attr.ib(type=typing.List[typing.List[int]])
+    typing_dict = attr.ib(type=typing.Dict[str, int])
+    typing_union = attr.ib(type=typing.Optional[bool])
+    typing_union = attr.ib(type=typing.Union[str, int])
 
     has_default = attr.ib(default=0)
     has_default_factory = attr.ib(default=attr.Factory(list))
     has_default_factory_takes_self = attr.ib(  # uninferrable but has default
-        default=attr.Factory(lambda _: list(), takes_self=True)
+        default=attr.Factory(lambda _: [], takes_self=True)
     )
 
 
 @attr.s
-class Required(object):
+class Required:
     a = attr.ib()
 
 
 @attr.s
-class UnhelpfulConverter(object):
+class UnhelpfulConverter:
     a = attr.ib(converter=lambda x: x)
 
 
