@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,14 +13,21 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
+import threading
+from functools import partial
 from random import Random
 
 import pytest
 
-import hypothesis.strategies as st
-from hypothesis import HealthCheck, assume, example, given, note, settings
+from hypothesis import (
+    HealthCheck,
+    assume,
+    example,
+    given,
+    note,
+    settings,
+    strategies as st,
+)
 from hypothesis.internal.cache import GenericCache, LRUReusedCache
 
 
@@ -30,7 +35,7 @@ class LRUCache(GenericCache):
     __slots__ = ("__tick",)
 
     def __init__(self, max_size):
-        super(LRUCache, self).__init__(max_size)
+        super().__init__(max_size)
         self.__tick = 0
 
     def new_entry(self, key, value):
@@ -70,7 +75,7 @@ class ValueScored(GenericCache):
 
 class RandomCache(GenericCache):
     def __init__(self, max_size):
-        super(RandomCache, self).__init__(max_size)
+        super().__init__(max_size)
         self.random = Random(0)
 
     def new_entry(self, key, value):
@@ -297,3 +302,22 @@ def test_iterates_over_remaining_keys():
     for i in range(3):
         cache[i] = "hi"
     assert sorted(cache) == [1, 2]
+
+
+def test_cache_is_threadsafe_issue_2433_regression():
+    errors = []
+
+    def target():
+        for _ in range(1000):
+            try:
+                st.builds(partial(str))
+            except Exception as exc:
+                errors.append(exc)
+
+    workers = [threading.Thread(target=target) for _ in range(4)]
+    for worker in workers:
+        worker.start()
+    for worker in workers:
+        worker.join()
+
+    assert not errors
