@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,17 +13,14 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import os
 import sys
 import tempfile
+import time
 import unicodedata
 
-import hypothesis.internal.charmap as cm
-import hypothesis.strategies as st
-from hypothesis import assume, given
-from hypothesis.internal.compat import hunichr
+from hypothesis import assume, given, strategies as st
+from hypothesis.internal import charmap as cm
 
 
 def test_charmap_contains_all_unicode():
@@ -40,7 +35,7 @@ def test_charmap_has_right_categories():
     for cat, intervals in cm.charmap().items():
         for u, v in intervals:
             for i in range(u, v + 1):
-                real = unicodedata.category(hunichr(i))
+                real = unicodedata.category(chr(i))
                 assert real == cat, "%d is %s but reported in %s" % (i, real, cat)
 
 
@@ -61,7 +56,7 @@ def test_query_matches_categories(exclude, include):
     assert_valid_range_list(values)
     for u, v in values:
         for i in (u, v, (u + v) // 2):
-            cat = unicodedata.category(hunichr(i))
+            cat = unicodedata.category(chr(i))
             if include is not None:
                 assert cat in include
             assert cat not in exclude
@@ -84,7 +79,7 @@ def test_query_matches_categories_codepoints(exclude, include, m1, m2):
 
 @given(st.sampled_from(cm.categories()), st.integers(0, sys.maxunicode))
 def test_exclude_only_excludes_from_that_category(cat, i):
-    c = hunichr(i)
+    c = chr(i)
     assume(unicodedata.category(c) != cat)
     intervals = cm.query(exclude_categories=(cat,))
     assert any(a <= i <= b for a, b in intervals)
@@ -109,6 +104,22 @@ def test_recreate_charmap():
     assert x == y
 
 
+def test_uses_cached_charmap():
+    cm.charmap()
+
+    # Reset the last-modified time of the cache file to a point in the past.
+    mtime = int(time.time() - 1000)
+    os.utime(cm.charmap_file(), (mtime, mtime))
+    statinfo = os.stat(cm.charmap_file())
+    assert statinfo.st_mtime == mtime
+
+    # Force reload of charmap from cache file and check that mtime is unchanged.
+    cm._charmap = None
+    cm.charmap()
+    statinfo = os.stat(cm.charmap_file())
+    assert statinfo.st_mtime == mtime
+
+
 def test_union_empty():
     assert cm._union_intervals([], []) == ()
     assert cm._union_intervals([], [[1, 2]]) == ((1, 2),)
