@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,15 +13,13 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import math
 import sys
 
-import hypothesis.strategies as st
-from hypothesis import given, reject
+from hypothesis import given, reject, strategies as st
 from hypothesis.strategies import complex_numbers
 from tests.common.debug import minimal
+from tests.common.utils import checks_deprecated_behaviour
 
 
 def test_minimal():
@@ -79,6 +75,7 @@ def test_minimal_min_magnitude_zero():
     assert minimal(complex_numbers(min_magnitude=0), lambda x: True) == 0
 
 
+@checks_deprecated_behaviour
 def test_minimal_min_magnitude_none():
     assert minimal(complex_numbers(min_magnitude=None), lambda x: True) == 0
 
@@ -102,5 +99,3 @@ def test_minmax_magnitude_equal(data, mag):
         assert math.isclose(abs(val), mag)
     except OverflowError:
         reject()
-    except AttributeError:
-        pass  # Python 2.7.3 does not have math.isclose
