@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
 from hypothesis import Verbosity, given, reporting, settings
@@ -89,7 +85,7 @@ def test_suppresses_exceptions_in_teardown():
                 cleanup(foo)
                 assert False
 
-    assert u"ValueError" in o.getvalue()
+    assert "ValueError" in o.getvalue()
     assert _current_build_context.value is None
 
 
@@ -110,8 +106,8 @@ def test_runs_multiple_cleanup_with_teardown():
                 cleanup(bar)
                 assert False
 
-    assert u"ValueError" in o.getvalue()
-    assert u"TypeError" in o.getvalue()
+    assert "ValueError" in o.getvalue()
+    assert "TypeError" in o.getvalue()
     assert _current_build_context.value is None
 
 
