@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,18 +13,13 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 from _pytest.outcomes import Failed, Skipped
 
-import hypothesis.strategies as s
-from hypothesis import find, given, reject, settings
-from hypothesis.errors import NoSuchExample, Unsatisfiable
-from tests.common.utils import checks_deprecated_behaviour
+from hypothesis import find, given, reject, settings, strategies as s
+from hypothesis.errors import InvalidArgument, NoSuchExample, Unsatisfiable
 
 
-@checks_deprecated_behaviour
 def test_stops_after_max_examples_if_satisfying():
     tracker = []
 
@@ -42,7 +35,6 @@ def test_stops_after_max_examples_if_satisfying():
     assert len(tracker) == max_examples
 
 
-@checks_deprecated_behaviour
 def test_stops_after_ten_times_max_examples_if_not_satisfying():
     count = [0]
 
@@ -55,7 +47,10 @@ def test_stops_after_ten_times_max_examples_if_not_satisfying():
     with pytest.raises(Unsatisfiable):
         find(s.integers(0, 10000), track, settings=settings(max_examples=max_examples))
 
-    assert count[0] == 10 * max_examples
+    # Very occasionally we can generate overflows in generation, which also
+    # count towards our example budget, which means that we don't hit the
+    # maximum.
+    assert count[0] <= 10 * max_examples
 
 
 some_normal_settings = settings()
@@ -74,7 +69,7 @@ def test_settings_are_default_in_given(x):
 def test_given_shrinks_pytest_helper_errors():
     final_value = [None]
 
-    @settings(derandomize=True)
+    @settings(derandomize=True, max_examples=100)
     @given(s.integers())
     def inner(x):
         final_value[0] = x
@@ -89,7 +84,7 @@ def test_given_shrinks_pytest_helper_errors():
 def test_pytest_skip_skips_shrinking():
     values = []
 
-    @settings(derandomize=True)
+    @settings(derandomize=True, max_examples=100)
     @given(s.integers())
     def inner(x):
         values.append(x)
@@ -101,12 +96,23 @@ def test_pytest_skip_skips_shrinking():
     assert len([x for x in values if x > 100]) == 1
 
 
-@checks_deprecated_behaviour
 def test_can_find_with_db_eq_none():
-    find(s.integers(), bool, settings(database=None))
+    find(s.integers(), bool, settings=settings(database=None, max_examples=100))
 
 
-@checks_deprecated_behaviour
 def test_no_such_example():
     with pytest.raises(NoSuchExample):
         find(s.none(), bool, database_key=b"no such example")
+
+
+def test_validates_strategies_for_test_method():
+    invalid_strategy = s.lists(s.nothing(), min_size=1)
+
+    class TestStrategyValidation:
+        @given(invalid_strategy)
+        def test_method_with_bad_strategy(self, x):
+            pass
+
+    instance = TestStrategyValidation()
+    with pytest.raises(InvalidArgument):
+        instance.test_method_with_bad_strategy()
