@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,13 +13,10 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
 from hypothesis import given, strategies as st
 from hypothesis.errors import InvalidArgument
-from hypothesis.internal.compat import hrange
 from tests.common.debug import assert_no_examples, minimal
 
 
@@ -135,7 +130,7 @@ def test_very_deep_deferral():
         else:
             return st.deferred(lambda: st.tuples(strategies[(i + 1) % len(strategies)]))
 
-    strategies = list(map(strat, hrange(100)))
+    strategies = list(map(strat, range(100)))
 
     assert strategies[0].has_reusable_values
     assert not strategies[0].is_empty
