@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,11 +13,9 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from hypothesis import given
 from hypothesis.internal.detection import is_hypothesis_test
-from hypothesis.stateful import GenericStateMachine
+from hypothesis.stateful import RuleBasedStateMachine, rule
 from hypothesis.strategies import integers
 
 
@@ -31,7 +27,7 @@ def test_functions_default_to_not_tests():
 
 
 def test_methods_default_to_not_tests():
-    class Foo(object):
+    class Foo:
         def foo():
             pass
 
@@ -47,7 +43,7 @@ def test_detection_of_functions():
 
 
 def test_detection_of_methods():
-    class Foo(object):
+    class Foo:
         @given(integers())
         def test(self, i):
             pass
@@ -56,11 +52,9 @@ def test_detection_of_methods():
 
 
 def test_detection_of_stateful_tests():
-    class Stuff(GenericStateMachine):
-        def steps(self):
-            return integers()
-
-        def execute_step(self, step):
+    class Stuff(RuleBasedStateMachine):
+        @rule(x=integers())
+        def a_rule(self, x):
             pass
 
     assert is_hypothesis_test(Stuff.TestCase().runTest)
