@@ -14,12 +14,10 @@
 # END HEADER
 
 import os
-import sys
 
 import pytest
 
 import hypothesis
-from hypothesis import given, strategies as st
 from hypothesis.internal import escalation as esc
 
 
@@ -50,23 +48,6 @@ def test_does_not_escalate_errors_in_hypothesis_file_if_disabled(monkeypatch):
         esc.escalate_hypothesis_internal_error()
 
 
-def test_immediately_escalates_errors_in_generation():
-    count = [0]
-
-    def explode(s):
-        count[0] += 1
-        raise ValueError()
-
-    @given(st.integers().map(explode))
-    def test(i):
-        pass
-
-    with pytest.raises(ValueError):
-        test()
-
-    assert count == [1]
-
-
 def test_is_hypothesis_file_not_confused_by_prefix(monkeypatch):
     # Errors in third-party extensions such as `hypothesis-trio` or
     # `hypothesis-jsonschema` used to be incorrectly considered to be
@@ -78,12 +59,6 @@ def test_is_hypothesis_file_not_confused_by_prefix(monkeypatch):
     assert esc.is_hypothesis_file(hypothesis.__file__)
     assert esc.is_hypothesis_file(esc.__file__)
 
-    # Ignore `Path.resolve` for python 3.5 because it is strict by default
-    # and some paths in this test are made up (this behavior has been changed
-    # since python 3.6)
-    if sys.version_info < (3, 6):
-        monkeypatch.setattr("pathlib.Path.resolve", lambda x: x, raising=False)
-
     assert not esc.is_hypothesis_file(pytest.__file__)
     assert not esc.is_hypothesis_file(root + "-suffix")
     assert not esc.is_hypothesis_file(root + "-suffix/something.py")
