@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import math
 
 import pytest
@@ -31,11 +27,11 @@ def test_can_handle_straddling_zero():
 @pytest.mark.parametrize(
     "func,val",
     [
-        (next_up, float("nan")),
-        (next_up, float("inf")),
+        (next_up, math.nan),
+        (next_up, math.inf),
         (next_up, -0.0),
-        (next_down, float("nan")),
-        (next_down, float("-inf")),
+        (next_down, math.nan),
+        (next_down, -math.inf),
         (next_down, 0.0),
     ],
 )
