@@ -17,17 +17,20 @@ import abc
 import collections
 import datetime
 import enum
+import inspect
 import io
+import re
 import string
 import sys
 import typing
+from inspect import signature
 from numbers import Real
 
 import pytest
 
 from hypothesis import HealthCheck, assume, given, infer, settings, strategies as st
-from hypothesis.errors import InvalidArgument, ResolutionFailed, Unsatisfiable
-from hypothesis.internal.compat import ForwardRef, get_type_hints, typing_root_type
+from hypothesis.errors import InvalidArgument, ResolutionFailed
+from hypothesis.internal.compat import PYPY, get_type_hints, typing_root_type
 from hypothesis.strategies import from_type
 from hypothesis.strategies._internal import types
 from tests.common.debug import assert_all_examples, find_any, minimal
@@ -35,37 +38,34 @@ from tests.common.utils import fails_with, temp_registered
 
 sentinel = object()
 generics = sorted(
-    (t for t in types._global_type_lookup if isinstance(t, typing_root_type)), key=str
+    (
+        t
+        for t in types._global_type_lookup
+        # We ignore TypeVar, because it is not a Generic type:
+        if isinstance(t, typing_root_type) and t != typing.TypeVar
+    ),
+    key=str,
 )
 xfail_on_39 = () if sys.version_info[:2] < (3, 9) else pytest.mark.xfail
 
 
-@pytest.mark.parametrize("typ", generics)
-def test_resolve_typing_module(typ):
-    @settings(
-        suppress_health_check=[HealthCheck.too_slow, HealthCheck.filter_too_much],
-        database=None,
-    )
-    @given(from_type(typ))
-    def inner(ex):
-        if typ in (typing.BinaryIO, typing.TextIO):
-            assert isinstance(ex, io.IOBase)
-        elif typ is typing.Tuple:
-            # isinstance is incompatible with Tuple on early 3.5
-            assert ex == ()
-        elif isinstance(typ, typing._ProtocolMeta):
-            pass
-        elif typ is typing.Type and not isinstance(typing.Type, type):
-            assert ex is type or isinstance(ex, typing.TypeVar)
-        else:
-            try:
-                assert isinstance(ex, typ)
-            except TypeError:
-                if sys.version_info[:2] < (3, 6):
-                    pytest.skip()
-                raise
+@pytest.mark.parametrize("typ", generics, ids=repr)
+@settings(
+    suppress_health_check=[HealthCheck.too_slow, HealthCheck.filter_too_much],
+    database=None,
+)
+@given(data=st.data())
+def test_resolve_typing_module(data, typ):
+    ex = data.draw(from_type(typ))
 
-    inner()
+    if typ in (typing.BinaryIO, typing.TextIO):
+        assert isinstance(ex, io.IOBase)
+    elif isinstance(typ, typing._ProtocolMeta):
+        pass
+    elif typ is typing.Type and not isinstance(typing.Type, type):
+        assert ex is type or isinstance(ex, typing.TypeVar)
+    else:
+        assert isinstance(ex, typ)
 
 
 @pytest.mark.parametrize("typ", [typing.Any, typing.Union])
@@ -78,83 +78,128 @@ def test_does_not_resolve_special_cases(typ):
     "typ,instance_of",
     [(typing.Union[int, str], (int, str)), (typing.Optional[int], (int, type(None)))],
 )
-def test_specialised_scalar_types(typ, instance_of):
-    @given(from_type(typ))
-    def inner(ex):
-        assert isinstance(ex, instance_of)
-
-    inner()
+@given(data=st.data())
+def test_specialised_scalar_types(data, typ, instance_of):
+    ex = data.draw(from_type(typ))
+    assert isinstance(ex, instance_of)
 
 
-@pytest.mark.skipif(not hasattr(typing, "Type"), reason="requires this attr")
 def test_typing_Type_int():
     assert from_type(typing.Type[int]).example() is int
 
 
-@pytest.mark.skipif(not hasattr(typing, "Type"), reason="requires this attr")
-def test_typing_Type_Union():
-    @given(from_type(typing.Type[typing.Union[str, list]]))
-    def inner(ex):
-        assert ex in (str, list)
-
-    inner()
+@given(from_type(typing.Type[typing.Union[str, list]]))
+def test_typing_Type_Union(ex):
+    assert ex in (str, list)
 
 
 @pytest.mark.parametrize(
-    "typ,coll_type,instance_of",
+    "typ",
     [
-        (typing.Set[int], set, int),
-        (typing.FrozenSet[int], frozenset, int),
-        (typing.Dict[int, int], dict, int),
-        (typing.KeysView[int], type({}.keys()), int),
-        (typing.ValuesView[int], type({}.values()), int),
-        (typing.List[int], list, int),
-        (typing.Tuple[int], tuple, int),
-        (typing.Tuple[int, ...], tuple, int),
-        (typing.Iterator[int], typing.Iterator, int),
-        (typing.Sequence[int], typing.Sequence, int),
-        (typing.Iterable[int], typing.Iterable, int),
-        (typing.Mapping[int, None], typing.Mapping, int),
-        (typing.Container[int], typing.Container, int),
-        (typing.NamedTuple("A_NamedTuple", (("elem", int),)), tuple, int),
+        collections.abc.ByteString,
+        # These are nonexistent or exist-but-are-not-types on Python 3.6
+        typing.Match if sys.version_info[:2] >= (3, 7) else int,
+        typing.Pattern if sys.version_info[:2] >= (3, 7) else int,
+        getattr(re, "Match", int),
+        getattr(re, "Pattern", int),
     ],
+    ids=repr,
 )
-def test_specialised_collection_types(typ, coll_type, instance_of):
-    @given(from_type(typ))
-    def inner(ex):
-        if sys.version_info[:2] >= (3, 6):
-            assume(ex)
-        assert isinstance(ex, coll_type)
-        assert all(isinstance(elem, instance_of) for elem in ex)
-
-    try:
-        inner()
-    except (ResolutionFailed, AssertionError):
-        if sys.version_info[:2] < (3, 6):
-            pytest.skip("Hard-to-reproduce bug (early version of typing?)")
-        raise
+@given(data=st.data())
+def test_rare_types(data, typ):
+    ex = data.draw(from_type(typ))
+    assert isinstance(ex, typ)
 
 
-@pytest.mark.skipif(sys.version_info[:2] < (3, 6), reason="new addition")
-def test_36_specialised_collection_types():
-    @given(from_type(typing.DefaultDict[int, int]))
-    def inner(ex):
-        assert isinstance(ex, collections.defaultdict)
-        assume(ex)
-        assert all(isinstance(elem, int) for elem in ex)
-        assert all(isinstance(elem, int) for elem in ex.values())
-
-    inner()
+class Elem:
+    pass
 
 
-@given(from_type(typing.ItemsView[int, int]))
+@pytest.mark.parametrize(
+    "typ,coll_type",
+    [
+        (typing.Set[Elem], set),
+        (typing.FrozenSet[Elem], frozenset),
+        (typing.Dict[Elem, None], dict),
+        (typing.DefaultDict[Elem, None], collections.defaultdict),
+        (typing.KeysView[Elem], type({}.keys())),
+        (typing.ValuesView[Elem], type({}.values())),
+        (typing.List[Elem], list),
+        (typing.Tuple[Elem], tuple),
+        (typing.Tuple[Elem, ...], tuple),
+        (typing.Iterator[Elem], typing.Iterator),
+        (typing.Sequence[Elem], typing.Sequence),
+        (typing.Iterable[Elem], typing.Iterable),
+        (typing.Mapping[Elem, None], typing.Mapping),
+        (typing.Container[Elem], typing.Container),
+        (typing.NamedTuple("A_NamedTuple", (("elem", Elem),)), tuple),
+        (typing.Counter[Elem], typing.Counter),
+        (typing.Deque[Elem], typing.Deque),
+    ],
+    ids=repr,
+)
+@given(data=st.data())
+def test_specialised_collection_types(data, typ, coll_type):
+    ex = data.draw(from_type(typ))
+    assert isinstance(ex, coll_type)
+    instances = [isinstance(elem, Elem) for elem in ex]
+    assert all(instances)
+    assume(instances)  # non-empty collections without calling len(iterator)
+
+
+class ElemValue:
+    pass
+
+
+@pytest.mark.parametrize(
+    "typ,coll_type",
+    [
+        (typing.ChainMap[Elem, ElemValue], typing.ChainMap),
+        (typing.DefaultDict[Elem, ElemValue], typing.DefaultDict),
+    ]
+    + (
+        [(typing.OrderedDict[Elem, ElemValue], typing.OrderedDict)]
+        if hasattr(typing, "OrderedDict")  # Python 3.7.2 and later
+        else []
+    ),
+    ids=repr,
+)
+@given(data=st.data())
+def test_specialised_mapping_types(data, typ, coll_type):
+    ex = data.draw(from_type(typ).filter(len))
+    assert isinstance(ex, coll_type)
+    instances = [isinstance(elem, Elem) for elem in ex]
+    assert all(instances)
+    assert all(isinstance(elem, ElemValue) for elem in ex.values())
+
+
+@given(from_type(typing.ItemsView[Elem, Elem]).filter(len))
 def test_ItemsView(ex):
     # See https://github.com/python/typing/issues/177
-    if sys.version_info[:2] >= (3, 6):
-        assume(ex)
     assert isinstance(ex, type({}.items()))
     assert all(isinstance(elem, tuple) and len(elem) == 2 for elem in ex)
-    assert all(all(isinstance(e, int) for e in elem) for elem in ex)
+    assert all(all(isinstance(e, Elem) for e in elem) for elem in ex)
+
+
+@pytest.mark.skipif(sys.version_info[:2] == (3, 6), reason="not a type on py36")
+@pytest.mark.parametrize("generic", [typing.Match, typing.Pattern])
+@pytest.mark.parametrize("typ", [bytes, str])
+@given(data=st.data())
+def test_regex_types(data, generic, typ):
+    x = data.draw(from_type(generic[typ]))
+    assert isinstance(x[0] if generic is typing.Match else x.pattern, typ)
+
+
+@given(x=infer)
+def test_Generator(x: typing.Generator[Elem, None, ElemValue]):
+    assert isinstance(x, typing.Generator)
+    try:
+        while True:
+            e = next(x)
+            assert isinstance(e, Elem)
+            x.send(None)  # The generators we create don't check the send type
+    except StopIteration as stop:
+        assert isinstance(stop.value, ElemValue)
 
 
 def test_Optional_minimises_to_None():
@@ -164,27 +209,18 @@ def test_Optional_minimises_to_None():
 @pytest.mark.parametrize("n", range(10))
 def test_variable_length_tuples(n):
     type_ = typing.Tuple[int, ...]
-    try:
-        from_type(type_).filter(lambda ex: len(ex) == n).example()
-    except Unsatisfiable:
-        if sys.version_info[:2] < (3, 6):
-            pytest.skip()
-        raise
+    from_type(type_).filter(lambda ex: len(ex) == n).example()
 
 
 def test_lookup_overrides_defaults():
     sentinel = object()
-    try:
-        st.register_type_strategy(int, st.just(sentinel))
+    with temp_registered(int, st.just(sentinel)):
 
         @given(from_type(typing.List[int]))
         def inner_1(ex):
             assert all(elem is sentinel for elem in ex)
 
         inner_1()
-    finally:
-        st.register_type_strategy(int, st.integers())
-        st.from_type.__clear_cache()
 
     @given(from_type(typing.List[int]))
     def inner_2(ex):
@@ -284,6 +320,43 @@ def test_distinct_typevars_same_constraint():
     )
 
 
+def test_distinct_typevars_distinct_type():
+    """Ensures that two different type vars have at least one different type in their strategies."""
+    A = typing.TypeVar("A")
+    B = typing.TypeVar("B")
+    find_any(
+        st.tuples(st.from_type(A), st.from_type(B)),
+        lambda ab: type(ab[0]) != type(ab[1]),  # noqa
+    )
+
+
+@given(st.data())
+def test_same_typevars_same_type(data):
+    """Ensures that single type argument will always have the same type in a single context."""
+    A = typing.TypeVar("A")
+
+    def same_type_args(a: A, b: A):
+        assert type(a) == type(b)
+
+    data.draw(st.builds(same_type_args))
+
+
+def test_typevars_can_be_redefined():
+    """We test that one can register a custom strategy for all type vars."""
+    A = typing.TypeVar("A")
+
+    with temp_registered(typing.TypeVar, st.just(1)):
+        assert_all_examples(st.from_type(A), lambda obj: obj == 1)
+
+
+def test_typevars_can_be_redefine_with_factory():
+    """We test that one can register a custom strategy for all type vars."""
+    A = typing.TypeVar("A")
+
+    with temp_registered(typing.TypeVar, lambda thing: st.just(thing.__name__)):
+        assert_all_examples(st.from_type(A), lambda obj: obj == "A")
+
+
 def annotated_func(a: int, b: int = 2, *, c: int, d: int = 4):
     return a + b + c + d
 
@@ -368,7 +441,6 @@ def test_error_if_has_unresolvable_hints():
         inner()
 
 
-@pytest.mark.skipif(not hasattr(typing, "NewType"), reason="test for NewType")
 def test_resolves_NewType():
     typ = typing.NewType("T", int)
     nested = typing.NewType("NestedT", typ)
@@ -386,7 +458,6 @@ def test_resolves_enum(ex):
     assert isinstance(ex, E)
 
 
-@pytest.mark.skipif(not hasattr(enum, "Flag"), reason="test for Flag")
 @pytest.mark.parametrize("resolver", [from_type, st.sampled_from])
 def test_resolves_flag_enum(resolver):
     # Storing all combinations takes O(2^n) memory.  Using an enum of 52
@@ -428,7 +499,8 @@ def test_required_args(target, args, kwargs):
     ).example()
 
 
-AnnotatedNamedTuple = typing.NamedTuple("AnnotatedNamedTuple", [("a", str)])
+class AnnotatedNamedTuple(typing.NamedTuple):
+    a: str
 
 
 @given(st.builds(AnnotatedNamedTuple))
@@ -446,15 +518,10 @@ def test_override_args_for_namedtuple(thing):
     assert thing.a is None
 
 
-@pytest.mark.parametrize(
-    "thing", [typing.Optional, typing.List, getattr(typing, "Type", typing.Set)]
-)  # check Type if it's available, otherwise Set is redundant but harmless
+@pytest.mark.parametrize("thing", [typing.Optional, typing.List, typing.Type])
 def test_cannot_resolve_bare_forward_reference(thing):
     with pytest.raises(InvalidArgument):
         t = thing["int"]
-        if type(getattr(t, "__args__", [None])[0]) != ForwardRef:
-            assert sys.version_info[:2] == (3, 5)
-            pytest.xfail("python 3.5 typing module is really weird")
         st.from_type(t).example()
 
 
@@ -464,20 +531,11 @@ class Tree:
         self.right = right
 
     def __repr__(self):
-        return "Tree({}, {})".format(self.left, self.right)
+        return f"Tree({self.left}, {self.right})"
 
 
 def test_resolving_recursive_type():
-    try:
-        assert isinstance(st.builds(Tree).example(), Tree)
-    except ResolutionFailed:
-        assert sys.version_info[:2] == (3, 5)
-        pytest.xfail("python 3.5 typing module may not resolve annotations")
-    except TypeError:
-        # TypeError raised if typing.get_type_hints(Tree.__init__) fails; see
-        # https://github.com/HypothesisWorks/hypothesis-python/issues/1074
-        assert sys.version_info[:2] == (3, 5)
-        pytest.skip("Could not find type hints to resolve")
+    assert isinstance(st.builds(Tree).example(), Tree)
 
 
 @given(from_type(typing.Tuple[()]))
@@ -613,7 +671,7 @@ def test_can_cast():
 @pytest.mark.parametrize("type_", [datetime.timezone, datetime.tzinfo])
 def test_timezone_lookup(type_):
     assert issubclass(type_, datetime.tzinfo)
-    assert_all_examples(st.from_type(type_), lambda t: isinstance(t, datetime.timezone))
+    assert_all_examples(st.from_type(type_), lambda t: isinstance(t, type_))
 
 
 @pytest.mark.parametrize(
@@ -650,3 +708,88 @@ def test_hashable_type_unhashable_value():
 )
 def test_repr_passthrough(typ, repr_):
     assert repr(st.from_type(typ)) == repr_
+
+
+class TreeForwardRefs(typing.NamedTuple):
+    val: int
+    l: typing.Optional["TreeForwardRefs"]
+    r: typing.Optional["TreeForwardRefs"]
+
+
+@pytest.mark.skipif(PYPY, reason="pypy36 does not resolve the forward refs")
+@given(st.builds(TreeForwardRefs))
+def test_resolves_forward_references_outside_annotations(t):
+    assert isinstance(t, TreeForwardRefs)
+
+
+def constructor(a: str = None):
+    pass
+
+
+class WithOptionalInSignature:
+    __signature__ = inspect.signature(constructor)
+    __annotations__ = typing.get_type_hints(constructor)
+
+    def __init__(self, **kwargs):
+        assert set(kwargs) == {"a"}
+        self.a = kwargs["a"]
+
+
+def test_compat_get_type_hints_aware_of_None_default():
+    # Regression test for https://github.com/HypothesisWorks/hypothesis/issues/2648
+    strategy = st.builds(WithOptionalInSignature, a=infer)
+    find_any(strategy, lambda x: x.a is None)
+    find_any(strategy, lambda x: x.a is not None)
+
+    assert typing.get_type_hints(constructor)["a"] == typing.Optional[str]
+    assert inspect.signature(constructor).parameters["a"].annotation == str
+
+
+_ValueType = typing.TypeVar("_ValueType")
+
+
+class Wrapper(typing.Generic[_ValueType]):
+    _inner_value: _ValueType
+
+    def __init__(self, inner_value: _ValueType) -> None:
+        self._inner_value = inner_value
+
+
+@given(st.builds(Wrapper))
+def test_issue_2603_regression(built):
+    """It was impossible to build annotated classes with constructors."""
+    assert isinstance(built, Wrapper)
+
+
+class AnnotatedConstructor(typing.Generic[_ValueType]):
+    value: _ValueType  # the same name we have in `__init__`
+
+    def __init__(self, value: int) -> None:
+        """By this example we show, that ``int`` is more important than ``_ValueType``."""
+        assert isinstance(value, int)
+
+
+@given(st.data())
+def test_constructor_is_more_important(data):
+    """Constructor types should take precedence over all other annotations."""
+    data.draw(st.builds(AnnotatedConstructor))
+
+
+def use_signature(self, value: str) -> None:
+    ...
+
+
+class AnnotatedConstructorWithSignature(typing.Generic[_ValueType]):
+    value: _ValueType  # the same name we have in `__init__`
+
+    __signature__ = signature(use_signature)
+
+    def __init__(self, value: int) -> None:
+        """By this example we show, that ``__signature__`` is the most important source."""
+        assert isinstance(value, str)
+
+
+@given(st.data())
+def test_signature_is_the_most_important_source(data):
+    """Signature types should take precedence over all other annotations."""
+    data.draw(st.builds(AnnotatedConstructorWithSignature))
