@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,10 +13,8 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import decimal
-from math import copysign
+from math import copysign, inf
 
 import pytest
 
@@ -44,16 +40,8 @@ def test_fuzz_floats_bounds(data):
     low, high = data.draw(tuples(bound, bound), label="low, high")
     if low is not None and high is not None and low > high:
         low, high = high, low
-    exmin = (
-        low is not None
-        and low != float("inf")
-        and data.draw(booleans(), label="exclude_min")
-    )
-    exmax = (
-        high is not None
-        and high != float("-inf")
-        and data.draw(booleans(), label="exclude_max")
-    )
+    exmin = low is not None and low != inf and data.draw(booleans(), label="ex_min")
+    exmax = high is not None and high != -inf and data.draw(booleans(), label="ex_max")
     try:
         val = data.draw(
             floats(low, high, exclude_min=exmin, exclude_max=exmax), label="value"
@@ -88,7 +76,7 @@ def test_fuzz_fractions_bounds(data):
     if low is not None and high is not None and low > high:
         low, high = high, low
     try:
-        val = data.draw(fractions(low, high, denom), label="value")
+        val = data.draw(fractions(low, high, max_denominator=denom), label="value")
     except InvalidArgument:
         reject()  # fractions too close for given max_denominator
     if low is not None:
