@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from hypothesis import given
 from hypothesis.errors import InvalidArgument
 from hypothesis.strategies import permutations
@@ -30,10 +26,10 @@ def test_can_find_non_trivial_permutation():
     assert x == [1, 0, 2, 3, 4]
 
 
-@given(permutations(list(u"abcd")))
+@given(permutations(list("abcd")))
 def test_permutation_values_are_permutations(perm):
     assert len(perm) == 4
-    assert set(perm) == set(u"abcd")
+    assert set(perm) == set("abcd")
 
 
 @given(permutations([]))
