@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,15 +13,11 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
-import hypothesis.strategies as st
-from hypothesis import Phase, example, given, settings
+from hypothesis import Phase, example, given, settings, strategies as st
 from hypothesis.database import ExampleDatabase, InMemoryExampleDatabase
 from hypothesis.errors import InvalidArgument
-from tests.common.utils import checks_deprecated_behaviour
 
 
 @example(11)
@@ -33,7 +27,7 @@ def test_only_runs_explicit_examples(i):
     assert i == 11
 
 
-@example(u"hello world")
+@example("hello world")
 @settings(phases=(Phase.reuse, Phase.generate, Phase.shrink))
 @given(st.booleans())
 def test_does_not_use_explicit_examples(i):
@@ -61,11 +55,6 @@ def test_phases_default_to_all():
     assert settings().phases == tuple(Phase)
 
 
-@checks_deprecated_behaviour
-def test_phases_none_equals_all():
-    assert settings(phases=None).phases == tuple(Phase)
-
-
 def test_does_not_reuse_saved_examples_if_reuse_not_in_phases():
     class BadDatabase(ExampleDatabase):
         def save(self, key, value):
@@ -101,7 +90,7 @@ def test_will_save_when_reuse_not_in_phases():
     with pytest.raises(ValueError):
         test_usage()
 
-    saved, = [v for k, v in database.data.items() if b"coverage" not in k]
+    (saved,) = [v for k, v in database.data.items() if b"pareto" not in k]
     assert len(saved) == 1
 
 
