@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,14 +13,11 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
-import hypothesis.strategies as st
-from hypothesis import given
+from hypothesis import given, strategies as st
 from hypothesis.errors import InvalidArgument
-from tests.common.debug import minimal
+from tests.common.debug import find_any, minimal
 
 
 @given(st.recursive(st.booleans(), st.lists, max_leaves=10))
@@ -56,6 +51,29 @@ def test_recursive_call_validates_base_is_strategy():
         x.example()
 
 
+def test_can_find_exactly_max_leaves():
+    strat = st.recursive(st.none(), lambda x: st.tuples(x, x), max_leaves=5)
+
+    def enough_leaves(t):
+        print(t)
+        count = 0
+        stack = [t]
+        while stack:
+            s = stack.pop()
+            if s is None:
+                count += 1
+            else:
+                stack.extend(s)
+        return count >= 5
+
+    find_any(strat, enough_leaves)
+
+
+@given(st.recursive(st.none(), lambda x: st.tuples(x, x), max_leaves=1))
+def test_can_exclude_branching_with_max_leaves(t):
+    assert t is None
+
+
 @given(st.recursive(st.none(), lambda x: st.one_of(x, x)))
 def test_issue_1502_regression(s):
     pass
