@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,19 +13,13 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import random
+from unittest.mock import Mock
 
 import pytest
 
 from hypothesis import Verbosity, assume, given, seed, settings, strategies as st
 
-try:
-    from unittest.mock import Mock
-except ImportError:
-    from mock import Mock
-
 
 def strat():
     return st.builds(dict, one=strat_one())
