@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,17 +13,13 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import base64
 import re
 import zlib
 
 import pytest
 
-import hypothesis.strategies as st
 from hypothesis import (
-    PrintSettings,
     Verbosity,
     __version__,
     example,
@@ -33,15 +27,15 @@ from hypothesis import (
     reject,
     reproduce_failure,
     settings,
+    strategies as st,
 )
 from hypothesis.core import decode_failure, encode_failure
 from hypothesis.errors import DidNotReproduce, InvalidArgument, UnsatisfiedAssumption
-from hypothesis.internal.compat import hbytes
-from tests.common.utils import capture_out, checks_deprecated_behaviour, no_shrink
+from tests.common.utils import capture_out, no_shrink
 
 
-@example(hbytes(20))  # shorter compressed
-@example(hbytes(3))  # shorter uncompressed
+@example(bytes(20))  # shorter compressed
+@example(bytes(3))  # shorter uncompressed
 @given(st.binary() | st.binary(min_size=100))
 def test_encoding_loop(b):
     assert decode_failure(encode_failure(b)) == b
@@ -63,17 +57,30 @@ def test_decoding_may_fail(t):
         assert False, "decoding failed with %r, not InvalidArgument" % (e,)
 
 
+def test_invalid_base_64_gives_invalid_argument():
+    with pytest.raises(InvalidArgument) as exc_info:
+        decode_failure(b"/")
+    assert "Invalid base64 encoded" in exc_info.value.args[0]
+
+
 def test_reproduces_the_failure():
     b = b"hello world"
     n = len(b)
 
     @reproduce_failure(__version__, encode_failure(b))
     @given(st.binary(min_size=n, max_size=n))
-    def test(x):
+    def test_outer(x):
+        assert x != b
+
+    @given(st.binary(min_size=n, max_size=n))
+    @reproduce_failure(__version__, encode_failure(b))
+    def test_inner(x):
         assert x != b
 
     with pytest.raises(AssertionError):
-        test()
+        test_outer()
+    with pytest.raises(AssertionError):
+        test_inner()
 
 
 def test_errors_if_provided_example_does_not_reproduce_failure():
@@ -118,7 +125,7 @@ def test_errors_with_did_not_reproduce_if_rejected():
 def test_prints_reproduction_if_requested():
     failing_example = [None]
 
-    @settings(print_blob=True, database=None)
+    @settings(print_blob=True, database=None, max_examples=100)
     @given(st.integers())
     def test(i):
         if failing_example[0] is None and i != 0:
@@ -140,6 +147,7 @@ def test_prints_reproduction_if_requested():
 
 
 def test_does_not_print_reproduction_for_simple_examples_by_default():
+    @settings(print_blob=False)
     @given(st.integers())
     def test(i):
         assert False
@@ -151,6 +159,7 @@ def test_does_not_print_reproduction_for_simple_examples_by_default():
 
 
 def test_does_not_print_reproduction_for_simple_data_examples_by_default():
+    @settings(print_blob=False)
     @given(st.data())
     def test(data):
         data.draw(st.integers())
@@ -163,7 +172,7 @@ def test_does_not_print_reproduction_for_simple_data_examples_by_default():
 
 
 def test_does_not_print_reproduction_for_large_data_examples_by_default():
-    @settings(phases=no_shrink)
+    @settings(phases=no_shrink, print_blob=False)
     @given(st.data())
     def test(data):
         b = data.draw(st.binary(min_size=1000, max_size=1000))
@@ -176,7 +185,7 @@ def test_does_not_print_reproduction_for_large_data_examples_by_default():
     assert "@reproduce_failure" not in o.getvalue()
 
 
-class Foo(object):
+class Foo:
     def __repr__(self):
         return "not a valid python expression"
 
@@ -209,7 +218,7 @@ def test_raises_invalid_if_wrong_version():
 
 def test_does_not_print_reproduction_if_verbosity_set_to_quiet():
     @given(st.data())
-    @settings(verbosity=Verbosity.quiet)
+    @settings(verbosity=Verbosity.quiet, print_blob=False)
     def test_always_fails(data):
         assert data.draw(st.just(False))
 
@@ -218,16 +227,3 @@ def test_does_not_print_reproduction_if_verbosity_set_to_quiet():
             test_always_fails()
 
     assert "@reproduce_failure" not in out.getvalue()
-
-
-@pytest.mark.parametrize(
-    "ps,b",
-    [
-        (PrintSettings.NEVER, False),
-        (PrintSettings.INFER, True),
-        (PrintSettings.ALWAYS, True),
-    ],
-)
-@checks_deprecated_behaviour
-def test_converts_print_settings_to_boolean(ps, b):
-    assert settings(print_blob=ps).print_blob is b
