@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from unittest import TestCase
 
 import pytest
@@ -24,7 +20,6 @@ import pytest
 from hypothesis import find, given, strategies as st
 from hypothesis.errors import InvalidArgument
 from hypothesis.stateful import RuleBasedStateMachine, rule
-from tests.common.utils import checks_deprecated_behaviour
 
 
 def test_cannot_use_without_a_runner():
@@ -36,19 +31,17 @@ def test_cannot_use_without_a_runner():
         f()
 
 
-@checks_deprecated_behaviour
 def test_cannot_use_in_find_without_default():
     with pytest.raises(InvalidArgument):
         find(st.runner(), lambda x: True)
 
 
-@checks_deprecated_behaviour
 def test_is_default_in_find():
     t = object()
-    assert find(st.runner(t), lambda x: True) == t
+    assert find(st.runner(default=t), lambda x: True) == t
 
 
-@given(st.runner(1))
+@given(st.runner(default=1))
 def test_is_default_without_self(runner):
     assert runner == 1
 
