@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,17 +13,13 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import collections
 import enum
 
-import hypothesis.strategies as st
-from hypothesis import given
+from hypothesis import given, strategies as st
 from hypothesis.errors import FailedHealthCheck, InvalidArgument, Unsatisfiable
-from hypothesis.internal.compat import hrange
 from hypothesis.strategies import sampled_from
-from tests.common.utils import checks_deprecated_behaviour, fails_with
+from tests.common.utils import fails_with
 
 an_enum = enum.Enum("A", "a b c")
 
@@ -50,19 +44,14 @@ def test_can_sample_enums(member):
     assert isinstance(member, an_enum)
 
 
-@checks_deprecated_behaviour
-def test_sampling_empty_is_deprecated():
-    assert sampled_from([]).is_empty
-
-
 @fails_with(FailedHealthCheck)
-@given(sampled_from(hrange(10)).filter(lambda x: x < 0))
+@given(sampled_from(range(10)).filter(lambda x: x < 0))
 def test_unsat_filtered_sampling(x):
     assert False
 
 
 @fails_with(Unsatisfiable)
-@given(sampled_from(hrange(2)).filter(lambda x: x < 0))
+@given(sampled_from(range(2)).filter(lambda x: x < 0))
 def test_unsat_filtered_sampling_in_rejection_stage(x):
     # Rejecting all possible indices before we calculate the allowed indices
     # takes an early exit path, so we need this test to cover that branch.
@@ -70,11 +59,11 @@ def test_unsat_filtered_sampling_in_rejection_stage(x):
 
 
 def test_easy_filtered_sampling():
-    x = sampled_from(hrange(100)).filter(lambda x: x == 0).example()
+    x = sampled_from(range(100)).filter(lambda x: x == 0).example()
     assert x == 0
 
 
-@given(sampled_from(hrange(100)).filter(lambda x: x == 99))
+@given(sampled_from(range(100)).filter(lambda x: x == 99))
 def test_filtered_sampling_finds_rare_value(x):
     assert x == 99
 
@@ -89,6 +78,29 @@ def test_does_not_include_duplicates_even_when_duplicated_in_collection(ls):
     assert len(ls) <= 1
 
 
-@given(st.lists(st.sampled_from(hrange(100)), max_size=3, unique=True))
+@given(st.lists(st.sampled_from(range(100)), max_size=3, unique=True))
 def test_max_size_is_respected_with_unique_sampled_from(ls):
     assert len(ls) <= 3
+
+
+@given(st.lists(st.sampled_from([0, 0.0]), unique=True, min_size=1))
+def test_issue_2247_regression(ls):
+    assert len(ls) == 1
+
+
+@given(st.data())
+def test_mutability_1(data):
+    # See https://github.com/HypothesisWorks/hypothesis/issues/2507
+    x = [1]
+    s = st.sampled_from(x)
+    x.append(2)
+    assert data.draw(s) != 2
+
+
+@given(st.data())
+def test_mutability_2(data):
+    x = [1]
+    s = st.sampled_from(x)
+    assert data.draw(s) != 2
+    x.append(2)
+    assert data.draw(s) != 2
