@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,18 +13,13 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import time
 
 import pytest
 
-import hypothesis.core as core
-import hypothesis.strategies as st
-from hypothesis import Verbosity, assume, given, settings
+from hypothesis import Verbosity, assume, core, given, settings, strategies as st
 from hypothesis.database import InMemoryExampleDatabase
 from hypothesis.errors import FailedHealthCheck
-from hypothesis.internal.compat import hrange
 from tests.common.utils import all_values, capture_out
 
 
@@ -81,7 +74,7 @@ def test_uses_global_force(monkeypatch):
 
     output = []
 
-    for _ in hrange(2):
+    for _ in range(2):
         with capture_out() as o:
             with pytest.raises(ValueError):
                 test()
