@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,27 +13,25 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
-from hypothesis import assume, given
+from hypothesis import HealthCheck, assume, given, settings
 from hypothesis.strategies import integers, text
 
 
-class HasSetup(object):
+class HasSetup:
     def setup_example(self):
-        self.setups = getattr(self, u"setups", 0)
+        self.setups = getattr(self, "setups", 0)
         self.setups += 1
 
 
-class HasTeardown(object):
+class HasTeardown:
     def teardown_example(self, ex):
-        self.teardowns = getattr(self, u"teardowns", 0)
+        self.teardowns = getattr(self, "teardowns", 0)
         self.teardowns += 1
 
 
-class SomeGivens(object):
+class SomeGivens:
     @given(integers())
     def give_me_an_int(self, x):
         pass
@@ -45,6 +41,7 @@ class SomeGivens(object):
         pass
 
     @given(integers())
+    @settings(max_examples=1000)
     def give_me_a_positive_int(self, x):
         assert x >= 0
 
@@ -53,6 +50,7 @@ class SomeGivens(object):
         pass
 
     @given(integers())
+    @settings(suppress_health_check=[HealthCheck.filter_too_much])
     def assume_some_stuff(self, x):
         assume(x > 0)
 
@@ -117,7 +115,7 @@ def test_sets_up_without_teardown():
     x = Foo()
     x.give_me_an_int()
     assert x.setups > 0
-    assert not hasattr(x, u"teardowns")
+    assert not hasattr(x, "teardowns")
 
 
 def test_tears_down_without_setup():
@@ -127,4 +125,4 @@ def test_tears_down_without_setup():
     x = Foo()
     x.give_me_an_int()
     assert x.teardowns > 0
-    assert not hasattr(x, u"setups")
+    assert not hasattr(x, "setups")
