@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,15 +13,12 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import math
 import sys
 from random import Random
 
 import pytest
 
-from hypothesis.internal.compat import ceil
 from hypothesis.internal.conjecture.shrinking import Integer, Lexical, Ordering
 
 
@@ -38,7 +33,7 @@ def measure_baseline(cls, value, **kwargs):
 def test_meets_budgetary_requirements(cls, example):
     # Somewhat arbitrary but not unreasonable budget.
     n = len(example)
-    budget = n * ceil(math.log(n, 2)) + 5
+    budget = n * math.ceil(math.log(n, 2)) + 5
     assert measure_baseline(cls, example) <= budget
 
 
