@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,14 +13,11 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import unicodedata
 
 import pytest
 
 from hypothesis.errors import InvalidArgument
-from hypothesis.internal.compat import text_type
 from hypothesis.strategies import characters
 from tests.common.debug import assert_no_examples, find_any, minimal
 from tests.common.utils import fails_with
@@ -86,7 +81,7 @@ def test_exclude_characters_of_major_categories():
 
 def test_find_one():
     char = minimal(characters(min_codepoint=48, max_codepoint=48), lambda _: True)
-    assert char == u"0"
+    assert char == "0"
 
 
 def test_find_something_rare():
@@ -99,12 +94,12 @@ def test_find_something_rare():
 
 def test_whitelisted_characters_alone():
     with pytest.raises(InvalidArgument):
-        characters(whitelist_characters=u"te02тест49st").example()
+        characters(whitelist_characters="te02тест49st").example()
 
 
 def test_whitelisted_characters_overlap_blacklisted_characters():
-    good_chars = u"te02тест49st"
-    bad_chars = u"ts94тсет"
+    good_chars = "te02тест49st"
+    bad_chars = "ts94тсет"
     with pytest.raises(InvalidArgument) as exc:
         characters(
             min_codepoint=ord("0"),
@@ -112,12 +107,12 @@ def test_whitelisted_characters_overlap_blacklisted_characters():
             whitelist_characters=good_chars,
             blacklist_characters=bad_chars,
         ).example()
-        assert repr(good_chars) in text_type(exc)
-        assert repr(bad_chars) in text_type(exc)
+        assert repr(good_chars) in str(exc)
+        assert repr(bad_chars) in str(exc)
 
 
 def test_whitelisted_characters_override():
-    good_characters = u"teтестst"
+    good_characters = "teтестst"
     st = characters(
         min_codepoint=ord("0"),
         max_codepoint=ord("9"),
@@ -131,7 +126,7 @@ def test_whitelisted_characters_override():
 
 
 def test_blacklisted_characters():
-    bad_chars = u"te02тест49st"
+    bad_chars = "te02тест49st"
     st = characters(
         min_codepoint=ord("0"), max_codepoint=ord("9"), blacklist_characters=bad_chars
     )
@@ -142,8 +137,8 @@ def test_blacklisted_characters():
 
 
 def test_whitelist_characters_disjoint_blacklist_characters():
-    good_chars = u"123abc"
-    bad_chars = u"456def"
+    good_chars = "123abc"
+    bad_chars = "456def"
     st = characters(
         min_codepoint=ord("0"),
         max_codepoint=ord("9"),
