@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,14 +13,12 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
+from collections import OrderedDict
 from random import Random
 
 import pytest
 
 from hypothesis import given, settings
-from hypothesis.internal.compat import OrderedDict
 from hypothesis.strategies import (
     booleans,
     dictionaries,
@@ -41,13 +37,18 @@ from tests.common.utils import flaky
 
 
 @pytest.mark.parametrize(
-    (u"col", u"strat"),
+    ("col", "strat"),
     [
         ((), tuples()),
         ([], lists(none(), max_size=0)),
         (set(), sets(none(), max_size=0)),
         (frozenset(), frozensets(none(), max_size=0)),
         ({}, fixed_dictionaries({})),
+        ({}, fixed_dictionaries({}, optional={})),
+        (OrderedDict(), fixed_dictionaries(OrderedDict(), optional=OrderedDict())),
+        ({}, fixed_dictionaries({}, optional={1: booleans()})),
+        ({0: False}, fixed_dictionaries({0: booleans()}, optional={1: booleans()})),
+        ({}, fixed_dictionaries({}, optional={(): booleans(), 0: booleans()})),
         ([], lists(nothing())),
         ([], lists(nothing(), unique=True)),
     ],
@@ -57,14 +58,14 @@ def test_find_empty_collection_gives_empty(col, strat):
 
 
 @pytest.mark.parametrize(
-    (u"coltype", u"strat"), [(list, lists), (set, sets), (frozenset, frozensets)]
+    ("coltype", "strat"), [(list, lists), (set, sets), (frozenset, frozensets)]
 )
 def test_find_non_empty_collection_gives_single_zero(coltype, strat):
     assert minimal(strat(integers()), bool) == coltype((0,))
 
 
 @pytest.mark.parametrize(
-    (u"coltype", u"strat"), [(list, lists), (set, sets), (frozenset, frozensets)]
+    ("coltype", "strat"), [(list, lists), (set, sets), (frozenset, frozensets)]
 )
 def test_minimizes_to_empty(coltype, strat):
     assert minimal(strat(integers()), lambda x: True) == coltype()
@@ -90,12 +91,17 @@ def test_ordered_dictionaries_preserve_keys():
     assert list(x.keys()) == keys
 
 
-@pytest.mark.parametrize(u"n", range(10))
+@given(fixed_dictionaries({}, optional={0: booleans(), 1: nothing(), 2: booleans()}))
+def test_fixed_dictionaries_with_optional_and_empty_keys(d):
+    assert 1 not in d
+
+
+@pytest.mark.parametrize("n", range(10))
 def test_lists_of_fixed_length(n):
     assert minimal(lists(integers(), min_size=n, max_size=n), lambda x: True) == [0] * n
 
 
-@pytest.mark.parametrize(u"n", range(10))
+@pytest.mark.parametrize("n", range(10))
 def test_sets_of_fixed_length(n):
     x = minimal(sets(integers(), min_size=n, max_size=n), lambda x: True)
     assert len(x) == n
@@ -106,7 +112,7 @@ def test_sets_of_fixed_length(n):
         assert x == set(range(min(x), min(x) + n))
 
 
-@pytest.mark.parametrize(u"n", range(10))
+@pytest.mark.parametrize("n", range(10))
 def test_dictionaries_of_fixed_length(n):
     x = set(
         minimal(
@@ -120,7 +126,7 @@ def test_dictionaries_of_fixed_length(n):
         assert x == set(range(min(x), min(x) + n))
 
 
-@pytest.mark.parametrize(u"n", range(10))
+@pytest.mark.parametrize("n", range(10))
 def test_lists_of_lower_bounded_length(n):
     x = minimal(lists(integers(), min_size=n), lambda x: sum(x) >= 2 * n)
     assert n <= len(x) <= 2 * n
@@ -129,7 +135,7 @@ def test_lists_of_lower_bounded_length(n):
     assert sum(x) == 2 * n
 
 
-@flaky(min_passes=1, max_runs=2)
+@flaky(min_passes=1, max_runs=3)
 def test_can_find_unique_lists_of_non_set_order():
     # This test checks that our strategy for unique lists doesn't accidentally
     # depend on the iteration order of sets.
@@ -142,7 +148,10 @@ def test_can_find_unique_lists_of_non_set_order():
     # a consistent value. This could be 0, or it could be the PYTHONHASHSEED
     # value listed in a failure log from CI.
 
-    ls = minimal(lists(text(), unique=True), lambda x: list(set(reversed(x))) != x)
+    ls = minimal(
+        lists(text(), min_size=2, unique=True),
+        lambda x: list(set(reversed(x))) != x,  # noqa: C414  # yes, reverse inside set
+    )
     assert len(set(ls)) == len(ls)
     assert len(ls) == 2
 
@@ -155,18 +164,15 @@ def test_can_draw_empty_set_from_unsatisfiable_strategy():
     assert find_any(sets(integers().filter(lambda s: False))) == set()
 
 
-small_set = sets(none())
-
-
-@given(lists(small_set, min_size=10))
+@given(lists(sets(none()), min_size=10))
 def test_small_sized_sets(x):
     pass
 
 
 def test_minimize_dicts_with_incompatible_keys():
     assert minimal(
-        fixed_dictionaries({1: booleans(), u"hi": lists(booleans())}), lambda x: True
-    ) == {1: False, u"hi": []}
+        fixed_dictionaries({1: booleans(), "hi": lists(booleans())}), lambda x: True
+    ) == {1: False, "hi": []}
 
 
 @given(
