@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,35 +13,33 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from hypothesis import given
 from hypothesis.strategies import binary, characters, text, tuples
 from tests.common.debug import minimal
-from tests.common.utils import checks_deprecated_behaviour, fails_with
+from tests.common.utils import fails_with
 
 
 def test_can_minimize_up_to_zero():
-    s = minimal(text(), lambda x: any(lambda t: t <= u"0" for t in x))
-    assert s == u"0"
+    s = minimal(text(), lambda x: any(lambda t: t <= "0" for t in x))
+    assert s == "0"
 
 
 def test_minimizes_towards_ascii_zero():
-    s = minimal(text(), lambda x: any(t < u"0" for t in x))
-    assert s == chr(ord(u"0") - 1)
+    s = minimal(text(), lambda x: any(t < "0" for t in x))
+    assert s == chr(ord("0") - 1)
 
 
 def test_can_handle_large_codepoints():
-    s = minimal(text(), lambda x: x >= u"☃")
-    assert s == u"☃"
+    s = minimal(text(), lambda x: x >= "☃")
+    assert s == "☃"
 
 
 def test_can_find_mixed_ascii_and_non_ascii_strings():
     s = minimal(
-        text(), lambda x: (any(t >= u"☃" for t in x) and any(ord(t) <= 127 for t in x))
+        text(), lambda x: (any(t >= "☃" for t in x) and any(ord(t) <= 127 for t in x))
     )
     assert len(s) == 2
-    assert sorted(s) == [u"0", u"☃"]
+    assert sorted(s) == ["0", "☃"]
 
 
 def test_will_find_ascii_examples_given_the_chance():
@@ -51,7 +47,7 @@ def test_will_find_ascii_examples_given_the_chance():
         tuples(text(max_size=1), text(max_size=1)), lambda x: x[0] and (x[0] < x[1])
     )
     assert ord(s[1]) == ord(s[0]) + 1
-    assert u"0" in s
+    assert "0" in s
 
 
 def test_minimisation_consistent_with_characters():
@@ -60,7 +56,7 @@ def test_minimisation_consistent_with_characters():
 
 
 def test_finds_single_element_strings():
-    assert minimal(text(), bool) == u"0"
+    assert minimal(text(), bool) == "0"
 
 
 @fails_with(AssertionError)
@@ -75,23 +71,23 @@ def test_binary_respects_max_size(x):
 
 
 def test_does_not_simplify_into_surrogates():
-    f = minimal(text(), lambda x: x >= u"\udfff")
-    assert f == u"\ue000"
+    f = minimal(text(), lambda x: x >= "\udfff")
+    assert f == "\ue000"
 
     size = 5
 
-    f = minimal(text(min_size=size), lambda x: sum(t >= u"\udfff" for t in x) >= size)
-    assert f == u"\ue000" * size
+    f = minimal(text(min_size=size), lambda x: sum(t >= "\udfff" for t in x) >= size)
+    assert f == "\ue000" * size
 
 
-@given(text(alphabet=[u"a", u"b"]))
+@given(text(alphabet=["a", "b"]))
 def test_respects_alphabet_if_list(xs):
-    assert set(xs).issubset(set(u"ab"))
+    assert set(xs).issubset(set("ab"))
 
 
-@given(text(alphabet=u"cdef"))
+@given(text(alphabet="cdef"))
 def test_respects_alphabet_if_string(xs):
-    assert set(xs).issubset(set(u"cdef"))
+    assert set(xs).issubset(set("cdef"))
 
 
 @given(text())
@@ -99,14 +95,14 @@ def test_can_encode_as_utf8(s):
     s.encode("utf-8")
 
 
-@given(text(characters(blacklist_characters=u"\n")))
+@given(text(characters(blacklist_characters="\n")))
 def test_can_blacklist_newlines(s):
-    assert u"\n" not in s
+    assert "\n" not in s
 
 
 @given(text(characters(blacklist_categories=("Cc", "Cs"))))
 def test_can_exclude_newlines_by_category(s):
-    assert u"\n" not in s
+    assert "\n" not in s
 
 
 @given(text(characters(max_codepoint=127)))
@@ -124,8 +120,3 @@ def test_fixed_size_bytes_just_draw_bytes():
 @given(text(max_size=10 ** 6))
 def test_can_set_max_size_large(s):
     pass
-
-
-@checks_deprecated_behaviour
-def test_explicit_alphabet_None_is_deprecated():
-    text(alphabet=None).example()
