@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import base64
 from collections import defaultdict, namedtuple
 
@@ -27,10 +23,8 @@ from hypothesis import __version__, reproduce_failure, seed, settings as Setting
 from hypothesis.control import current_build_context
 from hypothesis.database import ExampleDatabase
 from hypothesis.errors import DidNotReproduce, Flaky, InvalidArgument, InvalidDefinition
-from hypothesis.internal.compat import print_unicode
 from hypothesis.stateful import (
     Bundle,
-    GenericStateMachine,
     RuleBasedStateMachine,
     consumes,
     initialize,
@@ -40,58 +34,17 @@ from hypothesis.stateful import (
     rule,
     run_state_machine_as_test,
 )
-from hypothesis.strategies import (
-    binary,
-    booleans,
-    integers,
-    just,
-    lists,
-    none,
-    sampled_from,
-    tuples,
-)
-from tests.common.utils import capture_out, checks_deprecated_behaviour, raises
+from hypothesis.strategies import binary, booleans, data, integers, just, lists
+from tests.common.utils import capture_out, raises
 
 NO_BLOB_SETTINGS = Settings(print_blob=False)
 
-
-class SetStateMachine(GenericStateMachine):
-    def __init__(self):
-        self.elements = []
-
-    def steps(self):
-        strat = tuples(just(False), integers(0, 5))
-        if self.elements:
-            strat |= tuples(just(True), sampled_from(self.elements))
-        return strat
-
-    def execute_step(self, step):
-        delete, value = step
-        if delete:
-            self.elements.remove(value)
-            assert value not in self.elements
-        else:
-            self.elements.append(value)
-
-
-class OrderedStateMachine(GenericStateMachine):
-    def __init__(self):
-        self.counter = 0
-
-    def steps(self):
-        return integers(self.counter - 1, self.counter + 50)
-
-    def execute_step(self, step):
-        assert step >= self.counter
-        self.counter = step
-
-
-Leaf = namedtuple(u"Leaf", (u"label",))
-Split = namedtuple(u"Split", (u"left", u"right"))
+Leaf = namedtuple("Leaf", ("label",))
+Split = namedtuple("Split", ("left", "right"))
 
 
 class BalancedTrees(RuleBasedStateMachine):
-    trees = Bundle(u"BinaryTree")
+    trees = Bundle("BinaryTree")
 
     @rule(target=trees, x=booleans())
     def leaf(self, x):
@@ -117,7 +70,7 @@ class BalancedTrees(RuleBasedStateMachine):
             return 1 + self.size(tree.left) + self.size(tree.right)
 
 
-class DepthCharge(object):
+class DepthCharge:
     def __init__(self, value):
         if value is None:
             self.depth = 0
@@ -126,7 +79,7 @@ class DepthCharge(object):
 
 
 class DepthMachine(RuleBasedStateMachine):
-    charges = Bundle(u"charges")
+    charges = Bundle("charges")
 
     @rule(targets=(charges,), child=charges)
     def charge(self, child):
@@ -143,10 +96,10 @@ class DepthMachine(RuleBasedStateMachine):
 
 class MultipleRulesSameFuncMachine(RuleBasedStateMachine):
     def myfunc(self, data):
-        print_unicode(data)
+        print(data)
 
-    rule1 = rule(data=just(u"rule1data"))(myfunc)
-    rule2 = rule(data=just(u"rule2data"))(myfunc)
+    rule1 = rule(data=just("rule1data"))(myfunc)
+    rule2 = rule(data=just("rule2data"))(myfunc)
 
 
 class PreconditionMachine(RuleBasedStateMachine):
@@ -193,7 +146,7 @@ class NotTheLastMachine(RuleBasedStateMachine):
     stuff = Bundle("stuff")
 
     def __init__(self):
-        super(NotTheLastMachine, self).__init__()
+        super().__init__()
         self.last = None
         self.bye_called = False
 
@@ -223,12 +176,42 @@ class PopulateMultipleTargets(RuleBasedStateMachine):
         assert False
 
 
+class CanSwarm(RuleBasedStateMachine):
+    """This test will essentially never pass if you choose rules uniformly at
+    random, because every time the snake rule fires we return to the beginning,
+    so we will tend to undo progress well before we make enough progress for
+    the test to fail.
+
+    This tests our swarm testing functionality in stateful testing by ensuring
+    that we can sometimes generate long runs of steps which exclude a
+    particular rule.
+    """
+
+    def __init__(self):
+        super().__init__()
+        self.seen = set()
+
+    # The reason this rule takes a parameter is that it ensures that we do not
+    # achieve "swarming" by by just restricting the alphabet for single byte
+    # decisions, which is a thing the underlying conjecture engine  will
+    # happily do on its own without knowledge of the rule structure.
+    @rule(move=integers(0, 255))
+    def ladder(self, move):
+        self.seen.add(move)
+        assert len(self.seen) <= 15
+
+    @rule()
+    def snake(self):
+        self.seen.clear()
+
+
 bad_machines = (
     BalancedTrees,
     DepthMachine,
     RoseTreeStateMachine,
     NotTheLastMachine,
     PopulateMultipleTargets,
+    CanSwarm,
 )
 
 for m in bad_machines:
@@ -240,12 +223,12 @@ cheap_bad_machines.remove(BalancedTrees)
 
 
 with_cheap_bad_machines = pytest.mark.parametrize(
-    u"machine", cheap_bad_machines, ids=[t.__name__ for t in cheap_bad_machines]
+    "machine", cheap_bad_machines, ids=[t.__name__ for t in cheap_bad_machines]
 )
 
 
 @pytest.mark.parametrize(
-    u"machine", bad_machines, ids=[t.__name__ for t in bad_machines]
+    "machine", bad_machines, ids=[t.__name__ for t in bad_machines]
 )
 def test_bad_machines_fail(machine):
     test_class = machine.TestCase
@@ -254,10 +237,10 @@ def test_bad_machines_fail(machine):
             with raises(AssertionError):
                 test_class().runTest()
     except Exception:
-        print_unicode(o.getvalue())
+        print(o.getvalue())
         raise
     v = o.getvalue()
-    print_unicode(v)
+    print(v)
     steps = [l for l in v.splitlines() if "Step " in l or "state." in l]
     assert 1 <= len(steps) <= 50
 
@@ -272,53 +255,44 @@ def test_multiple_rules_same_func():
 
 
 def test_can_get_test_case_off_machine_instance():
-    assert SetStateMachine().TestCase is SetStateMachine().TestCase
-    assert SetStateMachine().TestCase is not None
+    assert DepthMachine().TestCase is DepthMachine().TestCase
+    assert DepthMachine().TestCase is not None
 
 
-class FlakyDrawLessMachine(GenericStateMachine):
-    def steps(self):
-        cb = current_build_context()
-        if cb.is_final:
-            return binary(min_size=1, max_size=1)
+class FlakyDrawLessMachine(RuleBasedStateMachine):
+    @rule(d=data())
+    def action(self, d):
+        if current_build_context().is_final:
+            d.draw(binary(min_size=1, max_size=1))
         else:
-            return binary(min_size=1024, max_size=1024)
-
-    def execute_step(self, step):
-        cb = current_build_context()
-        if not cb.is_final:
-            assert 0 not in bytearray(step)
+            buffer = binary(min_size=1024, max_size=1024)
+            assert 0 not in buffer
 
 
-@checks_deprecated_behaviour
 def test_flaky_draw_less_raises_flaky():
     with raises(Flaky):
         FlakyDrawLessMachine.TestCase().runTest()
 
 
-class FlakyStateMachine(GenericStateMachine):
-    def steps(self):
-        return just(())
-
-    def execute_step(self, step):
+class FlakyStateMachine(RuleBasedStateMachine):
+    @rule()
+    def action(self):
         assert current_build_context().is_final
 
 
-@checks_deprecated_behaviour
 def test_flaky_raises_flaky():
     with raises(Flaky):
         FlakyStateMachine.TestCase().runTest()
 
 
-class FlakyRatchettingMachine(GenericStateMachine):
+class FlakyRatchettingMachine(RuleBasedStateMachine):
     ratchet = 0
 
-    def steps(self):
+    @rule(d=data())
+    def action(self, d):
         FlakyRatchettingMachine.ratchet += 1
         n = FlakyRatchettingMachine.ratchet
-        return lists(integers(), min_size=n, max_size=n)
-
-    def execute_step(self, step):
+        d.draw(lists(integers(), min_size=n, max_size=n))
         assert False
 
 
@@ -329,7 +303,7 @@ class MachineWithConsumingRule(RuleBasedStateMachine):
     def __init__(self):
         self.created_counter = 0
         self.consumed_counter = 0
-        super(MachineWithConsumingRule, self).__init__()
+        super().__init__()
 
     @invariant()
     def bundle_length(self):
@@ -369,7 +343,7 @@ class MachineUsingMultiple(RuleBasedStateMachine):
 
     def __init__(self):
         self.expected_bundle_length = 0
-        super(MachineUsingMultiple, self).__init__()
+        super().__init__()
 
     @invariant()
     def bundle_length(self):
@@ -388,12 +362,72 @@ class MachineUsingMultiple(RuleBasedStateMachine):
 TestMachineUsingMultiple = MachineUsingMultiple.TestCase
 
 
+def test_multiple_variables_printed():
+    class ProducesMultiple(RuleBasedStateMachine):
+        b = Bundle("b")
+
+        @initialize(target=b)
+        def populate_bundle(self):
+            return multiple(1, 2)
+
+        @rule()
+        def fail_fast(self):
+            assert False
+
+    with capture_out() as o:
+        # The state machine must raise an exception for the
+        # falsifying example to be printed.
+        with raises(AssertionError):
+            run_state_machine_as_test(ProducesMultiple)
+
+    # This is tightly coupled to the output format of the step printing.
+    # The first line is "Falsifying Example:..." the second is creating
+    # the state machine, the third is calling the "initialize" method.
+    assignment_line = o.getvalue().split("\n")[2]
+    # 'populate_bundle()' returns 2 values, so should be
+    # expanded to 2 variables.
+    assert assignment_line == "v1, v2 = state.populate_bundle()"
+
+    # Make sure MultipleResult is iterable so the printed code is valid.
+    # See https://github.com/HypothesisWorks/hypothesis/issues/2311
+    state = ProducesMultiple()
+    v1, v2 = state.populate_bundle()
+    with raises(AssertionError):
+        state.fail_fast()
+
+
+def test_no_variables_printed():
+    class ProducesNoVariables(RuleBasedStateMachine):
+        b = Bundle("b")
+
+        @initialize(target=b)
+        def populate_bundle(self):
+            return multiple()
+
+        @rule()
+        def fail_fast(self):
+            assert False
+
+    with capture_out() as o:
+        # The state machine must raise an exception for the
+        # falsifying example to be printed.
+        with raises(AssertionError):
+            run_state_machine_as_test(ProducesNoVariables)
+
+    # This is tightly coupled to the output format of the step printing.
+    # The first line is "Falsifying Example:..." the second is creating
+    # the state machine, the third is calling the "initialize" method.
+    assignment_line = o.getvalue().split("\n")[2]
+    # 'populate_bundle()' returns 0 values, so there should be no
+    # variable assignment.
+    assert assignment_line == "state.populate_bundle()"
+
+
 def test_consumes_typecheck():
     with pytest.raises(TypeError):
         consumes(integers())
 
 
-@checks_deprecated_behaviour
 def test_ratchetting_raises_flaky():
     with raises(Flaky):
         FlakyRatchettingMachine.TestCase().runTest()
@@ -409,7 +443,7 @@ def test_empty_machine_is_invalid():
 
 def test_machine_with_no_terminals_is_invalid():
     class NonTerminalMachine(RuleBasedStateMachine):
-        @rule(value=Bundle(u"hi"))
+        @rule(value=Bundle("hi"))
         def bye(self, hi):
             pass
 
@@ -418,7 +452,7 @@ def test_machine_with_no_terminals_is_invalid():
 
 
 class DynamicMachine(RuleBasedStateMachine):
-    @rule(value=Bundle(u"hi"))
+    @rule(value=Bundle("hi"))
     def test_stuff(x):
         pass
 
@@ -431,13 +465,13 @@ class IntAdder(RuleBasedStateMachine):
 
 
 IntAdder.define_rule(
-    targets=(u"ints",), function=lambda self, x: x, arguments={u"x": integers()}
+    targets=("ints",), function=lambda self, x: x, arguments={"x": integers()}
 )
 
 IntAdder.define_rule(
-    targets=(u"ints",),
+    targets=("ints",),
     function=lambda self, x, y: x,
-    arguments={u"x": integers(), u"y": Bundle(u"ints")},
+    arguments={"x": integers(), "y": Bundle("ints")},
 )
 
 
@@ -464,18 +498,16 @@ def test_new_rules_are_picked_up_before_and_after_rules_call():
     assert len(Foo.rules()) == 2
 
 
-@checks_deprecated_behaviour
 def test_minimizes_errors_in_teardown():
     counter = [0]
 
-    class Foo(GenericStateMachine):
-        def __init__(self):
+    class Foo(RuleBasedStateMachine):
+        @initialize()
+        def init(self):
             counter[0] = 0
 
-        def steps(self):
-            return tuples()
-
-        def execute_step(self, value):
+        @rule()
+        def increment(self):
             counter[0] += 1
 
         def teardown(self):
@@ -486,40 +518,38 @@ def test_minimizes_errors_in_teardown():
     assert counter[0] == 1
 
 
-class RequiresInit(GenericStateMachine):
+class RequiresInit(RuleBasedStateMachine):
     def __init__(self, threshold):
-        super(RequiresInit, self).__init__()
+        super().__init__()
         self.threshold = threshold
 
-    def steps(self):
-        return integers()
-
-    def execute_step(self, value):
+    @rule(value=integers())
+    def action(self, value):
         if value > self.threshold:
-            raise ValueError(u"%d is too high" % (value,))
+            raise ValueError("%d is too high" % (value,))
 
 
-@checks_deprecated_behaviour
 def test_can_use_factory_for_tests():
     with raises(ValueError):
-        run_state_machine_as_test(lambda: RequiresInit(42))
+        run_state_machine_as_test(
+            lambda: RequiresInit(42), settings=Settings(max_examples=100)
+        )
 
 
-@Settings(stateful_step_count=5)
-class FailsEventually(GenericStateMachine):
+class FailsEventually(RuleBasedStateMachine):
     def __init__(self):
-        super(FailsEventually, self).__init__()
+        super().__init__()
         self.counter = 0
 
-    def steps(self):
-        return none()
-
-    def execute_step(self, _):
+    @rule()
+    def increment(self):
         self.counter += 1
         assert self.counter < 10
 
 
-@checks_deprecated_behaviour
+FailsEventually.TestCase.settings = Settings(stateful_step_count=5)
+
+
 def test_can_explicitly_pass_settings():
     run_state_machine_as_test(FailsEventually)
     try:
@@ -555,18 +585,18 @@ def test_settings_attribute_is_validated():
         FailsEventually.TestCase.settings = real_settings
 
 
-@checks_deprecated_behaviour
 def test_saves_failing_example_in_database():
     db = ExampleDatabase(":memory:")
     with raises(AssertionError):
-        run_state_machine_as_test(SetStateMachine, Settings(database=db))
+        run_state_machine_as_test(
+            DepthMachine, settings=Settings(database=db, max_examples=100)
+        )
     assert any(list(db.data.values()))
 
 
-@checks_deprecated_behaviour
 def test_can_run_with_no_db():
     with raises(AssertionError):
-        run_state_machine_as_test(SetStateMachine, Settings(database=None))
+        run_state_machine_as_test(DepthMachine, settings=Settings(database=None))
 
 
 def test_stateful_double_rule_is_forbidden(recwarn):
@@ -582,7 +612,7 @@ def test_stateful_double_rule_is_forbidden(recwarn):
 def test_can_explicitly_call_functions_when_precondition_not_satisfied():
     class BadPrecondition(RuleBasedStateMachine):
         def __init__(self):
-            super(BadPrecondition, self).__init__()
+            super().__init__()
 
         @precondition(lambda self: False)
         @rule()
@@ -602,7 +632,7 @@ def test_invariant():
 
     class Invariant(RuleBasedStateMachine):
         def __init__(self):
-            super(Invariant, self).__init__()
+            super().__init__()
 
         @invariant()
         def test_blah(self):
@@ -623,7 +653,7 @@ def test_no_double_invariant():
 
         class Invariant(RuleBasedStateMachine):
             def __init__(self):
-                super(Invariant, self).__init__()
+                super().__init__()
 
             @invariant()
             @invariant()
@@ -643,7 +673,7 @@ def test_invariant_precondition():
 
     class Invariant(RuleBasedStateMachine):
         def __init__(self):
-            super(Invariant, self).__init__()
+            super().__init__()
 
         @invariant()
         @precondition(lambda _: False)
@@ -662,12 +692,32 @@ def test_invariant_precondition():
     run_state_machine_as_test(Invariant)
 
 
+def test_invalid_rule_argument():
+    """Rule kwargs that are not a Strategy are expected to raise an InvalidArgument error."""
+    with pytest.raises(InvalidArgument):
+
+        class InvalidRuleMachine(RuleBasedStateMachine):
+            @rule(strategy=object())
+            def do_stuff(self):
+                pass
+
+
+def test_invalid_initialize_argument():
+    """Initialize kwargs that are not a Strategy are expected to raise an InvalidArgument error."""
+    with pytest.raises(InvalidArgument):
+
+        class InvalidInitialize(RuleBasedStateMachine):
+            @initialize(strategy=object())
+            def initialize(self):
+                pass
+
+
 def test_multiple_invariants():
     """If multiple invariants are present, they all get run."""
 
     class Invariant(RuleBasedStateMachine):
         def __init__(self):
-            super(Invariant, self).__init__()
+            super().__init__()
             self.first_invariant_ran = False
 
         @invariant()
@@ -693,7 +743,7 @@ def test_explicit_invariant_call_with_precondition():
 
     class BadPrecondition(RuleBasedStateMachine):
         def __init__(self):
-            super(BadPrecondition, self).__init__()
+            super().__init__()
 
         @precondition(lambda self: False)
         @invariant()
@@ -713,7 +763,7 @@ def test_invariant_checks_initial_state():
 
     class BadPrecondition(RuleBasedStateMachine):
         def __init__(self):
-            super(BadPrecondition, self).__init__()
+            super().__init__()
             self.num = 0
 
         @invariant()
@@ -732,7 +782,7 @@ def test_invariant_checks_initial_state():
 def test_always_runs_at_least_one_step():
     class CountSteps(RuleBasedStateMachine):
         def __init__(self):
-            super(CountSteps, self).__init__()
+            super().__init__()
             self.count = 0
 
         @rule()
@@ -757,10 +807,10 @@ def test_removes_needless_steps():
     but will still fail with very high probability.
     """
 
-    @Settings(derandomize=True)
+    @Settings(derandomize=True, max_examples=1000, deadline=None)
     class IncorrectDeletion(RuleBasedStateMachine):
         def __init__(self):
-            super(IncorrectDeletion, self).__init__()
+            super().__init__()
             self.__saved = defaultdict(set)
             self.__deleted = defaultdict(set)
 
@@ -797,6 +847,7 @@ def test_removes_needless_steps():
 
 
 def test_prints_equal_values_with_correct_variable_name():
+    @Settings(max_examples=100)
     class MovesBetweenBundles(RuleBasedStateMachine):
         b1 = Bundle("b1")
         b2 = Bundle("b2")
@@ -826,6 +877,7 @@ def test_prints_equal_values_with_correct_variable_name():
 
 
 def test_initialize_rule():
+    @Settings(max_examples=1000)
     class WithInitializeRules(RuleBasedStateMachine):
         initialized = []
 
@@ -883,8 +935,7 @@ def test_initialize_rule_populate_bundle():
     assert (
         result
         == """\
-Falsifying example: run_state_machine(\
-factory=WithInitializeBundleRules, data=data(...))
+Falsifying example:
 state = WithInitializeBundleRules()
 v1 = state.initialize_a(dep='dep')
 state.fail_fast(param=v1)
@@ -993,7 +1044,7 @@ def test_can_manually_call_initialize_rule():
     assert (
         result
         == """\
-Falsifying example: run_state_machine(factory=StateMachine, data=data(...))
+Falsifying example:
 state = StateMachine()
 state.initialize()
 state.fail_eventually()
@@ -1025,7 +1076,7 @@ def test_steps_printed_despite_pytest_fail(capsys):
     out, _ = capsys.readouterr()
     assert (
         """\
-Falsifying example: run_state_machine(factory=RaisesProblem, data=data(...))
+Falsifying example:
 state = RaisesProblem()
 state.oops()
 state.teardown()
@@ -1046,16 +1097,16 @@ def test_steps_not_printed_with_pytest_skip(capsys):
     assert "state" not in out
 
 
-@checks_deprecated_behaviour
 def test_rule_deprecation_targets_and_target():
     k, v = Bundle("k"), Bundle("v")
-    rule(targets=(k,), target=v)
+    with pytest.raises(InvalidArgument):
+        rule(targets=(k,), target=v)
 
 
-@checks_deprecated_behaviour
 def test_rule_deprecation_bundle_by_name():
     Bundle("k")
-    rule(target="k")
+    with pytest.raises(InvalidArgument):
+        rule(target="k")
 
 
 def test_rule_non_bundle_target():
@@ -1084,22 +1135,48 @@ def test_uses_seed(capsys):
 
 
 def test_reproduce_failure_works():
-    @reproduce_failure(__version__, base64.b64encode(b"\0\0\0"))
+    @reproduce_failure(__version__, base64.b64encode(b"\x00\x00\x01\x00\x00\x00"))
     class TrivialMachine(RuleBasedStateMachine):
         @rule()
         def oops(self):
             assert False
 
     with pytest.raises(AssertionError):
-        run_state_machine_as_test(TrivialMachine)
+        run_state_machine_as_test(TrivialMachine, settings=Settings(print_blob=True))
 
 
 def test_reproduce_failure_fails_if_no_error():
-    @reproduce_failure(__version__, base64.b64encode(b"\0\0\0"))
+    @reproduce_failure(__version__, base64.b64encode(b"\x00\x00\x01\x00\x00\x00"))
     class TrivialMachine(RuleBasedStateMachine):
         @rule()
         def ok(self):
             assert True
 
     with pytest.raises(DidNotReproduce):
-        run_state_machine_as_test(TrivialMachine)
+        run_state_machine_as_test(TrivialMachine, settings=Settings(print_blob=True))
+
+
+def test_cannot_have_zero_steps():
+    with pytest.raises(InvalidArgument):
+        Settings(stateful_step_count=0)
+
+
+def test_arguments_do_not_use_names_of_return_values():
+    # See https://github.com/HypothesisWorks/hypothesis/issues/2341
+    class TrickyPrintingMachine(RuleBasedStateMachine):
+        data = Bundle("data")
+
+        @initialize(target=data, value=integers())
+        def init_data(self, value):
+            return value
+
+        @rule(d=data)
+        def mostly_fails(self, d):
+            assert d == 42
+
+    with capture_out() as o:
+        with pytest.raises(AssertionError):
+            run_state_machine_as_test(TrickyPrintingMachine)
+    output = o.getvalue()
+    assert "v1 = state.init_data(value=0)" in output
+    assert "v1 = state.init_data(value=v1)" not in output
