@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,9 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
-import re
 import time
 import traceback
 
@@ -30,36 +25,36 @@ from hypothesis import (
     example,
     given,
     settings,
+    stateful,
     strategies as st,
+    target,
 )
-from hypothesis.internal.conjecture.data import Status
-from hypothesis.internal.conjecture.engine import ConjectureRunner, ExitReason
-from hypothesis.statistics import Statistics, collector
+from hypothesis.statistics import collector, describe_statistics
 
 
 def call_for_statistics(test_function):
-    result = [None]
-
-    def callback(statistics):
-        result[0] = statistics
-
-    with collector.with_value(callback):
+    result = []
+    with collector.with_value(result.append):
         try:
             test_function()
         except Exception:
             traceback.print_exc()
-    assert result[0] is not None
+    assert len(result) == 1, result
     return result[0]
 
 
+def unique_events(stats):
+    return set(sum((t["events"] for t in stats["generate-phase"]["test-cases"]), []))
+
+
 def test_notes_hard_to_satisfy():
     @given(st.integers())
     @settings(suppress_health_check=HealthCheck.all())
     def test(i):
-        assume(i == 0)
+        assume(i == 13)
 
     stats = call_for_statistics(test)
-    assert "satisfied assumptions" in stats.exit_reason
+    assert "satisfied assumptions" in stats["stopped-because"]
 
 
 def test_can_callback_with_a_string():
@@ -68,15 +63,14 @@ def test_can_callback_with_a_string():
         event("hi")
 
     stats = call_for_statistics(test)
-
-    assert any("hi" in s for s in stats.events)
+    assert any("hi" in s for s in unique_events(stats))
 
 
 counter = 0
 seen = []
 
 
-class Foo(object):
+class Foo:
     def __eq__(self, other):
         return True
 
@@ -102,9 +96,8 @@ def test_formats_are_evaluated_only_once():
         event(Foo())
 
     stats = call_for_statistics(test)
-
-    assert any("COUNTER 1" in s for s in stats.events)
-    assert not any("COUNTER 2" in s for s in stats.events)
+    assert "COUNTER 1" in unique_events(stats)
+    assert "COUNTER 2" not in unique_events(stats)
 
 
 def test_does_not_report_on_examples():
@@ -115,7 +108,7 @@ def test_does_not_report_on_examples():
             event("boo")
 
     stats = call_for_statistics(test)
-    assert not any("boo" in e for e in stats.events)
+    assert not unique_events(stats)
 
 
 def test_exact_timing():
@@ -124,8 +117,8 @@ def test_exact_timing():
     def test(i):
         time.sleep(0.5)
 
-    stats = call_for_statistics(test)
-    assert re.match(r"~ 5\d\dms", stats.runtimes)
+    stats = describe_statistics(call_for_statistics(test))
+    assert "~ 529ms" in stats
 
 
 def test_apparently_instantaneous_tests():
@@ -135,8 +128,8 @@ def test_apparently_instantaneous_tests():
     def test(i):
         pass
 
-    stats = call_for_statistics(test)
-    assert stats.runtimes == "< 1ms"
+    stats = describe_statistics(call_for_statistics(test))
+    assert "< 1ms" in stats
 
 
 def test_flaky_exit():
@@ -152,7 +145,7 @@ def test_flaky_exit():
                 assert False
 
     stats = call_for_statistics(test)
-    assert stats.exit_reason == "test was flaky"
+    assert stats["stopped-because"] == "test was flaky"
 
 
 @pytest.mark.parametrize("draw_delay", [False, True])
@@ -170,22 +163,23 @@ def test_draw_time_percentage(draw_delay, test_delay):
         if test_delay:
             time.sleep(0.05)
 
-    stats = call_for_statistics(test)
+    stats = describe_statistics(call_for_statistics(test))
     if not draw_delay:
-        assert stats.draw_time_percentage == "~ 0%"
+        assert "~ 0%" in stats
     elif test_delay:
-        assert stats.draw_time_percentage == "~ 50%"
+        assert "~ 50%" in stats
     else:
-        assert stats.draw_time_percentage == "~ 100%"
+        assert "~ 100%" in stats
 
 
 def test_has_lambdas_in_output():
+    @settings(max_examples=100, database=None)
     @given(st.integers().filter(lambda x: x % 2 == 0))
     def test(i):
         pass
 
     stats = call_for_statistics(test)
-    assert any("lambda x: x % 2 == 0" in e for e in stats.events)
+    assert any("lambda x: x % 2 == 0" in e for e in unique_events(stats))
 
 
 def test_stops_after_x_shrinks(monkeypatch):
@@ -195,24 +189,73 @@ def test_stops_after_x_shrinks(monkeypatch):
 
     monkeypatch.setattr(engine, "MAX_SHRINKS", 0)
 
-    @given(st.integers())
+    @given(st.integers(min_value=0))
     def test(n):
-        assert n < 100
+        assert n < 10
 
     stats = call_for_statistics(test)
-    assert "shrunk example" in stats.exit_reason
+    assert "shrunk example" in stats["stopped-because"]
 
 
-@pytest.mark.parametrize("drawtime,runtime", [(1, 0), (-1, 0), (0, -1), (-1, -1)])
-def test_weird_drawtime_issues(drawtime, runtime):
-    # Regression test for #1346, where we don't have the expected relationship
-    # 0<=drawtime<= runtime due to changing clocks or floating-point issues.
-    engine = ConjectureRunner(lambda: None)
-    engine.exit_reason = ExitReason.finished
-    engine.status_runtimes[Status.VALID] = [0]
+def test_stateful_states_are_deduped():
+    class DemoStateMachine(stateful.RuleBasedStateMachine):
+        Stuff = stateful.Bundle("stuff")
 
-    engine.all_drawtimes.append(drawtime)
-    engine.all_runtimes.extend([0, runtime])
+        @stateful.rule(target=Stuff, name=st.text())
+        def create_stuff(self, name):
+            return name
 
-    stats = Statistics(engine)
-    assert stats.draw_time_percentage == "NaN"
+        @stateful.rule(item=Stuff)
+        def do(self, item):
+            return
+
+    stats = call_for_statistics(DemoStateMachine.TestCase().runTest)
+    assert len(unique_events(stats)) <= 2
+
+
+def test_stateful_with_one_of_bundles_states_are_deduped():
+    class DemoStateMachine(stateful.RuleBasedStateMachine):
+        Things = stateful.Bundle("things")
+        Stuff = stateful.Bundle("stuff")
+        StuffAndThings = Things | Stuff
+
+        @stateful.rule(target=Things, name=st.text())
+        def create_thing(self, name):
+            return name
+
+        @stateful.rule(target=Stuff, name=st.text())
+        def create_stuff(self, name):
+            return name
+
+        @stateful.rule(item=StuffAndThings)
+        def do(self, item):
+            return
+
+    stats = call_for_statistics(DemoStateMachine.TestCase().runTest)
+    assert len(unique_events(stats)) <= 4
+
+
+def test_statistics_for_threshold_problem():
+    @settings(max_examples=100)
+    @given(st.floats(min_value=0, allow_infinity=False))
+    def threshold(error):
+        target(error, label="error")
+        assert error <= 10
+        target(0.0, label="never in failing example")
+
+    stats = call_for_statistics(threshold)
+    assert "  - Highest target scores:" in describe_statistics(stats)
+    assert "never in failing example" in describe_statistics(stats)
+    # Check that we report far-from-threshold failing examples
+    assert stats["targets"]["error"] > 10
+
+
+def test_statistics_with_events_and_target():
+    @given(st.sampled_from("1234"))
+    def test(value):
+        event(value)
+        target(float(value), label="a target")
+
+    stats = describe_statistics(call_for_statistics(test))
+    assert "- Events:" in stats
+    assert "- Highest target score: " in stats
