@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,15 +13,11 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import functools
 import threading
 from collections import namedtuple
 
-import hypothesis.reporting as reporting
-from hypothesis import HealthCheck, Verbosity, assume, given, note, settings
-from hypothesis.internal.conjecture.engine import MIN_TEST_CALLS
+from hypothesis import HealthCheck, Verbosity, assume, given, note, reporting, settings
 from hypothesis.strategies import (
     binary,
     booleans,
@@ -39,7 +33,14 @@ from hypothesis.strategies import (
     sets,
     text,
 )
-from tests.common.utils import capture_out, fails, fails_with, no_shrink, raises
+from tests.common.utils import (
+    assert_falsifying_output,
+    capture_out,
+    fails,
+    fails_with,
+    no_shrink,
+    raises,
+)
 
 
 @given(integers(), integers())
@@ -95,7 +96,7 @@ def test_integer_division_shrinks_positive_integers(n):
     assert n / 2 < n
 
 
-class TestCases(object):
+class TestCases:
     @given(integers())
     def test_abs_non_negative(self, x):
         assert abs(x) >= 0
@@ -228,13 +229,7 @@ def test_prints_on_failure_by_default():
         assume(evans >= 0)
         assert balthazar <= evans
 
-    with raises(AssertionError):
-        with capture_out() as out:
-            with reporting.with_reporter(reporting.default):
-                test_ints_are_sorted()
-    out = out.getvalue()
-    lines = [l.strip() for l in out.split("\n")]
-    assert "Falsifying example: test_ints_are_sorted(balthazar=1, evans=0)" in lines
+    assert_falsifying_output(test_ints_are_sorted, balthazar=1, evans=0)
 
 
 def test_does_not_print_on_success():
@@ -246,7 +241,7 @@ def test_does_not_print_on_success():
     with capture_out() as out:
         test_is_an_int()
     out = out.getvalue()
-    lines = [l.strip() for l in out.split(u"\n")]
+    lines = [l.strip() for l in out.split("\n")]
     assert all(not l for l in lines), lines
 
 
@@ -311,7 +306,7 @@ def test_has_ascii(x):
     if not x:
         return
     ascii_characters = (
-        u"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ \t\n"
+        "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ \t\n"
     )
     assert any(c in ascii_characters for c in x)
 
@@ -389,36 +384,42 @@ def test_fails_in_reify(x):
     pass
 
 
-@given(text(u"a"))
+@given(text("a"))
 def test_a_text(x):
-    assert set(x).issubset(set(u"a"))
+    assert set(x).issubset(set("a"))
 
 
-@given(text(u""))
+@given(text(""))
 def test_empty_text(x):
     assert not x
 
 
-@given(text(u"abcdefg"))
+@given(text("abcdefg"))
 def test_mixed_text(x):
-    assert set(x).issubset(set(u"abcdefg"))
+    assert set(x).issubset(set("abcdefg"))
 
 
 def test_when_set_to_no_simplifies_runs_failing_example_twice():
-    failing = [0]
+    failing = []
 
     @given(integers())
-    @settings(phases=no_shrink, max_examples=100, verbosity=Verbosity.normal)
+    @settings(
+        phases=no_shrink,
+        max_examples=100,
+        verbosity=Verbosity.normal,
+        report_multiple_bugs=False,
+    )
     def foo(x):
         if x > 11:
             note("Lo")
-            failing[0] += 1
+            failing.append(x)
             assert False
 
     with raises(AssertionError):
         with capture_out() as out:
             foo()
-    assert failing[0] <= MIN_TEST_CALLS + 2
+    assert len(failing) == 2
+    assert len(set(failing)) == 1
     assert "Falsifying example" in out.getvalue()
     assert "Lo" in out.getvalue()
 
