@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import functools
 
 import pytest
@@ -25,35 +21,22 @@ from hypothesis import find, given
 from hypothesis.errors import InvalidArgument
 from hypothesis.internal.validation import check_type
 from hypothesis.strategies import (
+    SearchStrategy as ActualSearchStrategy,
     binary,
     booleans,
+    data,
     dictionaries,
     floats,
     frozensets,
     integers,
     lists,
+    nothing,
     recursive,
     sets,
     text,
 )
-from tests.common.utils import checks_deprecated_behaviour, fails_with
-
-
-@checks_deprecated_behaviour
-def test_min_size_none_behavior():
-    lists(integers(), min_size=None).example()
-
-
-@checks_deprecated_behaviour
-@given(lists(integers(), min_size=5.0))
-def test_min_size_float_behaviour(arr):
-    assert len(arr) >= 5
-
-
-@checks_deprecated_behaviour
-@given(lists(integers(), max_size=5.0))
-def test_max_size_float_behaviour(arr):
-    assert len(arr) <= 5
+from hypothesis.strategies._internal.strategies import check_strategy
+from tests.common.utils import fails_with
 
 
 def test_errors_when_given_varargs():
@@ -63,7 +46,7 @@ def test_errors_when_given_varargs():
 
     with pytest.raises(InvalidArgument) as e:
         has_varargs()
-    assert u"varargs" in e.value.args[0]
+    assert "varargs" in e.value.args[0]
 
 
 def test_varargs_without_positional_arguments_allowed():
@@ -79,7 +62,7 @@ def test_errors_when_given_varargs_and_kwargs_with_positional_arguments():
 
     with pytest.raises(InvalidArgument) as e:
         has_varargs()
-    assert u"varargs" in e.value.args[0]
+    assert "varargs" in e.value.args[0]
 
 
 def test_varargs_and_kwargs_without_positional_arguments_allowed():
@@ -134,7 +117,7 @@ def test_can_put_arguments_in_the_middle():
 
 def test_float_ranges():
     with pytest.raises(InvalidArgument):
-        floats(float(u"nan"), 0).example()
+        floats(float("nan"), 0).example()
     with pytest.raises(InvalidArgument):
         floats(1, -1).example()
 
@@ -225,7 +208,6 @@ def test_given_warns_when_mixing_positional_with_keyword():
         test()
 
 
-@checks_deprecated_behaviour
 def test_cannot_find_non_strategies():
     with pytest.raises(InvalidArgument):
         find(bool, bool)
@@ -251,8 +233,6 @@ def test_valid_sizes(strategy, min_size, max_size):
 
 
 def test_check_type_with_tuple_of_length_two():
-    # This test covers logic for length-two tuples that is essential on PY2,
-    # e.g. string_types (str, unicode) which are all length-one on Python 3.
     def type_checker(x):
         check_type((int, str), x, "x")
 
@@ -260,3 +240,41 @@ def test_check_type_with_tuple_of_length_two():
     type_checker("1")
     with pytest.raises(InvalidArgument, match="Expected one of int, str but got "):
         type_checker(1.0)
+
+
+def test_validation_happens_on_draw():
+    @given(data())
+    def test(data):
+        data.draw(integers().flatmap(lambda _: lists(nothing(), min_size=1)))
+
+    with pytest.raises(InvalidArgument, match="has no values"):
+        test()
+
+
+class SearchStrategy:
+    """Not the SearchStrategy type you were looking for."""
+
+
+def check_type_(*args):
+    return check_type(*args)
+
+
+def test_check_type_suggests_check_strategy():
+    check_type_(SearchStrategy, SearchStrategy(), "this is OK")
+    with pytest.raises(AssertionError, match="use check_strategy instead"):
+        check_type_(ActualSearchStrategy, None, "SearchStrategy assertion")
+
+
+def check_strategy_(*args):
+    return check_strategy(*args)
+
+
+def test_check_strategy_might_suggest_sampled_from():
+    with pytest.raises(InvalidArgument) as excinfo:
+        check_strategy_("not a strategy")
+    assert "sampled_from" not in str(excinfo.value)
+    with pytest.raises(InvalidArgument, match="such as st.sampled_from"):
+        check_strategy_([1, 2, 3])
+    with pytest.raises(InvalidArgument, match="such as st.sampled_from"):
+        check_strategy_((1, 2, 3))
+    check_strategy_(integers(), "passes for our custom coverage check")
