@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,18 +13,18 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import datetime as dt
 
 import pytest
 from dateutil import tz, zoneinfo
 
 from hypothesis import assume, given
-from hypothesis.errors import InvalidArgument
+from hypothesis.errors import FailedHealthCheck, InvalidArgument
 from hypothesis.extra.dateutil import timezones
-from hypothesis.strategies import datetimes, sampled_from, times
-from tests.common.debug import minimal
+from hypothesis.strategies import data, datetimes, just, sampled_from, times
+from hypothesis.strategies._internal.datetime import datetime_does_not_exist
+from tests.common.debug import assert_all_examples, find_any, minimal
+from tests.common.utils import fails_with
 
 
 def test_utc_is_minimal():
@@ -67,7 +65,7 @@ def test_timezone_aware_times_are_timezone_aware(dt):
 
 def test_can_generate_non_utc():
     times(timezones=timezones()).filter(
-        lambda d: assume(d.tzinfo) and d.tzinfo.zone != u"UTC"
+        lambda d: assume(d.tzinfo) and d.tzinfo.zone != "UTC"
     ).validate()
 
 
@@ -83,3 +81,49 @@ def test_should_have_correct_ordering():
 
     next_interesting_tz = minimal(timezones(), lambda tz: offset(tz) > dt.timedelta(0))
     assert offset(next_interesting_tz) == dt.timedelta(seconds=3600)
+
+
+@given(data(), datetimes(), datetimes())
+def test_datetimes_stay_within_naive_bounds(data, lo, hi):
+    if lo > hi:
+        lo, hi = hi, lo
+    out = data.draw(datetimes(lo, hi, timezones=timezones()))
+    assert lo <= out.replace(tzinfo=None) <= hi
+
+
+DAY_WITH_IMAGINARY_HOUR_KWARGS = {
+    # The day of a spring-forward transition; 2am is imaginary
+    "min_value": dt.datetime(2020, 10, 4),
+    "max_value": dt.datetime(2020, 10, 5),
+    "timezones": just(tz.gettz("Australia/Sydney")),
+}
+
+
+@given(datetimes(timezones=timezones()) | datetimes(**DAY_WITH_IMAGINARY_HOUR_KWARGS))
+def test_dateutil_exists_our_not_exists_are_inverse(value):
+    assert datetime_does_not_exist(value) == (not tz.datetime_exists(value))
+
+
+def test_datetimes_can_exclude_imaginary():
+    find_any(
+        datetimes(**DAY_WITH_IMAGINARY_HOUR_KWARGS, allow_imaginary=True),
+        lambda x: not tz.datetime_exists(x),
+    )
+    assert_all_examples(
+        datetimes(**DAY_WITH_IMAGINARY_HOUR_KWARGS, allow_imaginary=False),
+        tz.datetime_exists,
+    )
+
+
+@fails_with(FailedHealthCheck)
+@given(
+    datetimes(
+        max_value=dt.datetime(1, 1, 1, 9),
+        timezones=just(tz.gettz("Australia/Sydney")),
+        allow_imaginary=False,
+    )
+)
+def test_non_imaginary_datetimes_at_boundary(val):
+    # This is expected to fail because Australia/Sydney is UTC+10,
+    # and the filter logic overflows when checking for round-trips.
+    assert False
