@@ -101,11 +101,16 @@ def test_time_bounds_must_be_naive(name, val):
         times(**{name: val}).validate()
 
 
-def test_can_trigger_error_in_draw_near_max_date():
+@pytest.mark.parametrize(
+    "bound",
+    [
+        {"min_value": dt.datetime.max - dt.timedelta(days=3)},
+        {"max_value": dt.datetime.min + dt.timedelta(days=3)},
+    ],
+)
+def test_can_trigger_error_in_draw_near_boundary(bound):
     assert_can_trigger_event(
-        datetimes(
-            min_value=dt.datetime.max - dt.timedelta(days=3), timezones=timezones()
-        ),
+        datetimes(**bound, timezones=timezones()),
         lambda event: "Failed to draw a datetime" in event,
     )
 
@@ -138,10 +143,12 @@ def test_datetimes_can_exclude_imaginary():
     }
     # Sanity check: fail unless those days contain an imaginary hour to filter out
     find_any(
-        datetimes(**australia, allow_imaginary=True), lambda x: not datetime_exists(x),
+        datetimes(**australia, allow_imaginary=True),
+        lambda x: not datetime_exists(x),
     )
     find_any(
-        datetimes(**ireland, allow_imaginary=True), lambda x: not datetime_exists(x),
+        datetimes(**ireland, allow_imaginary=True),
+        lambda x: not datetime_exists(x),
     )
     # Assert that with allow_imaginary=False we only generate existing datetimes.
     assert_all_examples(
