@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -24,12 +22,9 @@ For the full list of settings and their values, see
 https://docs.djangoproject.com/en/1.7/ref/settings/
 """
 
-# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
-
-from __future__ import absolute_import, division, print_function
-
 import os
 
+# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
 BASE_DIR = os.path.dirname(os.path.dirname(__file__))
 
 
@@ -37,7 +32,7 @@ BASE_DIR = os.path.dirname(os.path.dirname(__file__))
 # See https://docs.djangoproject.com/en/1.7/howto/deployment/checklist/
 
 # SECURITY WARNING: keep the secret key used in production secret!
-SECRET_KEY = u"o0zlv@74u4e3s+o0^h$+tlalh&$r(7hbx01g4^h5-3gizj%hub"
+SECRET_KEY = "o0zlv@74u4e3s+o0^h$+tlalh&$r(7hbx01g4^h5-3gizj%hub"
 
 # SECURITY WARNING: don't run with debug turned on in production!
 DEBUG = True
@@ -50,46 +45,46 @@ ALLOWED_HOSTS = []
 # Application definition
 
 INSTALLED_APPS = (
-    u"django.contrib.admin",
-    u"django.contrib.auth",
-    u"django.contrib.contenttypes",
-    u"django.contrib.sessions",
-    u"django.contrib.messages",
-    u"django.contrib.staticfiles",
-    u"tests.django.toystore",
+    "django.contrib.admin",
+    "django.contrib.auth",
+    "django.contrib.contenttypes",
+    "django.contrib.sessions",
+    "django.contrib.messages",
+    "django.contrib.staticfiles",
+    "tests.django.toystore",
 )
 
 MIDDLEWARE_CLASSES = (
-    u"django.contrib.sessions.middleware.SessionMiddleware",
-    u"django.middleware.common.CommonMiddleware",
-    u"django.middleware.csrf.CsrfViewMiddleware",
-    u"django.contrib.auth.middleware.AuthenticationMiddleware",
-    u"django.contrib.auth.middleware.SessionAuthenticationMiddleware",
-    u"django.contrib.messages.middleware.MessageMiddleware",
-    u"django.middleware.clickjacking.XFrameOptionsMiddleware",
+    "django.contrib.sessions.middleware.SessionMiddleware",
+    "django.middleware.common.CommonMiddleware",
+    "django.middleware.csrf.CsrfViewMiddleware",
+    "django.contrib.auth.middleware.AuthenticationMiddleware",
+    "django.contrib.auth.middleware.SessionAuthenticationMiddleware",
+    "django.contrib.messages.middleware.MessageMiddleware",
+    "django.middleware.clickjacking.XFrameOptionsMiddleware",
 )
 
-ROOT_URLCONF = u"tests.django.toys.urls"
+ROOT_URLCONF = "tests.django.toys.urls"
 
-WSGI_APPLICATION = u"tests.django.toys.wsgi.application"
+WSGI_APPLICATION = "tests.django.toys.wsgi.application"
 
 
 # Database
 # https://docs.djangoproject.com/en/1.7/ref/settings/#databases
 
 DATABASES = {
-    u"default": {
-        u"ENGINE": u"django.db.backends.sqlite3",
-        u"NAME": os.path.join(BASE_DIR, u"db.sqlite3"),
+    "default": {
+        "ENGINE": "django.db.backends.sqlite3",
+        "NAME": os.path.join(BASE_DIR, "db.sqlite3"),
     }
 }
 
 # Internationalization
 # https://docs.djangoproject.com/en/1.7/topics/i18n/
 
-LANGUAGE_CODE = u"en-us"
+LANGUAGE_CODE = "en-us"
 
-TIME_ZONE = u"UTC"
+TIME_ZONE = "UTC"
 
 USE_I18N = True
 
@@ -101,7 +96,7 @@ USE_TZ = os.environ.get("HYPOTHESIS_DJANGO_USETZ", "TRUE") == "TRUE"
 # Static files (CSS, JavaScript, Images)
 # https://docs.djangoproject.com/en/1.7/howto/static-files/
 
-STATIC_URL = u"/static/"
+STATIC_URL = "/static/"
 
 
 # Added these bits to avoid warnings on Django 2.2
