@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,9 +13,7 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
-from django.conf.urls import include, url
+from django.conf.urls import include, re_path
 from django.contrib import admin
 
 patterns, namespace, name = admin.site.urls
@@ -26,5 +22,5 @@ urlpatterns = [
     # Examples:
     # url(r'^$', 'toys.views.home', name='home'),
     # url(r'^blog/', include('blog.urls')),
-    url(r"^admin/", include((patterns, name), namespace=namespace))
+    re_path(r"^admin/", include((patterns, name), namespace=namespace))
 ]
