@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from django.core.exceptions import ValidationError
 from django.db import models
 
@@ -30,14 +26,19 @@ class Store(models.Model):
     company = models.ForeignKey(Company, null=False, on_delete=models.CASCADE)
 
 
+class Car(models.Model):
+    # See https://github.com/HypothesisWorks/hypothesis/issues/2369
+    model = models.CharField(max_length=100, unique=True)
+
+
 class CharmField(models.Field):
     def db_type(self, connection):
-        return u"char(1)"
+        return "char(1)"
 
 
 class CustomishField(models.Field):
     def db_type(self, connection):
-        return u"char(1)"
+        return "char(1)"
 
 
 class Customish(models.Model):
@@ -61,15 +62,15 @@ class CouldBeCharming(models.Model):
 
 
 class SelfLoop(models.Model):
-    me = models.ForeignKey(u"self", null=True, on_delete=models.SET_NULL)
+    me = models.ForeignKey("self", null=True, on_delete=models.SET_NULL)
 
 
 class LoopA(models.Model):
-    b = models.ForeignKey(u"LoopB", null=False, on_delete=models.CASCADE)
+    b = models.ForeignKey("LoopB", null=False, on_delete=models.CASCADE)
 
 
 class LoopB(models.Model):
-    a = models.ForeignKey(u"LoopA", null=True, on_delete=models.SET_NULL)
+    a = models.ForeignKey("LoopA", null=True, on_delete=models.SET_NULL)
 
 
 class ManyNumerics(models.Model):
@@ -98,7 +99,7 @@ class OddFields(models.Model):
 
 
 class CustomishDefault(models.Model):
-    customish = CustomishField(default=u"b")
+    customish = CustomishField(default="b")
 
 
 class MandatoryComputed(models.Model):
@@ -106,11 +107,11 @@ class MandatoryComputed(models.Model):
     company = models.ForeignKey(Company, null=False, on_delete=models.CASCADE)
 
     def __init__(self, **kw):
-        if u"company" in kw:
+        if "company" in kw:
             raise RuntimeError()
-        cname = kw[u"name"] + u"_company"
-        kw[u"company"] = Company.objects.create(name=cname)
-        super(MandatoryComputed, self).__init__(**kw)
+        cname = kw["name"] + "_company"
+        kw["company"] = Company.objects.create(name=cname)
+        super().__init__(**kw)
 
 
 def validate_even(value):
