@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,25 +13,19 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
+import os.path
 
-import hypothesis.strategies as st
-from hypothesis import assume, core, find, given, settings
-from hypothesis.database import InMemoryExampleDatabase
+from hypothesis import assume, core, find, given, settings, strategies as st
+from hypothesis.database import ExampleDatabase, InMemoryExampleDatabase
 from hypothesis.errors import NoSuchExample, Unsatisfiable
-from hypothesis.internal.compat import hbytes
-from tests.common.utils import (
-    all_values,
-    checks_deprecated_behaviour,
-    non_covering_examples,
-)
+from hypothesis.internal.entropy import deterministic_PRNG
+from tests.common.utils import all_values, non_covering_examples
 
 
 def has_a_non_zero_byte(x):
-    return any(hbytes(x))
+    return any(bytes(x))
 
 
-@checks_deprecated_behaviour
 def test_saves_incremental_steps_in_database():
     key = b"a database key"
     database = InMemoryExampleDatabase()
@@ -46,7 +38,6 @@ def test_saves_incremental_steps_in_database():
     assert len(all_values(database)) > 1
 
 
-@checks_deprecated_behaviour
 def test_clears_out_database_as_things_get_boring():
     key = b"a database key"
     database = InMemoryExampleDatabase()
@@ -79,7 +70,6 @@ def test_clears_out_database_as_things_get_boring():
         assert False
 
 
-@checks_deprecated_behaviour
 def test_trashes_invalid_examples():
     key = b"a database key"
     database = InMemoryExampleDatabase()
@@ -104,7 +94,6 @@ def test_trashes_invalid_examples():
     assert len(all_values(database)) < original
 
 
-@checks_deprecated_behaviour
 def test_respects_max_examples_in_database_usage():
     key = b"a database key"
     database = InMemoryExampleDatabase()
@@ -126,7 +115,8 @@ def test_respects_max_examples_in_database_usage():
         except NoSuchExample:
             pass
 
-    stuff()
+    with deterministic_PRNG():
+        stuff()
     assert len(all_values(database)) > 10
     do_we_care = False
     counter[0] = 0
@@ -145,3 +135,15 @@ def test_does_not_use_database_when_seed_is_forced(monkeypatch):
         pass
 
     test()
+
+
+@given(st.binary(), st.binary())
+def test_database_not_created_when_not_used(tmp_path_factory, key, value):
+    path = tmp_path_factory.mktemp("hypothesis") / "examples"
+    assert not os.path.exists(str(path))
+    database = ExampleDatabase(path)
+    assert not list(database.fetch(key))
+    assert not os.path.exists(str(path))
+    database.save(key, value)
+    assert os.path.exists(str(path))
+    assert list(database.fetch(key)) == [value]
