@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,17 +13,22 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import random
 
 import attr
 import pytest
 
-import hypothesis.internal.escalation as esc
-import hypothesis.strategies as st
-from hypothesis import HealthCheck, Phase, Verbosity, assume, given, note, settings
-from hypothesis.internal.compat import hbytes
+from hypothesis import (
+    HealthCheck,
+    Phase,
+    Verbosity,
+    assume,
+    given,
+    note,
+    settings,
+    strategies as st,
+)
+from hypothesis.internal import escalation as esc
 from hypothesis.internal.conjecture.data import Status
 from hypothesis.internal.conjecture.engine import ConjectureRunner
 
@@ -39,19 +42,19 @@ def teardown_module(module):
 
 
 @attr.s()
-class Write(object):
+class Write:
     value = attr.ib()
     child = attr.ib()
 
 
 @attr.s()
-class Branch(object):
+class Branch:
     bits = attr.ib()
     children = attr.ib(default=attr.Factory(dict))
 
 
 @attr.s()
-class Terminal(object):
+class Terminal:
     status = attr.ib()
     payload = attr.ib(default=None)
 
@@ -79,7 +82,7 @@ def run_language_test_for(root, data, seed):
         node = root
         while not isinstance(node, Terminal):
             if isinstance(node, Write):
-                local_data.write(hbytes(node.value))
+                local_data.write(node.value)
                 node = node.child
             else:
                 assert isinstance(node, Branch)
