@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import math
 
 import pytest
@@ -25,7 +21,6 @@ from hypothesis import find, settings as Settings
 from hypothesis.errors import NoSuchExample
 from hypothesis.strategies import booleans, dictionaries, floats, integers, lists
 from tests.common.debug import minimal
-from tests.common.utils import checks_deprecated_behaviour
 
 
 def test_can_find_an_int():
@@ -50,7 +45,6 @@ def test_can_find_nans():
         assert 2 <= len(x) <= 3
 
 
-@checks_deprecated_behaviour
 def test_condition_is_name():
     settings = Settings(max_examples=20)
     with pytest.raises(NoSuchExample) as e:
