@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,13 +13,12 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
+from collections import Counter
 
 import pytest
 
-from hypothesis import assume, given, settings
+from hypothesis import HealthCheck, assume, given, settings
 from hypothesis.database import ExampleDatabase
-from hypothesis.internal.compat import Counter
 from hypothesis.strategies import (
     booleans,
     builds,
@@ -39,7 +36,9 @@ ConstantLists = integers().flatmap(lambda i: lists(just(i)))
 OrderedPairs = integers(1, 200).flatmap(lambda e: tuples(integers(0, e - 1), just(e)))
 
 
-@settings(max_examples=100)
+# This health check fails very very occasionally - rarely enough to not be worth
+# investigation
+@settings(max_examples=100, suppress_health_check=[HealthCheck.filter_too_much])
 @given(ConstantLists)
 def test_constant_lists_are_constant(x):
     assume(len(x) >= 3)
@@ -99,7 +98,7 @@ def test_mixed_list_flatmap():
 
     result = minimal(s, criterion)
     assert len(result) == 6
-    assert set(result) == {False, u""}
+    assert set(result) == {False, ""}
 
 
 @pytest.mark.parametrize("n", range(1, 10))
