@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,11 +13,7 @@
 #
 # END HEADER
 
-"""Tests for being able to generate weird and wonderful floating point
-numbers."""
-
-
-from __future__ import absolute_import, division, print_function
+"""Tests for being able to generate weird and wonderful floating point numbers."""
 
 import math
 import sys
@@ -87,7 +81,7 @@ def test_is_not_negative_infinite(x):
 @given(floats())
 @TRY_HARDER
 def test_is_int(x):
-    assume(not (math.isinf(x) or math.isnan(x)))
+    assume(math.isfinite(x))
     assert x == int(x)
 
 
@@ -95,7 +89,7 @@ def test_is_int(x):
 @given(floats())
 @TRY_HARDER
 def test_is_not_int(x):
-    assume(not (math.isinf(x) or math.isnan(x)))
+    assume(math.isfinite(x))
     assert x != int(x)
 
 
@@ -103,7 +97,7 @@ def test_is_not_int(x):
 @given(floats())
 @TRY_HARDER
 def test_is_in_exact_int_range(x):
-    assume(not (math.isinf(x) or math.isnan(x)))
+    assume(math.isfinite(x))
     assert x + 1 != x
 
 
