@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,13 +13,11 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
+from collections import OrderedDict
 
-import hypothesis.strategies as st
-from hypothesis import given, settings
+from hypothesis import given, strategies as st
 from hypothesis.control import reject
 from hypothesis.errors import HypothesisDeprecationWarning, InvalidArgument
-from hypothesis.internal.compat import OrderedDict
 
 
 def foo(x):
@@ -51,11 +47,10 @@ def builds_ignoring_invalid(target, *args, **kwargs):
     return st.tuples(st.tuples(*args), st.fixed_dictionaries(kwargs)).map(splat)
 
 
-size_strategies = dict(
-    min_size=st.integers(min_value=0, max_value=100),
-    max_size=st.integers(min_value=0, max_value=100) | st.none(),
-)
-
+size_strategies = {
+    "min_size": st.integers(min_value=0, max_value=100),
+    "max_size": st.integers(min_value=0, max_value=100) | st.none(),
+}
 
 values = st.integers() | st.text()
 
@@ -66,9 +61,9 @@ Strategies = st.recursive(
             [
                 st.none(),
                 st.booleans(),
-                st.randoms(),
+                st.randoms(use_true_random=True),
                 st.complex_numbers(),
-                st.randoms(),
+                st.randoms(use_true_random=True),
                 st.fractions(),
                 st.decimals(),
             ]
@@ -87,7 +82,7 @@ Strategies = st.recursive(
             x,
             x,
             dict_class=st.sampled_from([dict, OrderedDict]),
-            **size_strategies
+            **size_strategies,
         ),
         st.builds(lambda s, f: s.map(f), x, st.sampled_from(fns)),
     ),
@@ -105,7 +100,6 @@ strategy_globals["baz"] = baz
 
 
 @given(Strategies)
-@settings(max_examples=2000)
 def test_repr_evals_to_thing_with_same_repr(strategy):
     r = repr(strategy)
     via_eval = eval(r, strategy_globals)
