@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,18 +13,14 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import random
 
 from pytest import raises
 
-import hypothesis.strategies as st
-from hypothesis import Verbosity, find, given, settings
-from tests.common.utils import checks_deprecated_behaviour, no_shrink
+from hypothesis import Verbosity, find, given, settings, strategies as st
+from tests.common.utils import no_shrink
 
 
-@checks_deprecated_behaviour
 def test_seeds_off_random():
     s = settings(phases=no_shrink, database=None)
     r = random.getstate()
