@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from hypothesis import HealthCheck, given, reject, settings
 from hypothesis.errors import InvalidArgument, Unsatisfiable
 from hypothesis.strategies import integers
@@ -35,7 +31,7 @@ def test_contains_the_test_function_name_in_the_exception_string():
         this_has_a_totally_unique_name()
     assert this_has_a_totally_unique_name.__name__ in e.value.args[0]
 
-    class Foo(object):
+    class Foo:
         @given(integers())
         @look_for_one
         def this_has_a_unique_name_and_lives_on_a_class(self, x):
