@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,15 +13,12 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
-import hypothesis.strategies as st
-from hypothesis import given
+from hypothesis import given, strategies as st
 from hypothesis.extra.numpy import arrays
 from tests.common.debug import find_any, minimal
 
 
-@given(arrays(object, 100, st.builds(list)))
+@given(arrays(object, 100, elements=st.builds(list)))
 def test_generated_lists_are_distinct(ls):
     assert len(set(map(id, ls))) == len(ls)
 
@@ -36,14 +31,14 @@ def distinct_integers(draw):
     return i
 
 
-@given(arrays("uint64", 10, distinct_integers()))
+@given(arrays("uint64", 10, elements=distinct_integers()))
 def test_does_not_reuse_distinct_integers(arr):
     assert len(set(arr)) == len(arr)
 
 
 def test_may_reuse_distinct_integers_if_asked():
     find_any(
-        arrays("uint64", 10, distinct_integers(), fill=distinct_integers()),
+        arrays("uint64", 10, elements=distinct_integers(), fill=distinct_integers()),
         lambda x: len(set(x)) < len(x),
     )
 
