@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,13 +13,13 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
+import sys
 
 import pytest
 
-from hypothesis.internal.compat import PY2, WINDOWS, escape_unicode_characters, hunichr
+from hypothesis.internal.compat import WINDOWS, escape_unicode_characters
 
-pytest_plugins = str("pytester")
+pytest_plugins = "pytester"
 
 TESTSUITE = """
 from hypothesis import given, settings, Verbosity
@@ -49,7 +47,6 @@ UNICODE_EMITTING = """
 import pytest
 from hypothesis import given, settings, Verbosity
 from hypothesis.strategies import text
-from hypothesis.internal.compat import PY3
 import sys
 
 def test_emits_unicode():
@@ -66,7 +63,6 @@ def test_emits_unicode():
     WINDOWS,
     reason=("Encoding issues in running the subprocess, possibly pytest's fault"),
 )
-@pytest.mark.skipif(PY2, reason="Output streams don't have encodings in python 2")
 def test_output_emitting_unicode(testdir, monkeypatch):
     monkeypatch.setenv("LC_ALL", "C")
     monkeypatch.setenv("LANG", "C")
@@ -76,7 +72,7 @@ def test_output_emitting_unicode(testdir, monkeypatch):
     )
     out = "\n".join(result.stdout.lines)
     assert "test_emits_unicode" in out
-    assert hunichr(1001) in out or escape_unicode_characters(hunichr(1001)) in out
+    assert chr(1001) in out or escape_unicode_characters(chr(1001)) in out
     assert result.ret == 0
 
 
@@ -112,21 +108,18 @@ def test_healthcheck_traceback_is_hidden(testdir):
     timeout_token = ": FailedHealthCheck"
     def_line = get_line_num(def_token, result)
     timeout_line = get_line_num(timeout_token, result)
-    assert timeout_line - def_line == 6
+    expected = 6 if sys.version_info[:2] < (3, 8) else 7
+    assert timeout_line - def_line == expected
 
 
 COMPOSITE_IS_NOT_A_TEST = """
 from hypothesis.strategies import composite
 @composite
 def test_data_factory(draw):
-    assert False, 'Unreachable due to lazy construction'
+    pass
 """
 
 
-@pytest.mark.skipif(pytest.__version__[:3] == "3.0", reason="very very old")
 def test_deprecation_of_strategies_as_tests(testdir):
     script = testdir.makepyfile(COMPOSITE_IS_NOT_A_TEST)
-    testdir.runpytest(script, "-Werror").assert_outcomes(failed=1)
-    result = testdir.runpytest(script)
-    result.assert_outcomes(passed=1)
-    result.stdout.fnmatch_lines(["*HypothesisDeprecationWarning*"])
+    testdir.runpytest(script).assert_outcomes(failed=1)
