@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,7 +13,7 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
+from unittest.mock import Mock, create_autospec
 
 import pytest
 
@@ -23,23 +21,20 @@ from hypothesis import example, given
 from hypothesis.strategies import integers
 from tests.common.utils import fails
 
-try:
-    from unittest.mock import Mock, create_autospec
-except ImportError:
-    from mock import Mock, create_autospec
+pytest_plugins = "pytester"
 
 
-@pytest.fixture
+@pytest.fixture(scope="session")
 def infinity():
     return float("inf")
 
 
-@pytest.fixture
+@pytest.fixture(scope="module")
 def mock_fixture():
     return Mock()
 
 
-@pytest.fixture
+@pytest.fixture(scope="module")
 def spec_fixture():
     class Foo:
         def __init__(self):
@@ -84,3 +79,56 @@ def test_can_inject_mock_via_fixture(mock_fixture, xs):
 def test_can_inject_autospecced_mock_via_fixture(spec_fixture, xs):
     spec_fixture.bar.return_value = float("inf")
     assert xs <= spec_fixture.bar()
+
+
+TESTSUITE = """
+import pytest
+from hypothesis import given, strategies as st
+
+@pytest.fixture(scope="function", autouse=True)
+def autofix(request):
+    pass
+
+@given(x=st.integers())
+def test_requests_function_scoped_fixture(capsys, x):
+    pass
+
+@pytest.mark.parametrize("percent", ["%", "%s"])
+@given(x=st.integers())
+def test_requests_function_scoped_fixture_percent_parametrized(capsys, x, percent):
+    # See https://github.com/HypothesisWorks/hypothesis/issues/2469
+    pass
+
+@given(x=st.integers())
+def test_autouse_function_scoped_fixture(x):
+    pass
+"""
+
+
+def test_given_plus_function_scoped_non_autouse_fixtures_are_deprecated(testdir):
+    script = testdir.makepyfile(TESTSUITE)
+    testdir.runpytest(script).assert_outcomes(passed=4)
+    testdir.runpytest(script, "-Werror").assert_outcomes(passed=1, failed=3)
+
+
+TESTSCRIPT_OVERRIDE_FIXTURE = """
+import pytest
+from hypothesis import given, strategies as st
+
+@pytest.fixture(scope="function", name="event_loop")
+def event_loop_1():
+    return
+
+@pytest.fixture(scope="module", name="event_loop")
+def event_loop_2():
+    return
+
+@given(x=st.integers())
+def test_override_fixture(event_loop, x):
+    pass
+"""
+
+
+def test_given_plus_overridden_fixture(testdir):
+    script = testdir.makepyfile(TESTSCRIPT_OVERRIDE_FIXTURE)
+    testdir.runpytest(script, "-Werror").assert_outcomes(passed=1, failed=0)
