@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,15 +13,10 @@
 #
 # END HEADER
 
-"""This module provides the core primitives of Hypothesis, such as given."""
-
-
-from __future__ import absolute_import, division, print_function
-
 import subprocess
 import sys
 
-import hypothesis.core as core
+from hypothesis import core as core
 
 
 def test_is_running_under_pytest():
