@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,12 +13,17 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
-import hypothesis.strategies as st
-from hypothesis import HealthCheck, Verbosity, assume, example, given, settings
+from hypothesis import (
+    HealthCheck,
+    Verbosity,
+    assume,
+    example,
+    given,
+    settings,
+    strategies as st,
+)
 from hypothesis.internal.compat import ceil
 from tests.common.debug import minimal
 
