@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,11 +13,8 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from random import Random
 
-import hypothesis.strategies as st
 from hypothesis import (
     HealthCheck,
     Phase,
@@ -29,11 +24,11 @@ from hypothesis import (
     given,
     reject,
     settings,
+    strategies as st,
 )
-from hypothesis.internal.compat import hbytes
 from hypothesis.internal.conjecture.data import ConjectureData, Status, StopTest
 from hypothesis.internal.conjecture.engine import ConjectureRunner
-from hypothesis.searchstrategy.numbers import WideRangeIntStrategy
+from hypothesis.strategies._internal.numbers import WideRangeIntStrategy
 
 
 @st.composite
@@ -46,10 +41,11 @@ def problems(draw):
             d = ConjectureData.for_buffer(buf)
             k = d.draw(st.integers())
             stop = d.draw_bits(8)
-            if stop > 0 and k > 0:
-                return (draw(st.integers(0, k - 1)), hbytes(d.buffer))
         except (StopTest, IndexError):
             pass
+        else:
+            if stop > 0 and k > 0:
+                return (draw(st.integers(0, k - 1)), bytes(d.buffer))
 
 
 @example((2, b"\x00\x00\n\x01"))
@@ -64,7 +60,6 @@ def problems(draw):
 @given(problems())
 def test_always_reduces_integers_to_smallest_suitable_sizes(problem):
     n, blob = problem
-    blob = hbytes(blob)
     try:
         d = ConjectureData.for_buffer(blob)
         k = d.draw(st.integers())
@@ -97,7 +92,7 @@ def test_always_reduces_integers_to_smallest_suitable_sizes(problem):
 
     assert runner.interesting_examples
 
-    v, = runner.interesting_examples.values()
+    (v,) = runner.interesting_examples.values()
 
     shrinker = runner.new_shrinker(v, lambda x: x.status == Status.INTERESTING)
 
@@ -117,9 +112,7 @@ def test_always_reduces_integers_to_smallest_suitable_sizes(problem):
     #   have power of two sizes, so it may be up to a factor of two more than
     #   that.
     bits_needed = 1 + n.bit_length()
-    actual_bits_needed = min(
-        [s for s in WideRangeIntStrategy.sizes if s >= bits_needed]
-    )
+    actual_bits_needed = min(s for s in WideRangeIntStrategy.sizes if s >= bits_needed)
     bytes_needed = actual_bits_needed // 8
     # 3 extra bytes: two for the sampler, one for the capping value.
     assert len(v.buffer) == 3 + bytes_needed
