@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,22 +13,15 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from random import Random
 
 import pytest
 
-import hypothesis.internal.conjecture.utils as cu
-import hypothesis.strategies as st
-from hypothesis import settings
-from hypothesis.internal.compat import ceil, hrange
-from hypothesis.internal.conjecture.engine import (
-    ConjectureData,
-    ConjectureRunner,
-    uniform,
-)
-from hypothesis.searchstrategy import SearchStrategy
+from hypothesis import settings, strategies as st
+from hypothesis.internal.compat import ceil
+from hypothesis.internal.conjecture import utils as cu
+from hypothesis.internal.conjecture.engine import ConjectureData, ConjectureRunner
+from hypothesis.strategies._internal import SearchStrategy
 
 POISON = "POISON"
 
@@ -55,7 +46,7 @@ class LinearLists(SearchStrategy):
         self.__elements = elements
 
     def do_draw(self, data):
-        return [data.draw(self.__elements) for _ in hrange(data.draw(self.__length))]
+        return [data.draw(self.__elements) for _ in range(data.draw(self.__length))]
 
 
 class Matrices(SearchStrategy):
@@ -68,16 +59,7 @@ class Matrices(SearchStrategy):
         n = data.draw(self.__length)
         m = data.draw(self.__length)
 
-        return [data.draw(self.__elements) for _ in hrange(n * m)]
-
-
-class TrialRunner(ConjectureRunner):
-    def generate_new_examples(self):
-        def draw_bytes(data, n):
-            return uniform(self.random, n)
-
-        while not self.interesting_examples:
-            self.test_function(self.new_conjecture_data(draw_bytes))
+        return [data.draw(self.__elements) for _ in range(n * m)]
 
 
 LOTS = 10 ** 6
@@ -101,8 +83,10 @@ def test_minimal_poisoned_containers(seed, size, p, strategy_class, monkeypatch)
         if POISON in v:
             data.mark_interesting()
 
-    runner = TrialRunner(test_function, random=Random(seed), settings=TRIAL_SETTINGS)
+    runner = ConjectureRunner(
+        test_function, random=Random(seed), settings=TRIAL_SETTINGS
+    )
     runner.run()
-    v, = runner.interesting_examples.values()
+    (v,) = runner.interesting_examples.values()
     result = ConjectureData.for_buffer(v.buffer).draw(strategy)
     assert len(result) == 1
