@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,21 +13,14 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 from random import Random
 
 import pytest
 
-import hypothesis.internal.conjecture.utils as cu
 from hypothesis import HealthCheck, settings
-from hypothesis.internal.compat import hbytes, hrange
-from hypothesis.internal.conjecture.engine import (
-    ConjectureData,
-    ConjectureRunner,
-    uniform,
-)
-from hypothesis.searchstrategy import SearchStrategy
+from hypothesis.internal.conjecture import utils as cu
+from hypothesis.internal.conjecture.engine import ConjectureData, ConjectureRunner
+from hypothesis.strategies._internal import SearchStrategy
 
 POISON = "POISON"
 
@@ -96,27 +87,23 @@ def test_can_reduce_poison_from_any_subtree(size, seed):
 
     runner = ConjectureRunner(test_function, random=random, settings=TEST_SETTINGS)
 
-    while not runner.interesting_examples:
-        runner.test_function(
-            runner.new_conjecture_data(lambda data, n: uniform(random, n))
-        )
-
+    runner.generate_new_examples()
     runner.shrink_interesting_examples()
 
-    data, = runner.interesting_examples.values()
+    (data,) = runner.interesting_examples.values()
 
     assert len(ConjectureData.for_buffer(data.buffer).draw(strat)) == size
 
     starts = [b.start for b in data.blocks if b.length == 2]
     assert len(starts) % 2 == 0
 
-    for i in hrange(0, len(starts), 2):
+    for i in range(0, len(starts), 2):
         # Now for each leaf position in the tree we try inserting a poison
         # value artificially. Additionally, we add a marker to the end that
         # must be preserved. The marker means that we are not allow to rely on
         # discarding the end of the buffer to get the desired shrink.
         u = starts[i]
-        marker = hbytes([1, 2, 3, 4])
+        marker = bytes([1, 2, 3, 4])
 
         def test_function_with_poison(data):
             v = data.draw(strat)
@@ -129,12 +116,12 @@ def test_can_reduce_poison_from_any_subtree(size, seed):
         )
 
         runner.cached_test_function(
-            data.buffer[:u] + hbytes([255]) * 4 + data.buffer[u + 4 :] + marker
+            data.buffer[:u] + bytes([255]) * 4 + data.buffer[u + 4 :] + marker
         )
 
         assert runner.interesting_examples
         runner.shrink_interesting_examples()
 
-        shrunk, = runner.interesting_examples.values()
+        (shrunk,) = runner.interesting_examples.values()
 
         assert ConjectureData.for_buffer(shrunk.buffer).draw(strat) == (POISON,)
