@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,16 +13,14 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
-from collections import namedtuple
+from collections import OrderedDict, namedtuple
 from fractions import Fraction
 from functools import reduce
 
 import pytest
 
+import hypothesis.strategies as st
 from hypothesis import assume, settings
-from hypothesis.internal.compat import OrderedDict, hrange
 from hypothesis.strategies import (
     booleans,
     builds,
@@ -62,25 +58,25 @@ def test_minimal_fractions_3():
 
 
 def test_minimize_string_to_empty():
-    assert minimal(text()) == u""
+    assert minimal(text()) == ""
 
 
 def test_minimize_one_of():
-    for _ in hrange(100):
-        assert minimal(integers() | text() | booleans()) in (0, u"", False)
+    for _ in range(100):
+        assert minimal(integers() | text() | booleans()) in (0, "", False)
 
 
 def test_minimize_mixed_list():
     mixed = minimal(lists(integers() | text()), lambda x: len(x) >= 10)
-    assert set(mixed).issubset({0, u""})
+    assert set(mixed).issubset({0, ""})
 
 
 def test_minimize_longer_string():
-    assert minimal(text(), lambda x: len(x) >= 10) == u"0" * 10
+    assert minimal(text(), lambda x: len(x) >= 10) == "0" * 10
 
 
 def test_minimize_longer_list_of_strings():
-    assert minimal(lists(text()), lambda x: len(x) >= 10) == [u""] * 10
+    assert minimal(lists(text()), lambda x: len(x) >= 10) == [""] * 10
 
 
 def test_minimize_3_set():
@@ -159,7 +155,7 @@ def test_dictionary(dict_class):
         lambda t: len(t) >= 3,
     )
     assert isinstance(x, dict_class)
-    assert set(x.values()) == {u""}
+    assert set(x.values()) == {""}
     for k in x:
         if k < 0:
             assert k + 1 in x
@@ -277,17 +273,17 @@ def test_list_with_wide_gap():
 
 
 def test_minimize_namedtuple():
-    T = namedtuple(u"T", (u"a", u"b"))
+    T = namedtuple("T", ("a", "b"))
     tab = minimal(builds(T, integers(), integers()), lambda x: x.a < x.b)
     assert tab.b == tab.a + 1
 
 
 def test_minimize_dict():
     tab = minimal(
-        fixed_dictionaries({u"a": booleans(), u"b": booleans()}),
-        lambda x: x[u"a"] or x[u"b"],
+        fixed_dictionaries({"a": booleans(), "b": booleans()}),
+        lambda x: x["a"] or x["b"],
     )
-    assert not (tab[u"a"] and tab[u"b"])
+    assert not (tab["a"] and tab["b"])
 
 
 def test_minimize_list_of_sets():
@@ -325,14 +321,65 @@ def test_can_find_sets_unique_by_incomplete_data():
         lists(tuples(integers(), integers()), unique_by=max), lambda x: len(x) >= size
     )
     assert len(ls) == size
-    values = sorted(list(map(max, ls)))
+    values = sorted(map(max, ls))
     assert values[-1] - values[0] == size - 1
-    for u, v in ls:
+    for u, _ in ls:
         assert u <= 0
 
 
-@pytest.mark.parametrize(u"n", range(10))
+@pytest.mark.parametrize("n", range(10))
 def test_lists_forced_near_top(n):
     assert minimal(
         lists(integers(), min_size=n, max_size=n + 2), lambda t: len(t) == n + 2
     ) == [0] * (n + 2)
+
+
+def test_sum_of_pair():
+    assert minimal(
+        tuples(integers(0, 1000), integers(0, 1000)), lambda x: sum(x) > 1000
+    ) == (1, 1000)
+
+
+def test_calculator_benchmark():
+    """This test comes from
+    https://github.com/jlink/shrinking-challenge/blob/main/challenges/calculator.md,
+    which is originally from Pike, Lee. "SmartCheck: automatic and efficient
+    counterexample reduction and generalization."
+    Proceedings of the 2014 ACM SIGPLAN symposium on Haskell. 2014.
+    """
+
+    expression = st.deferred(
+        lambda: st.one_of(
+            st.integers(),
+            st.tuples(st.just("+"), expression, expression),
+            st.tuples(st.just("/"), expression, expression),
+        )
+    )
+
+    def div_subterms(e):
+        if isinstance(e, int):
+            return True
+        if e[0] == "/" and e[-1] == 0:
+            return False
+        return div_subterms(e[1]) and div_subterms(e[2])
+
+    def evaluate(e):
+        if isinstance(e, int):
+            return e
+        elif e[0] == "+":
+            return evaluate(e[1]) + evaluate(e[2])
+        else:
+            assert e[0] == "/"
+            return evaluate(e[1]) // evaluate(e[2])
+
+    def is_failing(e):
+        assume(div_subterms(e))
+        try:
+            evaluate(e)
+            return False
+        except ZeroDivisionError:
+            return True
+
+    x = minimal(expression, is_failing)
+
+    assert x == ("/", 0, ("+", 0, 0))
