@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,21 +13,27 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import random
 from math import log
 
-import hypothesis.strategies as st
-from hypothesis import HealthCheck, Phase, Verbosity, assume, example, given, settings
-from hypothesis.internal.compat import ceil, hbytes, int_from_bytes
+from hypothesis import (
+    HealthCheck,
+    Phase,
+    Verbosity,
+    assume,
+    example,
+    given,
+    settings,
+    strategies as st,
+)
+from hypothesis.internal.compat import ceil, int_from_bytes
 from hypothesis.internal.conjecture.data import ConjectureData
 from hypothesis.internal.conjecture.engine import ConjectureRunner
 
 
 @st.composite
 def problem(draw):
-    b = hbytes(draw(st.binary(min_size=1, max_size=8)))
+    b = draw(st.binary(min_size=1, max_size=8))
     m = int_from_bytes(b) * 256
     assume(m > 0)
     marker = draw(st.binary(max_size=8))
@@ -75,9 +79,6 @@ def test_avoids_zig_zag_trap(p):
 
     random.seed(0)
 
-    b = hbytes(b)
-    marker = hbytes(marker)
-
     n_bits = 8 * (len(b) + 1)
 
     def test_function(data):
@@ -96,13 +97,13 @@ def test_avoids_zig_zag_trap(p):
         settings=settings(base_settings, phases=(Phase.generate, Phase.shrink)),
     )
 
-    runner.cached_test_function(b + hbytes([0]) + b + hbytes([1]) + marker)
+    runner.cached_test_function(b + bytes([0]) + b + bytes([1]) + marker)
 
     assert runner.interesting_examples
 
     runner.run()
 
-    v, = runner.interesting_examples.values()
+    (v,) = runner.interesting_examples.values()
 
     data = ConjectureData.for_buffer(v.buffer)
 
