@@ -15,6 +15,10 @@ export BASE="$BUILD_RUNTIMES"
 export PYENV="$BASE/pyenv"
 export SNAKEPIT="$BASE/python-versions/"
 
+export XDG_CACHE_HOME="$BUILD_RUNTIMES/.cache"
+export CARGO_HOME="$XDG_CACHE_HOME/.cargo"
+export RUSTUP_HOME="$XDG_CACHE_HOME/.rustup"
+
 # Note: Deliberately ignoring BUILD_RUNTIMES configuration because we don't
 # want this to go in cache, because it takes up a huge amount of space and
 # slows everything down!
@@ -26,7 +30,7 @@ export INSTALLED_RUBY_DIR="$RBENV_ROOT/versions/$RBENV_VERSION/"
 export GEM_HOME="$INSTALLED_RUBY_DIR"
 export GEM_PATH="$GEM_HOME"
 
-export PATH="$INSTALLED_RUBY_DIR/bin:$HOME/.cargo/bin:$PATH"
+export PATH="$CARGO_HOME/bin:$INSTALLED_RUBY_DIR/bin:$HOME/.cargo/bin:$PATH"
 
 pythonloc() {
     VERSION="$1"
