@@ -1,11 +1,9 @@
 #!/usr/bin/env python
 
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -17,10 +15,8 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import hashlib
 import sys
 
 if __name__ == "__main__":
-    print(hashlib.sha1(sys.stdin.read().encode("utf-8")).hexdigest()[:10])
+    print(hashlib.sha384(sys.stdin.read().encode("utf-8")).hexdigest()[:10])
