@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import os
 
 import setuptools
@@ -39,7 +35,7 @@ setuptools.setup(
     package_dir={"": SOURCE},
     url=("https://github.com/HypothesisWorks/hypothesis-python/tree/master/tooling"),
     license="MPL v2",
-    description="A library for property based testing",
+    description="A library for property-based testing",
     python_requires=">=3.6",
     long_description=open(README).read(),
 )
