@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import os
 import shlex
 import subprocess
@@ -193,11 +189,10 @@ SECRETS = os.path.join(ROOT, "secrets")
 DEPLOY_KEY = os.path.join(SECRETS, "deploy_key")
 PYPIRC = os.path.join(SECRETS, ".pypirc")
 
-RUBYGEMS_API_KEY = os.path.join(SECRETS, "api_key.yaml")
 CARGO_API_KEY = os.path.join(SECRETS, "cargo-credentials")
 
 
-SECRET_FILES = [DEPLOY_KEY, PYPIRC, RUBYGEMS_API_KEY, CARGO_API_KEY]
+SECRET_FILES = [DEPLOY_KEY, PYPIRC, CARGO_API_KEY]
 
 
 def decrypt_secrets():
@@ -237,8 +232,6 @@ IS_PULL_REQUEST = IS_TRAVIS_PULL_REQUEST or IS_CIRCLE_PULL_REQUEST
 
 
 def all_projects():
-    import hypothesistooling.projects.conjecturerust as cr
-    import hypothesistooling.projects.hypothesispython as hp
-    import hypothesistooling.projects.hypothesisruby as hr
+    from hypothesistooling.projects import conjecturerust as cr, hypothesispython as hp
 
-    return [cr, hp, hr]
+    return [cr, hp]
