@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -22,14 +20,11 @@ this work on Windows as well by using Anaconda (as our build already
 does).
 """
 
-from __future__ import absolute_import, division, print_function
-
 import os
 import shutil
 import subprocess
 
-import hypothesistooling.scripts as scripts
-from hypothesistooling import git
+from hypothesistooling import git, scripts
 from hypothesistooling.junkdrawer import once
 
 HOME = os.environ["HOME"]
