@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,14 +13,11 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import os
 import subprocess
 
 import hypothesistooling as tools
-import hypothesistooling.installers as install
-import hypothesistooling.releasemanagement as rm
+from hypothesistooling import installers as install, releasemanagement as rm
 from hypothesistooling.junkdrawer import in_dir, unlink_if_present, unquote_string
 
 PACKAGE_NAME = "conjecture-rust"
