@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import os
 import re
 import shutil
@@ -26,7 +22,7 @@ import sys
 import requests
 
 import hypothesistooling as tools
-import hypothesistooling.releasemanagement as rm
+from hypothesistooling import releasemanagement as rm
 
 PACKAGE_NAME = "hypothesis-python"
 
@@ -117,6 +113,12 @@ def update_changelog_and_version():
     __version_info__ = new_version_info
     __version__ = new_version_string
 
+    if release_type == "major":
+        major, _, _ = __version_info__
+        old = f"Hypothesis {major - 1}.x"
+        beginning = beginning.replace(old, f"Hypothesis {major}.x")
+        rest = "\n".join([old, len(old) * "=", "", rest])
+
     rm.replace_assignment(VERSION_FILE, "__version_info__", repr(new_version_info))
 
     heading_for_new_version = " - ".join((new_version_string, rm.release_date_string()))
@@ -171,6 +173,7 @@ def build_distribution():
 
 def upload_distribution():
     tools.assert_can_release()
+
     subprocess.check_call(
         [
             sys.executable,
@@ -201,11 +204,11 @@ def upload_distribution():
     # https://developer.github.com/v3/repos/releases/#create-a-release
     requests.post(
         "https://api.github.com/repos/HypothesisWorks/hypothesis/releases",
-        json=dict(
-            tag_name=tag_name(),
-            name="Hypothesis for Python - version " + current_version(),
-            body=changelog_body,
-        ),
+        json={
+            "tag_name": tag_name(),
+            "name": "Hypothesis for Python - version " + current_version(),
+            "body": changelog_body,
+        },
         timeout=120,  # seconds
         # Scoped personal access token, stored in Travis environ variable
         auth=("Zac-HD", os.environ["Zac_release_token"]),
