@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -23,9 +21,6 @@ probably makes all sorts of undocumented assumptions, even as it looks
 like a nice tidy reusable set of functionality.
 """
 
-
-from __future__ import absolute_import, division, print_function
-
 import re
 from datetime import datetime
 
@@ -61,7 +56,7 @@ def extract_assignment_from_string(contents, name):
 
     matcher = assignment_matcher(name)
 
-    for i, l in enumerate(lines):
+    for l in lines:
         match = matcher.match(l)
         if match is not None:
             return match[2].strip()
