@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import yaml
 from pyup.config import Config
 
@@ -24,7 +20,7 @@ import hypothesistooling as tools
 
 
 def test_pyup_yml_is_valid():
-    with open(tools.PYUP_FILE, "r") as i:
+    with open(tools.PYUP_FILE) as i:
         data = yaml.safe_load(i.read())
     config = Config()
     config.update_config(data)
