@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,8 +13,6 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
 import os
 import subprocess
 
@@ -37,7 +33,7 @@ def get_mypy_analysed_type(fname, val):
         encoding="utf-8",
         universal_newlines=True,
         # We set the MYPYPATH explicitly, because PEP561 discovery wasn't
-        # working in CI as of mypy==0.600 - hopefully a temporary workaround.
+        # working in CI as of mypy==0.730 - hopefully a temporary workaround.
         env=dict(os.environ, MYPYPATH=PYTHON_SRC),
     ).stdout.read()
     assert len(out.splitlines()) == 1
@@ -62,7 +58,7 @@ def get_mypy_analysed_type(fname, val):
         ("booleans().filter(bool)", "bool"),
         ("lists(none())", "list[None]"),
         ("dictionaries(integers(), datetimes())", "dict[int, datetime.datetime]"),
-        ("data()", "hypothesis._strategies.DataObject"),
+        ("data()", "hypothesis.strategies._internal.core.DataObject"),
         # Ex`-1 stands for recursion in the whole type, i.e. Ex`0 == Union[...]
         ("recursive(integers(), lists)", "Union[list[Ex`-1], int]"),
         # See https://github.com/python/mypy/issues/5269 - fix the hints on
@@ -79,11 +75,13 @@ def test_revealed_types(tmpdir, val, expect):
         "reveal_type(s)\n".format(val)
     )
     typ = get_mypy_analysed_type(str(f.realpath()), val)
-    assert typ == "hypothesis.searchstrategy.strategies.SearchStrategy[%s]" % expect
+    assert (
+        typ == "hypothesis.strategies._internal.strategies.SearchStrategy[%s]" % expect
+    )
 
 
 def test_data_object_type_tracing(tmpdir):
-    f = tmpdir.join("chech_mypy_on_st_data.py")
+    f = tmpdir.join("check_mypy_on_st_data.py")
     f.write(
         "from hypothesis.strategies import data, integers\n"
         "d = data().example()\n"
